@@ -1,7 +1,7 @@
 /*****************************************************************************
-  FILE           : $Source: /usr/local/bv/SNNS/SNNSv4.0/kernel/sources/RCS/cc_learn.h,v $
+  FILE           : $Source: /projects/higgs1/SNNS/CVS/SNNS/kernel/sources/cc_learn.h,v $
   SHORTNAME      : 
-  SNNS VERSION   : 4.0
+  SNNS VERSION   : 4.2
 
   PURPOSE        : Header file of correspondent '.c' file
   NOTES          :
@@ -10,20 +10,27 @@
   DATE           : 5.2.92
 
   CHANGED BY     : Michael Schmalzl
-  IDENTIFICATION : $State: Exp $ $Locker:  $
-  RCS VERSION    : $Revision: 2.3 $
-  LAST CHANGE    : $Date: 1995/03/14 14:02:41 $
+  RCS VERSION    : $Revision: 2.7 $
+  LAST CHANGE    : $Date: 1998/02/25 15:25:57 $
 
-             Copyright (c) 1990-1995  SNNS Group, IPVR, Univ. Stuttgart, FRG
+    Copyright (c) 1990-1995  SNNS Group, IPVR, Univ. Stuttgart, FRG
+    Copyright (c) 1996-1998  SNNS Group, WSI, Univ. Tuebingen, FRG
 
 ******************************************************************************/
 #ifndef _CC_LEARN_DEFINED_
 #define  _CC_LEARN_DEFINED_
 
 /* begin global definition section */
+extern krui_err LEARN_CC(int StartPattern, int EndPattern,
+                      float *ParameterInArray, int NoOfInParams,
+                      float **ParameterOutArray, int *NoOfOutParams);
 extern krui_err LEARN_CasCor(int StartPattern, int EndPattern,
                       float *ParameterInArray, int NoOfInParams,
                       float **ParameterOutArray, int *NoOfOutParams);
+extern krui_err TEST_CasCor(int start_pattern, int end_pattern,
+			float *parameterInArray, int NoOfInParams,
+			float **parameterOutArray, int *NoOfOutParams);
+
 /* end   global definition section */
 
 /* begin privat definition section */
