@@ -1,7 +1,7 @@
 /*****************************************************************************
-  FILE           : $Source: /usr/local/bv/SNNS/SNNSv4.0/kernel/sources/RCS/dlvq_learn.c,v $
+  FILE           : $Source: /projects/higgs1/SNNS/CVS/SNNS/kernel/sources/dlvq_learn.c,v $
   SHORTNAME      : 
-  SNNS VERSION   : 4.0
+  SNNS VERSION   : 4.2
 
   PURPOSE        : Functions of DLVQ
   NOTES          :
@@ -10,20 +10,23 @@
   DATE           : 5.2.93
 
   CHANGED BY     : Michael Vogt, Guenter Mamier
-  IDENTIFICATION : $State: Exp $ $Locker:  $
-  RCS VERSION    : $Revision: 2.5 $
-  LAST CHANGE    : $Date: 1995/03/24 10:07:04 $
+  RCS VERSION    : $Revision: 2.12 $
+  LAST CHANGE    : $Date: 1998/03/13 16:23:54 $
 
-             Copyright (c) 1990-1995  SNNS Group, IPVR, Univ. Stuttgart, FRG
+    Copyright (c) 1990-1995  SNNS Group, IPVR, Univ. Stuttgart, FRG
+    Copyright (c) 1996-1998  SNNS Group, WSI, Univ. Tuebingen, FRG
 
 ******************************************************************************/
+#include <config.h>
 
 #include <stdio.h>
+#include <stdlib.h>
 #include <math.h>
 #include <time.h>  
 #include <memory.h>
-#include <malloc.h>
+#ifdef HAVE_VALUES_H
 #include <values.h>
+#endif
 
 #include "kr_typ.h"      /*  Kernel Types and Constants  */
 #include "kr_const.h"    /*  Constant Declarators for SNNS-Kernel  */
@@ -35,7 +38,7 @@
 #include "kr_ui.h"
 #include "cc_mac.h"
 #include "kr_newpattern.h"
-#include "cc_rcc.h"
+#include "cc_glob.h"
 #include "dlvq_type.h"
 #include "dlvq_learn.ph"
 
@@ -1009,6 +1012,7 @@ krui_err LEARN_DLVQ(int startPattern, int endPattern, float *ParameterInArray,
 	learnParam1 = ParameterInArray[0];
 	learnParam2 = ParameterInArray[1];
 	noOfTrainingCycles = (int)ParameterInArray[2];
+	dlvq_numberOfLearnCycles = (int)ParameterInArray[3];
     }
   
 
