@@ -1,7 +1,7 @@
 /*****************************************************************************
-  FILE           : $Source: /usr/local/bv/SNNS/SNNSv4.0/kernel/sources/RCS/dlvq_learn.h,v $
+  FILE           : $Source: /projects/higgs1/SNNS/CVS/SNNS/kernel/sources/dlvq_learn.h,v $
   SHORTNAME      : 
-  SNNS VERSION   : 4.0
+  SNNS VERSION   : 4.2
 
   PURPOSE        : Header file of correspondent '.c' file
   NOTES          :
@@ -10,11 +10,11 @@
   DATE           : 5.2.93
 
   CHANGED BY     : 
-  IDENTIFICATION : $State: Exp $ $Locker:  $
-  RCS VERSION    : $Revision: 2.3 $
-  LAST CHANGE    : $Date: 1995/03/14 14:02:54 $
+  RCS VERSION    : $Revision: 2.6 $
+  LAST CHANGE    : $Date: 1998/02/25 15:26:07 $
 
-             Copyright (c) 1990-1995  SNNS Group, IPVR, Univ. Stuttgart, FRG
+    Copyright (c) 1990-1995  SNNS Group, IPVR, Univ. Stuttgart, FRG
+    Copyright (c) 1996-1998  SNNS Group, WSI, Univ. Tuebingen, FRG
 
 ******************************************************************************/
 
