@@ -1,7 +1,7 @@
 /*****************************************************************************
-  FILE           : $Source: /usr/local/bv/SNNS/SNNSv4.1/kernel/sources/RCS/ext_typ.h,v $
+  FILE           : $Source: /projects/higgs1/SNNS/CVS/SNNS/kernel/sources/ext_typ.h,v $
   SHORTNAME      : 
-  SNNS VERSION   : 4.1
+  SNNS VERSION   : 4.2
 
   PURPOSE        : SNNS MasPar Kernel: Datatypes and Constants for Internal Usage
   NOTES          :
@@ -10,11 +10,11 @@
   DATE           : 01.01.92
 
   CHANGED BY     : Sven Doering
-  IDENTIFICATION : $State: Exp $ $Locker:  $
-  RCS VERSION    : $Revision: 2.5 $
-  LAST CHANGE    : $Date: 1995/11/16 12:02:18 $
+  RCS VERSION    : $Revision: 2.7 $
+  LAST CHANGE    : $Date: 1998/02/25 15:26:11 $
 
-             Copyright (c) 1990-1995  SNNS Group, IPVR, Univ. Stuttgart, FRG
+    Copyright (c) 1990-1995  SNNS Group, IPVR, Univ. Stuttgart, FRG
+    Copyright (c) 1996-1998  SNNS Group, WSI, Univ. Tuebingen, FRG
 
 ******************************************************************************/
 #ifndef  KR_EXTERNAL_TYPES
