@@ -1,7 +1,7 @@
 /*****************************************************************************
-  FILE           : $Source: /import/snns/SNNSv4.0/kernel/sources/RCS/func_tbl.c,v $
+  FILE           : $Source: /projects/higgs1/SNNS/CVS/SNNS/kernel/sources/func_tbl.c,v $
   SHORTNAME      : 
-  SNNS VERSION   : 4.0
+  SNNS VERSION   : 4.2
 
   PURPOSE        : SNNS-Kernel Function table
   NOTES          :
@@ -9,14 +9,15 @@
   AUTHOR         : Niels Mache
   DATE           : 25.06.90
 
-  CHANGED BY     : Sven Doering, Michael Vogt, Ralf Huebner
-  IDENTIFICATION : $State: Exp $ $Locker:  $
-  RCS VERSION    : $Revision: 2.19 $
-  LAST CHANGE    : $Date: 1995/05/08 15:02:35 $
+  CHANGED BY     : Sven Doering, Michael Vogt, Ralf Huebner, Thomas Gern
+  RCS VERSION    : $Revision: 2.51 $
+  LAST CHANGE    : $Date: 1998/09/03 09:52:20 $
 
-             Copyright (c) 1990-1995  SNNS Group, IPVR, Univ. Stuttgart, FRG
+    Copyright (c) 1990-1995  SNNS Group, IPVR, Univ. Stuttgart, FRG
+    Copyright (c) 1996-1998  SNNS Group, WSI, Univ. Tuebingen, FRG
 
 ******************************************************************************/
+#include <config.h>
 #include <stdio.h>
 
 #include "kr_typ.h"	    /*	Kernel Types and Constants  */
@@ -24,15 +25,18 @@
 #include "learn_f.h"
 #include "init_f.h"
 #include "trans_f.h"
+#include "remap_f.h"
 #include "update_f.h"
 #include "arttr_f.h"
 #include "tbl_func.h"
 #include "kr_td.h"
 #include "cc_learn.h"
-#include "rcc_learn.h"
+#include "tacoma_learn.h"
+#include "cc_type.h"
 #include "dlvq_learn.h"
 #include "prun_f.h"
 #include "stochastic_learn_f.h" 
+#include "scaled_conj_grad.h"
 
 #include "func_tbl.ph"
 
@@ -76,6 +80,7 @@ struct FuncTable  kernel_func_table[]	=
 {"Out_Clip_11",      OUT_FUNC, 0, 0, (FunctionPtr) OUT_Clip_11},
 {"Out_ART2_Noise_PLin", OUT_FUNC, 0, 0, (FunctionPtr) OUT_ART2_Noise_PLin},
 {"Out_ART2_Noise_ContDiff", OUT_FUNC, 0, 0, (FunctionPtr) OUT_ART2_Noise_ContDiff},
+{"Out_Custom_Python",OUT_FUNC, 0, 0, (FunctionPtr) OUT_Custom_Python},
 
 /*  Activation functions  */
 /*  This is the DEFAULT FUNCTION  */
@@ -87,6 +92,7 @@ struct FuncTable  kernel_func_table[]	=
 {"Act_Perceptron",   ACT_FUNC, 0, 0, (FunctionPtr) ACT_Perceptron},
 {"Act_Signum",       ACT_FUNC, 0, 0, (FunctionPtr) ACT_Signum},
 {"Act_Signum0",      ACT_FUNC, 0, 0, (FunctionPtr) ACT_Signum0},
+{"Act_Softmax",     ACT_FUNC ,0, 0, (FunctionPtr) ACT_Softmax},
 {"Act_StepFunc",     ACT_FUNC, 0, 0, (FunctionPtr) ACT_StepFunction},
 {"Act_HystStep",     ACT_FUNC, 0, 0, (FunctionPtr) ACT_HystStepFunction},
 {"Act_BAM",          ACT_FUNC, 0, 0, (FunctionPtr) ACT_BAMFunction},
@@ -116,17 +122,17 @@ struct FuncTable  kernel_func_table[]	=
 {"Act_ARTMAP_NCa",   ACT_FUNC, 0, 0, (FunctionPtr) ACT_ARTMAP_NCa},
 {"Act_ARTMAP_NCb",   ACT_FUNC, 0, 0, (FunctionPtr) ACT_ARTMAP_NCb},
 {"Act_ARTMAP_DRho",  ACT_FUNC, 0, 0, (FunctionPtr) ACT_ARTMAP_DRho},
-{"Act_RCC_Logistic",    ACT_FUNC, 1, 0, (FunctionPtr) ACT_RCC_Logistic},
-{"Act_RCC_LogisticSym", ACT_FUNC, 1, 0, (FunctionPtr) ACT_RCC_LogisticSym},
-{"Act_RCC_Tanh",        ACT_FUNC, 1, 0, (FunctionPtr) ACT_RCC_Tanh},
-{"Act_RCC_Linear",      ACT_FUNC, 1, 0, (FunctionPtr) ACT_RCC_Linear},
-{"Act_LogSym",          ACT_FUNC, 0, 0, (FunctionPtr) ACT_LogisticSym},
+{"Act_LogSym",       ACT_FUNC, 0, 0, (FunctionPtr) ACT_LogisticSym},
+{"Act_CC_Thresh",    ACT_FUNC, 0, 0, (FunctionPtr) ACT_CC_Threshold},
+{"Act_Sinus",        ACT_FUNC, 0, 0, (FunctionPtr) ACT_SIN},
+{"Act_Exponential",  ACT_FUNC, 0, 0, (FunctionPtr) ACT_EXPONENT},
 {"Act_TD_Logistic",  ACT_FUNC, 0, 0, (FunctionPtr) ACT_TD_Logistic},
-{"Act_TD_Elliott",  ACT_FUNC, 0, 0, (FunctionPtr) ACT_TD_Elliott},
+{"Act_TD_Elliott",   ACT_FUNC, 0, 0, (FunctionPtr) ACT_TD_Elliott},
 {"Act_Euclid",       ACT_FUNC, 0, 0, (FunctionPtr) ACT_Euclid},
 {"Act_Component",    ACT_FUNC, 0, 0, (FunctionPtr) ACT_Component},
 {"Act_RM",	     ACT_FUNC, 0, 0, (FunctionPtr) ACT_RM}, 
-
+{"Act_TACOMA",       ACT_FUNC, 0, 0, (FunctionPtr) ACT_TACOMA},
+{"Act_Custom_Python",       ACT_FUNC, 0, 0, (FunctionPtr) ACT_Custom_Python},
 
 
 /*  Derivation functions of the activation functions
@@ -141,6 +147,7 @@ struct FuncTable  kernel_func_table[]	=
 {"Act_Perceptron",   ACT_DERIV_FUNC, 0, 0, (FunctionPtr) ACT_DERIV_Dummy},
 {"Act_Signum",       ACT_DERIV_FUNC, 0, 0, (FunctionPtr) ACT_DERIV_Dummy},
 {"Act_Signum0",      ACT_DERIV_FUNC, 0, 0, (FunctionPtr) ACT_DERIV_Dummy},
+{"Act_Softmax",     ACT_DERIV_FUNC ,0, 0, (FunctionPtr) ACT_DERIV_Dummy},
 {"Act_StepFunc",     ACT_DERIV_FUNC, 0, 0, (FunctionPtr) ACT_DERIV_Dummy},
 {"Act_HystStep",     ACT_DERIV_FUNC, 0, 0, (FunctionPtr) ACT_DERIV_Dummy},
 {"Act_BAM",          ACT_DERIV_FUNC, 0, 0, (FunctionPtr) ACT_DERIV_Dummy},
@@ -158,7 +165,6 @@ struct FuncTable  kernel_func_table[]	=
 {"Act_at_least_2",   ACT_DERIV_FUNC, 0, 0, (FunctionPtr) ACT_DERIV_Dummy},
 {"Act_exactly_1",    ACT_DERIV_FUNC, 0, 0, (FunctionPtr) ACT_DERIV_Dummy},
 {"Act_Product",      ACT_DERIV_FUNC, 0, 0, (FunctionPtr) ACT_DERIV_Dummy},
-
 {"Act_ART1_NC",      ACT_DERIV_FUNC, 0, 0, (FunctionPtr) ACT_DERIV_Dummy},
 {"Act_ART2_Identity",ACT_DERIV_FUNC, 0, 0, (FunctionPtr) ACT_DERIV_Dummy},
 {"Act_ART2_NormP",   ACT_DERIV_FUNC, 0, 0, (FunctionPtr) ACT_DERIV_Dummy},
@@ -170,17 +176,17 @@ struct FuncTable  kernel_func_table[]	=
 {"Act_ARTMAP_NCa",   ACT_DERIV_FUNC, 0, 0, (FunctionPtr) ACT_DERIV_Dummy},
 {"Act_ARTMAP_NCb",   ACT_DERIV_FUNC, 0, 0, (FunctionPtr) ACT_DERIV_Dummy},
 {"Act_ARTMAP_DRho",  ACT_DERIV_FUNC, 0, 0, (FunctionPtr) ACT_DERIV_Dummy},
-{"Act_RCC_Logistic",    ACT_DERIV_FUNC, 0, 0, (FunctionPtr) ACT_DERIV_Logistic},
-{"Act_RCC_LogisticSym", ACT_DERIV_FUNC, 0, 0, (FunctionPtr) ACT_DERIV_LogisticSym},
-{"Act_RCC_Tanh",        ACT_DERIV_FUNC, 0, 0, (FunctionPtr) ACT_DERIV_tanh},
-{"Act_RCC_Linear",      ACT_DERIV_FUNC, 0, 0, (FunctionPtr) ACT_DERIV_Identity},
-{"Act_LogSym",          ACT_DERIV_FUNC, 0, 0, (FunctionPtr) ACT_DERIV_LogisticSym},
+{"Act_LogSym",       ACT_DERIV_FUNC, 0, 0, (FunctionPtr) ACT_DERIV_LogisticSym},
+{"Act_CC_Thresh",    ACT_DERIV_FUNC, 0, 0, (FunctionPtr) ACT_DERIV_CC_Threshold},
+{"Act_Sinus",        ACT_DERIV_FUNC, 0, 0, (FunctionPtr) ACT_DERIV_SIN},
+{"Act_Exponential",  ACT_DERIV_FUNC, 0, 0, (FunctionPtr) ACT_DERIV_EXPONENT},
 {"Act_TD_Logistic",  ACT_DERIV_FUNC, 0, 0, (FunctionPtr) ACT_DERIV_TD_Logistic},
-{"Act_TD_Elliott",  ACT_DERIV_FUNC, 0, 0, (FunctionPtr) ACT_DERIV_TD_Elliott},
+{"Act_TD_Elliott",   ACT_DERIV_FUNC, 0, 0, (FunctionPtr) ACT_DERIV_TD_Elliott},
 {"Act_Euclid",       ACT_DERIV_FUNC, 0, 0, (FunctionPtr) ACT_DERIV_Dummy},
 {"Act_Component",    ACT_DERIV_FUNC, 0, 0, (FunctionPtr) ACT_DERIV_Dummy},
 {"Act_RM",           ACT_DERIV_FUNC, 0, 0, (FunctionPtr) ACT_DERIV_Dummy}, 
-
+{"Act_TACOMA",       ACT_DERIV_FUNC, 0, 0, (FunctionPtr) ACT_DERIV_TACOMA},
+{"Act_Custom_Python",       ACT_DERIV_FUNC, 0, 0, (FunctionPtr) ACT_DERIV_Custom_Python},
 
 /*  Second derivation functions of the activation functions
     NOTE: The second derivative function of the activation function
@@ -195,6 +201,7 @@ struct FuncTable  kernel_func_table[]	=
 {"Act_Perceptron",          ACT_2_DERIV_FUNC, 0, 0, (FunctionPtr) ACT_2_DERIV_Dummy},
 {"Act_Signum",              ACT_2_DERIV_FUNC, 0, 0, (FunctionPtr) ACT_2_DERIV_Dummy},
 {"Act_Signum0",             ACT_2_DERIV_FUNC, 0, 0, (FunctionPtr) ACT_2_DERIV_Dummy},
+{"Act_Softmax",             ACT_2_DERIV_FUNC ,0, 0, (FunctionPtr) ACT_2_DERIV_Dummy},
 {"Act_StepFunc",            ACT_2_DERIV_FUNC, 0, 0, (FunctionPtr) ACT_2_DERIV_Dummy},
 {"Act_HystStep",            ACT_2_DERIV_FUNC, 0, 0, (FunctionPtr) ACT_2_DERIV_Dummy},
 {"Act_BAM",                 ACT_2_DERIV_FUNC, 0, 0, (FunctionPtr) ACT_2_DERIV_Dummy},
@@ -223,16 +230,17 @@ struct FuncTable  kernel_func_table[]	=
 {"Act_ARTMAP_NCa",          ACT_2_DERIV_FUNC, 0, 0, (FunctionPtr) ACT_2_DERIV_Dummy},
 {"Act_ARTMAP_NCb",          ACT_2_DERIV_FUNC, 0, 0, (FunctionPtr) ACT_2_DERIV_Dummy},
 {"Act_ARTMAP_DRho",         ACT_2_DERIV_FUNC, 0, 0, (FunctionPtr) ACT_2_DERIV_Dummy},
-{"Act_RCC_Logistic",        ACT_2_DERIV_FUNC, 0, 0, (FunctionPtr) ACT_2_DERIV_Logistic},
-{"Act_RCC_LogisticSym",     ACT_2_DERIV_FUNC, 0, 0, (FunctionPtr) ACT_2_DERIV_TanHFunction},
-{"Act_RCC_Tanh",            ACT_2_DERIV_FUNC, 0, 0, (FunctionPtr) ACT_2_DERIV_tanh},
-{"Act_RCC_Linear",          ACT_2_DERIV_FUNC, 0, 0, (FunctionPtr) ACT_2_DERIV_Identity},
 {"Act_LogSym",              ACT_2_DERIV_FUNC, 0, 0, (FunctionPtr) ACT_2_DERIV_TanHFunction},
 {"Act_TD_Logistic",         ACT_2_DERIV_FUNC, 0, 0, (FunctionPtr) ACT_2_DERIV_Dummy},
 {"Act_TD_Elliott",          ACT_2_DERIV_FUNC, 0, 0, (FunctionPtr) ACT_2_DERIV_Dummy},
 {"Act_Euclid",              ACT_2_DERIV_FUNC, 0, 0, (FunctionPtr) ACT_2_DERIV_Dummy},
 {"Act_Component",           ACT_2_DERIV_FUNC, 0, 0, (FunctionPtr) ACT_2_DERIV_Dummy},
 {"Act_RM",                  ACT_2_DERIV_FUNC, 0, 0, (FunctionPtr) ACT_2_DERIV_Dummy}, 
+{"Act_TACOMA",              ACT_2_DERIV_FUNC, 0, 0, (FunctionPtr) ACT_2_DERIV_Dummy},
+{"Act_CC_Thresh",           ACT_2_DERIV_FUNC, 0, 0, (FunctionPtr) ACT_2_DERIV_Dummy},
+{"Act_Sinus",               ACT_2_DERIV_FUNC, 0, 0, (FunctionPtr) ACT_2_DERIV_Dummy},
+{"Act_Exponential",         ACT_2_DERIV_FUNC, 0, 0, (FunctionPtr) ACT_2_DERIV_Dummy},
+{"Act_Custom_Python",         ACT_2_DERIV_FUNC, 0, 0, (FunctionPtr) ACT_2_DERIV_Dummy},
 
 
 /*  Site functions  */
@@ -251,8 +259,8 @@ struct FuncTable  kernel_func_table[]	=
 {"Topological_Order", UPDATE_FUNC | DEFAULT_FUNC, 0, 0, (FunctionPtr) UPDATE_topologicalPropagate},
 {"ART1_Stable",       UPDATE_FUNC, 1, 0, (FunctionPtr) UPDATE_ART1_Propagate},
 {"ART1_Synchronous",  UPDATE_FUNC, 1, 0, (FunctionPtr) UPDATE_ART1_syncPropagate},
-{"ART2_Stable",       UPDATE_FUNC, 1, 0, (FunctionPtr) UPDATE_ART2_Propagate},
-{"ART2_Synchronous",  UPDATE_FUNC, 1, 0, (FunctionPtr) UPDATE_ART2_syncPropagate},
+{"ART2_Stable",       UPDATE_FUNC, 5, 0, (FunctionPtr) UPDATE_ART2_Propagate},
+{"ART2_Synchronous",  UPDATE_FUNC, 5, 0, (FunctionPtr) UPDATE_ART2_syncPropagate},
 {"ARTMAP_Stable",     UPDATE_FUNC, 3, 0, (FunctionPtr) UPDATE_ARTMAP_Propagate},
 {"ARTMAP_Synchronous",UPDATE_FUNC, 3, 0, (FunctionPtr) UPDATE_ARTMAP_syncPropagate},
 {"Auto_Synchronous",    UPDATE_FUNC, 1, 0, (FunctionPtr) UPDATE_RM_Propagate},
@@ -268,10 +276,10 @@ struct FuncTable  kernel_func_table[]	=
 {"Kohonen_Order",     UPDATE_FUNC, 0, 0, (FunctionPtr) UPDATE_KohonenPropagate},
 {"Random_Order",      UPDATE_FUNC, 0, 0, (FunctionPtr) UPDATE_randomOrderPropagate},
 {"Random_Permutation",UPDATE_FUNC, 0, 0, (FunctionPtr) UPDATE_randomPermutPropagate},
-{"RCC_Order",         UPDATE_FUNC, 0, 0, (FunctionPtr) UPDATE_RCC_Propagate},
 {"Serial_Order",      UPDATE_FUNC, 0, 0, (FunctionPtr) UPDATE_serialPropagate},
 {"Synchonous_Order",  UPDATE_FUNC, 0, 0, (FunctionPtr) UPDATE_syncPropagate},
 {"TimeDelay_Order",   UPDATE_FUNC, 0, 0, (FunctionPtr) UPDATE_TimeDelayPropagate},
+{"ENZO_prop",         UPDATE_FUNC, 1, 0, (FunctionPtr) ENZO_propagate},
 
 /*  Leaning Functions  */
 /*  This is the DEFAULT FUNCTION  */
@@ -282,31 +290,36 @@ struct FuncTable  kernel_func_table[]	=
 {"ARTMAP",              LEARN_FUNC, 3, 0, (FunctionPtr) LEARN_ARTMAP},
 {"BackPercolation",     LEARN_FUNC, 3, 1, (FunctionPtr) LEARN_perc},
 {"BackpropBatch",       LEARN_FUNC | FF_LEARN_FUNC, 2, 1, (FunctionPtr) LEARN_backpropBatch},
+{"BackpropChunk",       LEARN_FUNC, 3, 1, (FunctionPtr) LEARN_backpropChunk},
+{"BackpropClassJogChunk", LEARN_FUNC, 5, 1, (FunctionPtr) LEARN_backpropClassJogChunk},
+{"BackpropJogChunk",    LEARN_FUNC, 5, 1, (FunctionPtr) LEARN_backpropJogChunk},
 {"BackpropMomentum",    LEARN_FUNC | FF_LEARN_FUNC, 4, 1, (FunctionPtr) LEARN_backpropMomentum},
 {"BackpropWeightDecay", LEARN_FUNC | FF_LEARN_FUNC, 4, 1, (FunctionPtr) LEARN_backpropWeightDecay},
 {"BPTT",                LEARN_FUNC, 3, 1, (FunctionPtr) LEARN_BPTT},
 {"BBPTT",               LEARN_FUNC, 3, 1, (FunctionPtr) LEARN_BBPTT},
-{"CC",                  LEARN_FUNC, 5, 1, (FunctionPtr) LEARN_CasCor},
+{"CC",                  LEARN_FUNC, 5, 1, (FunctionPtr) LEARN_CC},
 {"Counterpropagation",  LEARN_FUNC, 3, 1, (FunctionPtr) LEARN_CPN},
-{"Dynamic_LVQ",         LEARN_FUNC, 5, 1, (FunctionPtr) LEARN_DLVQ},
+{"Dynamic_LVQ",         LEARN_FUNC, 5, 1, (FunctionPtr) LEARN_DLVQ}, /* No Of params must be 5 !!! Otherwise batchman will not work for this function */
 {"Hebbian",             LEARN_FUNC, 3, 1, (FunctionPtr) LEARN_HEBB},
-{"JE_BP",               LEARN_FUNC, 2, 1, (FunctionPtr) LEARN_JE_Backprop},
-{"JE_BP_Momentum",      LEARN_FUNC, 4, 1, (FunctionPtr) LEARN_JE_BackpropMomentum},
-{"JE_Quickprop",        LEARN_FUNC, 4, 1, (FunctionPtr) LEARN_JE_Quickprop},
-{"JE_Rprop",            LEARN_FUNC, 3, 1, (FunctionPtr) LEARN_JE_Rprop},
+{"JE_BP",               LEARN_FUNC, 3, 1, (FunctionPtr) LEARN_JE_Backprop},
+{"JE_BP_Momentum",      LEARN_FUNC, 5, 1, (FunctionPtr) LEARN_JE_BackpropMomentum},
+{"JE_Quickprop",        LEARN_FUNC, 5, 1, (FunctionPtr) LEARN_JE_Quickprop},
+{"JE_Rprop",            LEARN_FUNC, 4, 1, (FunctionPtr) LEARN_JE_Rprop},
 {"Kohonen",             LEARN_FUNC, 5, 1, (FunctionPtr) LEARN_kohonen},
 {"Monte-Carlo",         LEARN_FUNC, 4, 1, (FunctionPtr) LEARN_MonteCarlo},
 {"PruningFeedForward",  LEARN_FUNC, 5, 1, (FunctionPtr) NULL},
 {"QPTT",                LEARN_FUNC, 4, 1, (FunctionPtr) LEARN_QPTT},
 {"Quickprop",           LEARN_FUNC | FF_LEARN_FUNC, 4, 1, (FunctionPtr) LEARN_quickprop},
-{"RadialBasisLearning", LEARN_FUNC, 4, 1, (FunctionPtr) LEARN_RBF},
+{"RadialBasisLearning", LEARN_FUNC, 5, 1, (FunctionPtr) LEARN_RBF},
 {"RBF-DDA",             LEARN_FUNC, 3, 1, (FunctionPtr) LEARN_RBF_DDA},
-{"RCC",                 LEARN_FUNC, 5, 1, (FunctionPtr) LEARN_RecCasCor},
 {"RM_delta",            LEARN_FUNC, 2, 1, (FunctionPtr) LEARN_RM_delta},
 {"Rprop",               LEARN_FUNC | FF_LEARN_FUNC, 3, 1, (FunctionPtr) LEARN_rprop},
+{"RpropMAP",            LEARN_FUNC | FF_LEARN_FUNC, 5, 1, (FunctionPtr) LEARN_RpropMAP},
+{"SCG",                 LEARN_FUNC | FF_LEARN_FUNC, 4, 2, (FunctionPtr) LEARN_SCG},
 {"Sim_Ann_SS", LEARN_FUNC, 4, 1, (FunctionPtr) LEARN_SimulatedAnnealingSS},
 {"Sim_Ann_WTA", LEARN_FUNC, 4, 1, (FunctionPtr) LEARN_SimulatedAnnealingWTA},
 {"Sim_Ann_WWTA", LEARN_FUNC, 4, 1, (FunctionPtr) LEARN_SimulatedAnnealingWWTA},
+{"TACOMA",              LEARN_FUNC, 5, 1, (FunctionPtr) LEARN_Tacoma},
 {"TimeDelayBackprop",   LEARN_FUNC, 2, 1, (FunctionPtr) LEARN_TDbackprop},
 
 /*  Testing Functions  */
@@ -315,6 +328,8 @@ struct FuncTable  kernel_func_table[]	=
 /* {"ART1",                TEST_FUNC, 1, 0, (FunctionPtr) TEST_ART1}, */
  {"BackpropBatch",       TEST_FUNC, 2, 1, (FunctionPtr) TEST_backprop},
 /* {"ART2",                TEST_FUNC, 5, 0, (FunctionPtr) TEST_ART2}, */
+{"BackpropChunk",       TEST_FUNC, 2, 1, (FunctionPtr) TEST_backprop},
+{"BackpropClassJogChunk",TEST_FUNC, 2, 1, (FunctionPtr) TEST_backprop},
 {"BackpropMomentum",    TEST_FUNC, 4, 1, (FunctionPtr) TEST_backpropMomentum},
 /* {"ARTMAP",              TEST_FUNC, 3, 0, (FunctionPtr) TEST_ARTMAP}, */
 {"BackpropWeightDecay", TEST_FUNC, 4, 1, (FunctionPtr) TEST_backpropMomentum},
@@ -326,22 +341,24 @@ struct FuncTable  kernel_func_table[]	=
 {"Quickprop",           TEST_FUNC, 4, 1, (FunctionPtr) TEST_backpropMomentum},
 /* {"Counterpropagation",  TEST_FUNC, 3, 1, (FunctionPtr) TEST_CPN},*/
 {"Rprop",               TEST_FUNC, 3, 1, (FunctionPtr) TEST_rprop},
+{"RpropMAP",          TEST_FUNC, 5, 1, (FunctionPtr) TEST_MAP},
 /* {"RadialBasislearning", TEST_FUNC, 4, 1, (FunctionPtr) TEST_RBF},
-{"Dynamic_LVQ",         TEST_FUNC, 5, 1, (FunctionPtr) TEST_DLVQ},
+{"Dynamic_LVQ",         TEST_FUNC, 5, 1, (FunctionPtr) TEST_DLVQ},*/
 {"BPTT",                TEST_FUNC, 3, 1, (FunctionPtr) TEST_BPTT},
 {"CC",                  TEST_FUNC, 5, 1, (FunctionPtr) TEST_CasCor},
-{"BBPTT",               TEST_FUNC, 3, 1, (FunctionPtr) TEST_BBPTT},
-{"RCC",                 TEST_FUNC, 5, 1, (FunctionPtr) TEST_RecCasCor},
-{"QPTT",                TEST_FUNC, 4, 1, (FunctionPtr) TEST_QPTT},
-{"Kohonen",             TEST_FUNC, 5, 1, (FunctionPtr) TEST_kohonen},*/
-{"JE_BP",               TEST_FUNC, 2, 1, (FunctionPtr) TEST_JE_Backprop},
-{"JE_BP_Momentum",      TEST_FUNC, 4, 1, (FunctionPtr) TEST_JE_BackpropMomentum},
-{"JE_Quickprop",        TEST_FUNC, 4, 1, (FunctionPtr) TEST_JE_BackpropMomentum},
-{"JE_Rprop",            TEST_FUNC, 3, 1, (FunctionPtr) TEST_JE_Rprop}, 
+{"TACOMA",              TEST_FUNC, 5, 1, (FunctionPtr) TEST_CasCor},
+{"BBPTT",               TEST_FUNC, 3, 1, (FunctionPtr) TEST_BPTT},
+{"QPTT",                TEST_FUNC, 4, 1, (FunctionPtr) TEST_BPTT},
+/*{"Kohonen",             TEST_FUNC, 5, 1, (FunctionPtr) TEST_kohonen},*/
+{"JE_BP",               TEST_FUNC, 3, 1, (FunctionPtr) TEST_JE_Backprop},
+{"JE_BP_Momentum",      TEST_FUNC, 5, 1, (FunctionPtr) TEST_JE_BackpropMomentum},
+{"JE_Quickprop",        TEST_FUNC, 5, 1, (FunctionPtr) TEST_JE_BackpropMomentum},
+{"JE_Rprop",            TEST_FUNC, 4, 1, (FunctionPtr) TEST_JE_Rprop}, 
 {"Monte-Carlo",         TEST_FUNC, 4, 1, (FunctionPtr) TEST_MonteCarlo}, 
-{"Simulated_Annealing_SS_error", TEST_FUNC, 4, 1, (FunctionPtr) TEST_SimulatedAnnealingSS},
-{"Simulated_Annealing_WTA_error", TEST_FUNC, 4, 1, (FunctionPtr) TEST_SimulatedAnnealingWTA},
-{"Simulated_Annealing_WWTA_error", TEST_FUNC, 4, 1, (FunctionPtr) TEST_SimulatedAnnealingWWTA},
+{"SCG",                 TEST_FUNC, 4, 1, (FunctionPtr) TEST_SCG},
+{"Sim_Ann_SS", TEST_FUNC, 4, 1, (FunctionPtr) TEST_SimulatedAnnealingSS},
+{"Sim_Ann_WTA", TEST_FUNC, 4, 1, (FunctionPtr) TEST_SimulatedAnnealingWTA},
+{"Sim_Ann_WWTA", TEST_FUNC, 4, 1, (FunctionPtr) TEST_SimulatedAnnealingWWTA},
 
 /*  Initialisation Functions  */
 /*  This is the DEFAULT FUNCTION  */
@@ -365,10 +382,10 @@ struct FuncTable  kernel_func_table[]	=
 {"PseudoInv",           INIT_FUNC, 0, 0, (FunctionPtr) INIT_PseudoInv},
 {"Random_Weights_Perc", INIT_FUNC, 2, 0, (FunctionPtr) INIT_randomizeWeights_perc},
 {"RBF_Weights",         INIT_FUNC, 5, 0, (FunctionPtr) INIT_RBF_Weights},
-{"RBF_Weights_Kohonen", INIT_FUNC, 4, 0, (FunctionPtr) INIT_RBF_Weights_kohonen},
-{"RBF_Weights_Redo",    INIT_FUNC, 5, 0, (FunctionPtr) INIT_RBF_Weights_redo},
-{"RCC_Weights",         INIT_FUNC, 2, 0, (FunctionPtr) INIT_RCC_Weights},
+{"RBF_Weights_Kohonen", INIT_FUNC, 3, 0, (FunctionPtr) INIT_RBF_Weights_kohonen},
+{"RBF_Weights_Redo",    INIT_FUNC, 3, 0, (FunctionPtr) INIT_RBF_Weights_redo},
 {"RM_Random_Weights",   INIT_FUNC, 2, 0, (FunctionPtr) INIT_RM_randomizeWeights},
+{"ENZO_noinit",         INIT_FUNC,  0, 0, (FunctionPtr) ENZO_noinit},
 
 /* Pruning Functions */
 /*  This is the DEFAULT FUNCTION  */
@@ -377,8 +394,17 @@ struct FuncTable  kernel_func_table[]	=
 {"OptimalBrainDamage", PRUNING_FUNC, 1, 1, (FunctionPtr) PRUNE_OBD},
 {"OptimalBrainSurgeon", PRUNING_FUNC, 1, 1, (FunctionPtr) PRUNE_OBS},
 {"Skeletonization", PRUNING_FUNC, 1, 1, (FunctionPtr) PRUNE_Skeletonization},
-{"Noncontributing_Units", PRUNING_FUNC, 1, 1, (FunctionPtr) PRUNE_Noncontributing}
+{"Noncontributing_Units", PRUNING_FUNC, 1, 1, (FunctionPtr) PRUNE_Noncontributing},
 
+/* Remap Functions */
+/*  This is the DEFAULT FUNCTION  */
+{"None", REMAP_FUNC | DEFAULT_FUNC, 0, 0, (FunctionPtr) REMAP_none},
+{"Binary", REMAP_FUNC, 0, 0, (FunctionPtr) REMAP_binary},
+{"Inverse", REMAP_FUNC, 0, 0, (FunctionPtr) REMAP_invers},
+{"Clip", REMAP_FUNC, 2, 0, (FunctionPtr) REMAP_clip},
+{"LinearScale", REMAP_FUNC, 2, 0, (FunctionPtr) REMAP_linearscale},
+{"Norm", REMAP_FUNC, 0, 0, (FunctionPtr) REMAP_norm},
+{"Threshold", REMAP_FUNC, 4, 0, (FunctionPtr) REMAP_threshold}
   };
 
 
@@ -389,13 +415,3 @@ const int  NoOfKernelFuncs = (sizeof (kernel_func_table) / sizeof (struct FuncTa
 
 
 
-
-
-
-
-
-
-
-
-
-
