@@ -1,7 +1,7 @@
 /*****************************************************************************
-  FILE           : $Source: /usr/local/bv/SNNS/SNNSv4.1/kernel/sources/RCS/kr_art1.c,v $
+  FILE           : $Source: /projects/higgs1/SNNS/CVS/SNNS/kernel/sources/kr_art1.c,v $
   SHORTNAME      : 
-  SNNS VERSION   : 4.1
+  SNNS VERSION   : 4.2
 
   PURPOSE        : SNNS Kernel Functions for ART1 networks
   NOTES          :
@@ -10,13 +10,14 @@
   DATE           : 17.05.92
 
   CHANGED BY     : Sven Doering
-  IDENTIFICATION : $State: Exp $ $Locker:  $
-  RCS VERSION    : $Revision: 2.4 $
-  LAST CHANGE    : $Date: 1995/11/16 12:03:22 $
+  RCS VERSION    : $Revision: 2.8 $
+  LAST CHANGE    : $Date: 1998/03/03 14:08:35 $
 
-             Copyright (c) 1990-1995  SNNS Group, IPVR, Univ. Stuttgart, FRG
+    Copyright (c) 1990-1995  SNNS Group, IPVR, Univ. Stuttgart, FRG
+    Copyright (c) 1996-1998  SNNS Group, WSI, Univ. Tuebingen, FRG
 
 ******************************************************************************/
+#include <config.h>
 
 #include <stdlib.h>
 
@@ -25,6 +26,7 @@
 #include <stdio.h>
 #endif
 
+#include <string.h>
 
 #include "kr_const.h"
 #include "kr_mac.h"
