@@ -1,7 +1,7 @@
 /*****************************************************************************
-  FILE           : $Source: /usr/local/bv/SNNS/SNNSv4.0/kernel/sources/RCS/kr_io.c,v $
+  FILE           : $Source: /projects/higgs1/SNNS/CVS/SNNS/kernel/sources/kr_io.c,v $
   SHORTNAME      : kr_io.c
-  SNNS VERSION   : 4.0
+  SNNS VERSION   : 4.2
  
   PURPOSE        : SNNS-Kernel User Interface File I/O
   NOTES          :
@@ -10,13 +10,14 @@
   DATE           : 28.05.90
  
   CHANGED BY     : Michael Vogt, Guenter Mamier
-  IDENTIFICATION : $State: Exp $ $Locker:  $
-  RCS VERSION    : $Revision: 2.9 $
-  LAST CHANGE    : $Date: 1995/03/14 13:59:03 $
+  RCS VERSION    : $Revision: 2.18 $
+  LAST CHANGE    : $Date: 1998/03/03 14:08:39 $
  
-             Copyright (c) 1990-1995  SNNS Group, IPVR, Univ. Stuttgart, FRG
+    Copyright (c) 1990-1995  SNNS Group, IPVR, Univ. Stuttgart, FRG
+    Copyright (c) 1996-1998  SNNS Group, WSI, Univ. Tuebingen, FRG
  
 ******************************************************************************/
+#include <config.h>
 #include <stdlib.h>
 #include <time.h>
 #include <string.h>
@@ -36,6 +37,9 @@
 #include "dlvq_learn.h"
 #include "kr_io.ph"	 /*  Function Prototypes */
 #include "kr_newpattern.h" /*pattern handling functions */
+#include "cc_glob.h"      /* for NetLearnAlgorithm to decide, if we must
+                            save in TACOMA-mode */
+#include "cc_mac.h"
 
 #ifdef ultrix
 #define retchk( ret_code )  if ((ret_code) == EOF)  return( KRERR_IO )
@@ -688,7 +692,7 @@ static krui_err  krio_fmtShapeing(int choose_me)
     case  CONNECT_DEF:
         sprintf( aux, "%d", unit_no_len );
 	mstrcpy( fmt_shape3, " %", aux, "d:%8.5f", (char *) 0 );
-
+        mstrcpy( fmt_shape4, " %", aux, "d:%8.5f (%8.5f,%8.5f) ", (char *) 0 );
         len = Max( unit_no_len, strlen( formats[ 9 ] ) );
         len1 = len + 2;
 	if (len1 > MAX_LIN_LEN)  return( KRERR_SAVE_LINE_LEN );
@@ -1193,13 +1197,16 @@ static krui_err  krio_writeSourcesAndWeights(void)
 {
   bool  second;
   int   i, err,
-        source_unit;
+        source_unit,
+        tacoma_mode;
 
   FlintType     weight;
+  float val_a,val_b,val_c;
+  
 
-
-  i = 0;
-  source_unit = krui_getFirstPredUnit( &weight );
+  tacoma_mode = (!strcmp(krui_getUnitActFuncName(GET_UNIT_NO(unitPtr)),"Act_TACOMA"));
+   i = 0;
+  source_unit = krui_getFirstPredUnitAndData( &weight, &val_a, &val_b, &val_c );
   second = FALSE;
 
   do  {
@@ -1213,13 +1220,15 @@ static krui_err  krio_writeSourcesAndWeights(void)
       err = fprintf( file_out, fmt_blank );
       retchk( err );
     }
-
-    err = fprintf( file_out, fmt_shape3, source_unit, weight );
+    if ((tacoma_mode)&&((val_a != 0.0)&&(val_b != 0.0)))
+      err = fprintf( file_out, fmt_shape4, source_unit, weight, val_b, val_a);
+    else
+      err = fprintf( file_out, fmt_shape3, source_unit, weight );
     retchk( err );
 
     second = TRUE;
   }
-  while ( (source_unit = krui_getNextPredUnit( &weight )) > 0);
+  while ( (source_unit = krui_getNextPredUnitAndData( &weight, &val_a, &val_b, &val_c )) > 0);
 
   err = fprintf( file_out, "\n" );
   retchk( err );
@@ -1243,6 +1252,7 @@ static krui_err  krio_writeConnectionDefs(void)
   int   target_unit, unit_no,
         err;
 
+
   FlintType  weight;
 
 
@@ -2572,6 +2582,9 @@ static void  krio_readConnectionDefs(void)
   FlintType  weight;
   int   unit_no, src_unit_no;
   bool  new_unit, unit_has_sites;
+  float tacoma_xi,tacoma_ri;
+  int fscanRet;
+  struct Link* LinkDummy;
 
 
   if ( !skipComments() )  return;
@@ -2626,13 +2639,17 @@ static void  krio_readConnectionDefs(void)
 
     while (TRUE)  {
       /*  read link weights  */
-      if (fscanf( file_in, "%d : %f", &src_unit_no, &weight ) != 2)  {
+      fscanRet = fscanf( file_in, "%d:%f (%f,%f) ", &src_unit_no, &weight, 
+                 &tacoma_xi, &tacoma_ri );
+      if (fscanRet==2) 
+         tacoma_xi=tacoma_ri=0.0;
+      if ((fscanRet!=2)&&(fscanRet!=4)){
         KernelErrorCode = KRERR_FILE_SYNTAX;
         return;
       }
-
-      if (krui_createLink( src_unit_no, weight ) != KRERR_NO_ERROR)  return;
-
+      LinkDummy=krui_createLinkWithAdditionalParameters
+                      ( src_unit_no, weight,tacoma_ri,tacoma_xi,0.0);
+      if (KernelErrorCode!=KRERR_NO_ERROR) return;
       if ( !comma() )  break;
     }
 
@@ -2762,7 +2779,7 @@ static void  krio_readLayerDefs(void)
 ******************************************************************************/
 static void  readXYTransTable(void)
 {
-  int x, y, z;
+  int x, y, z, c;
 
 
   kr_xyTransTable( OP_TRANSTABLE_CLEAR, &x, &y, 0 );
@@ -2782,7 +2799,12 @@ static void  readXYTransTable(void)
       KernelErrorCode = KRERR_FILE_SYNTAX;
       return;
     }
-    (void) skipSpace();
+
+    /* skip remaining spaces */
+    do{
+	c = getc( file_in );
+	if (c == '\n')  lineno++;
+    }while(c == ' ');
 
     kr_xyTransTable( OP_TRANSTABLE_SET, &x, &y, z );
   }
