@@ -1,7 +1,7 @@
 /*****************************************************************************
-  FILE           : $Source: /usr/local/bv/SNNS/SNNSv4.0/kernel/sources/RCS/kr_mem.c,v $
+  FILE           : $Source: /projects/higgs1/SNNS/CVS/SNNS/kernel/sources/kr_mem.c,v $
   SHORTNAME      : 
-  SNNS VERSION   : 4.0
+  SNNS VERSION   : 4.2
  
   PURPOSE        : SNNS-Kernel Memory Manager 
   NOTES          :
@@ -10,19 +10,24 @@
   DATE           : 21.2.90
  
   CHANGED BY     : Sven Doering
-  IDENTIFICATION : $State: Exp $ $Locker:  $
-  RCS VERSION    : $Revision: 2.6 $
-  LAST CHANGE    : $Date: 1995/03/14 13:59:08 $
+  RCS VERSION    : $Revision: 2.17 $
+  LAST CHANGE    : $Date: 1998/05/15 13:12:08 $
  
-             Copyright (c) 1990-1995  SNNS Group, IPVR, Univ. Stuttgart, FRG
+    Copyright (c) 1990-1995  SNNS Group, IPVR, Univ. Stuttgart, FRG
+    Copyright (c) 1996-1998  SNNS Group, WSI, Univ. Tuebingen, FRG
  
 ******************************************************************************/
+#include <config.h>
 #include <stdio.h>
 #include <stdlib.h>
 #include <string.h>
 #include <memory.h>
+#ifdef HAVE_VALUES_H
 #include <values.h>
-
+#else
+#include <math.h>
+#endif
+#include <limits.h>
 
 #include "kr_typ.h"	 /*  Kernel Types and Constants  */
 #include "kernel.h"
@@ -32,6 +37,11 @@
 #include "kr_mem.ph"	 /*  Function prototypes  */
 #include "kr_mac.h"	 /*  Kernel Macros  */
 
+
+#ifndef MAXSHORT
+#define MAXSHORT SHRT_MAX
+#endif
+
 /*  ULTRIX-32 Operating System	*/
 #if defined (ultrix) || defined (__BORLANDC__) 
 #include "strdup.h"	/*  include strdup function because strdup is
@@ -39,8 +49,6 @@
 #endif
 
 
-
-
 /*****************************************************************************
   FUNCTION : krm_allocLinks
 
@@ -604,20 +612,25 @@ krui_err  krm_allocUnits(int N)
   PURPOSE  : get one unit structure
   NOTES    :
 
-  RETURNS  :
+  RETURNS  : the number of the current unit structure. This number is negative 
+             if a new block had to be allocated, to signal the calling program 
+             that it has to update its unit pointers.
   UPDATE   : 
 ******************************************************************************/
 int  krm_getUnit(void)
 {
   register int   unit_no;
+  int ret_fact = 1;
 
   KernelErrorCode = KRERR_NO_ERROR;
-  if ((unit_array == NULL) || (NoOfUnits == NoOfAllocUnits))
+  if ((unit_array == NULL) || (NoOfUnits == NoOfAllocUnits)){
     if (krm_allocUnits( UNIT_BLOCK ) != 0)
       {  /*  Insufficient memory  */
       KernelErrorCode = KRERR_INSUFFICIENT_MEM;
       return( 0 );
     }
+    ret_fact = -1;
+  }
   NoOfUnits++;
 
   if (FreeUnitIndex != 0)
@@ -641,7 +654,7 @@ int  krm_getUnit(void)
     if (unit_no < MinUnitNo)  MinUnitNo = unit_no;
   }
 
-  return( unit_no );
+  return( unit_no * ret_fact);
 }
 
 
@@ -1527,7 +1540,7 @@ void    krm_releaseFtypeEntry(struct FtypeUnitStruct *Ftype_entry)
   RETURNS  : the ftype
   UPDATE   : 
 ******************************************************************************/
-struct FtypeUnitStruct  *krm_FtypeCreateEntry(char *Ftype_symbol, OutFuncPtr out_func, ActFuncPtr act_func, ActDerivFuncPtr act_deriv_func, ActDerivFuncPtr act_2_deriv_func)
+struct FtypeUnitStruct  *krm_FtypeCreateEntry(char *Ftype_symbol, OutFuncPtr out_func, ActFuncPtr act_func, ActDerivFuncPtr act_deriv_func, ActDerivFuncPtr act_2_deriv_func, PyObject *python_out_func,PyObject *python_act_func,PyObject *python_act_deriv_func,   PyObject *python_act_2_deriv_func)
 {
   struct  FtypeUnitStruct   *Ftype_entry;
   struct  NameTable         *n_ptr;
@@ -1546,6 +1559,10 @@ struct FtypeUnitStruct  *krm_FtypeCreateEntry(char *Ftype_symbol, OutFuncPtr out
   Ftype_entry->act_func = act_func;
   Ftype_entry->act_deriv_func = act_deriv_func;
   Ftype_entry->act_2_deriv_func = act_2_deriv_func;
+  Ftype_entry->python_out_func = python_out_func;
+  Ftype_entry->python_act_func = python_act_func;
+  Ftype_entry->python_act_deriv_func = python_act_deriv_func;
+  Ftype_entry->python_act_2_deriv_func = python_act_2_deriv_func;
   Ftype_entry->sites = NULL;
 
   return( Ftype_entry );
@@ -1817,3 +1834,272 @@ void    krm_releaseMem(void)
 
 
 /*  ---------------------  End of Memory Management Functions  -------------  */
+
+/*  ---------------------    Begin Enzo Interface Functions   -------------  */
+#ifdef __ENZO__
+/*****************************************************************************
+  FUNCTION : krm_getNet
+
+  PURPOSE  : Receiving a network from the Enzo network manager modul
+  RETURNS  : 
+  NOTES    :
+
+  UPDATE   : 
+******************************************************************************/
+void krm_getNet( memNet *n )
+{                              /* the patterns stay untouched! */
+    char *afunc, *ofunc;
+    
+    strcpy(n->update_func, krui_getUpdateFunc());
+    strcpy(n->learn_func,  krui_getLearnFunc());
+    strcpy(n->init_func,   krui_getInitialisationFunc());
+    
+    kr_getUnitDefaults( &n->u_act, &n->u_bias, &n->u_ttflags,
+		        &n->u_subnet_no, &n->u_layer_no,
+			&afunc, &ofunc                         );
+
+    strcpy( n->u_act_func, afunc );
+    strcpy( n->u_out_func, ofunc );
+
+    n->NoOfLinks   = NoOfLinks;
+    n->NoOfAllocLinks  = NoOfAllocLinks;
+    n->link_array  = link_array;
+    n->link_block_list   = link_block_list;
+    n->free_link_ptr   = free_link_ptr;
+    
+    n->NoOfSites   = NoOfSites;
+    n->NoOfNetSites  = NoOfNetSites;
+    n->NoOfAllocSites  = NoOfAllocSites;
+    n->site_array  = site_array;
+    n->site_block_list   = site_block_list;
+    n->free_site_ptr   = free_site_ptr;
+    n->site_array  = site_array;
+
+
+    n->NoOfAllocUnits  = NoOfAllocUnits;
+    n->FreeUnitIndex   = FreeUnitIndex;
+    n->NoOfUnits   = NoOfUnits;
+    n->NoOfInputUnits  = NoOfInputUnits;
+    n->NoOfOutputUnits   = NoOfOutputUnits;
+    n->NoOfHiddenUnits   = NoOfHiddenUnits;
+    n->MaxUnitNo   = MaxUnitNo;
+    n->MinUnitNo   = MinUnitNo;
+    n->unit_array  = unit_array;
+
+    n->topo_ptr_array  = topo_ptr_array;
+    
+    n->NoOfNTableEntries   = NoOfNTableEntries;
+    n->NoOfAllocNTableEntries  = NoOfAllocNTableEntries;
+    n->NTable_array  = NTable_array;
+    n->NTable_block_list   = NTable_block_list;
+    n->free_NTable_entry   = free_NTable_entry;
+    n->NTable_array  = NTable_array;
+    
+    n->NoOfSTableEntries   = NoOfSTableEntries;
+    n->NoOfAllocSTableEntries  = NoOfAllocSTableEntries;
+    n->STable_array  = STable_array;
+    n->STable_block_list   = STable_block_list;
+    n->free_STable_entry   = free_STable_entry;
+    n->STable_array  = STable_array;
+    
+    n->Ftype_list_root   = Ftype_list_root;
+    n->NoOfFTableEntries   = NoOfFTableEntries;
+
+
+
+    n->curr_Ftype_entry = curr_Ftype_entry;
+    n->curr_STable_entry = curr_STable_entry;
+    n->curr_STable_block = curr_STable_block;
+    n->curr_NTable_entry = curr_NTable_entry;
+    n->curr_NTable_block = curr_NTable_block;
+    n->NetModified =  NetModified;
+    n->NetInitialize = NetInitialize;
+    n->LearnFuncHasChanged = LearnFuncHasChanged;
+    n->unitPtr =  unitPtr;
+    n->sitePtr = sitePtr;
+    n->prevSitePtr = prevSitePtr;
+    n->linkPtr = linkPtr;
+    n->prevLinkPtr = prevLinkPtr;
+    n->unitNo = unitNo;
+    n->specialNetworkType = specialNetworkType;
+    n->TopoSortID = TopoSortID;
+    n->no_of_topo_units = no_of_topo_units;
+    
+    /* treat this just as the net would have been deleted */
+
+    NoOfLinks   = 0;
+    NoOfAllocLinks  = 0;
+    link_array  = NULL;
+    link_block_list   = NULL;
+    free_link_ptr   = NULL;
+    
+    NoOfSites   = 0;
+    NoOfNetSites  = 0;
+    NoOfAllocSites  = 0;
+    site_array  = NULL;
+    site_block_list   = NULL;
+    free_site_ptr   = NULL;
+    
+    NoOfAllocUnits  = 0;
+    FreeUnitIndex   = 0;
+    NoOfUnits   = 0;
+    NoOfInputUnits  = 0;
+    NoOfOutputUnits   = 0;
+    NoOfHiddenUnits   = 0;
+    MaxUnitNo   = 0;
+    unit_array  = NULL;
+
+    topo_ptr_array  = NULL; 
+    
+    NoOfNTableEntries   = 0;
+    NoOfAllocNTableEntries  = 0;
+    NTable_array  = NULL;
+    NTable_block_list   = NULL;
+    free_NTable_entry   = NULL;
+    NTable_array  = NULL;
+    
+    NoOfSTableEntries   = 0;
+    NoOfAllocSTableEntries  = 0;
+    STable_array  = NULL;
+    STable_block_list   = NULL;
+    free_STable_entry   = NULL;
+    
+    Ftype_list_root   = NULL;
+    NoOfFTableEntries   = 0;
+}
+
+
+
+/*****************************************************************************
+  FUNCTION : krm_putNet
+
+  PURPOSE  : Putting a network back under the control of the Enzo network 
+             manager modul
+  RETURNS  : 
+  NOTES    :
+
+  UPDATE   : 
+******************************************************************************/
+void krm_putNet( memNet *n )
+{
+    
+    krm_releaseFtypeList();
+    krm_releaseSTableArrays();
+    krm_releaseNTableArrays();
+    krm_releaseLinkArrays();
+    krm_releaseSiteArrays();
+    krm_releaseUnitArrays();
+
+    
+    krui_setUpdateFunc( n->update_func );
+    krui_setLearnFunc( n->learn_func );
+    krui_setInitialisationFunc( n->init_func );
+
+    kr_setUnitDefaults( n->u_act, n->u_bias, n->u_ttflags,
+		        n->u_subnet_no, n->u_layer_no,
+		        n->u_act_func, n->u_out_func       );
+
+    NoOfLinks   = n->NoOfLinks;
+    NoOfAllocLinks  = n->NoOfAllocLinks;
+    link_array  = n->link_array;
+    link_block_list   = n->link_block_list;
+    free_link_ptr   = n->free_link_ptr;
+    
+    NoOfSites   = n->NoOfSites;
+    NoOfNetSites  = n->NoOfNetSites;
+    NoOfAllocSites  = n->NoOfAllocSites;
+    site_array  = n->site_array;
+    site_block_list   = n->site_block_list;
+    free_site_ptr   = n->free_site_ptr;
+    site_array  = n->site_array;
+
+    NoOfAllocUnits  = n->NoOfAllocUnits;
+    FreeUnitIndex   = n->FreeUnitIndex;
+    NoOfUnits   = n->NoOfUnits;
+    NoOfInputUnits  = n->NoOfInputUnits;
+    NoOfOutputUnits   = n->NoOfOutputUnits;
+    NoOfHiddenUnits   = n->NoOfHiddenUnits;
+    MinUnitNo   = n->MinUnitNo;
+    MaxUnitNo   = n->MaxUnitNo;
+    unit_array  = n->unit_array;
+    
+    topo_ptr_array  = n->topo_ptr_array;
+    
+    NoOfNTableEntries   = n->NoOfNTableEntries;
+    NoOfAllocNTableEntries  = n->NoOfAllocNTableEntries;
+    NTable_array  = n->NTable_array;
+    NTable_block_list   = n->NTable_block_list;
+    free_NTable_entry   = n->free_NTable_entry;
+    NTable_array  = n->NTable_array;
+    
+    NoOfSTableEntries   = n->NoOfSTableEntries;
+    NoOfAllocSTableEntries  = n->NoOfAllocSTableEntries;
+    STable_array  = n->STable_array;
+    STable_block_list   = n->STable_block_list;
+    free_STable_entry   = n->free_STable_entry;
+    STable_array  = n->STable_array;
+    
+    Ftype_list_root   = n->Ftype_list_root;
+    NoOfFTableEntries   = n->NoOfFTableEntries;
+
+    curr_Ftype_entry = n->curr_Ftype_entry;
+    curr_STable_entry = n->curr_STable_entry;
+    curr_STable_block = n->curr_STable_block;
+    curr_NTable_entry = n->curr_NTable_entry;
+    curr_NTable_block = n->curr_NTable_block;
+    NetModified =  n->NetModified;
+    NetInitialize = n->NetInitialize;
+    LearnFuncHasChanged = n->LearnFuncHasChanged;
+    unitPtr =  n->unitPtr;
+    sitePtr = n->sitePtr;
+    prevSitePtr = n->prevSitePtr;
+    linkPtr = n->linkPtr;
+    prevLinkPtr = n->prevLinkPtr;
+    unitNo = n->unitNo;
+    specialNetworkType = n->specialNetworkType;
+    TopoSortID = n->TopoSortID;
+    no_of_topo_units = n->no_of_topo_units;
+}
+
+
+
+/*****************************************************************************
+  FUNCTION : krm_getPattern
+
+  PURPOSE  : Receiving a pattern set from the Enzo  manager modul
+
+  RETURNS  : 
+  NOTES    : This is just a dummy function
+
+  UPDATE   : 
+******************************************************************************/
+void krm_getPattern( memPat *p )
+{
+
+}
+
+
+
+/*****************************************************************************
+  FUNCTION : krm_putPattern
+
+  PURPOSE  : Receiving a pattern set back under the control of the Enzo 
+             manager modul
+  RETURNS  : 
+  NOTES    :
+
+  UPDATE   : 
+******************************************************************************/
+void krm_putPattern( memPat *p )
+{
+    static int in[MAX_NO_OF_VAR_I_DIM],out[MAX_NO_OF_VAR_I_DIM];
+
+    krui_setCurrPatSet( p->number );
+    in[0] = 1; /*krui_getNoOfInputUnits();*/
+    in[1] = 1;
+    out[0] = 1; /*krui_getNoOfOutputUnits();*/
+    out[1] = 1;
+    krui_DefTrainSubPat(in, out, in, out,NULL);
+}
+
+#endif
