@@ -1,7 +1,7 @@
 /*****************************************************************************
-  FILE           : $Source: /usr/local/bv/SNNS/SNNSv4.0/kernel/sources/RCS/kr_pat_parse.h,v $
+  FILE           : $Source: /projects/higgs1/SNNS/CVS/SNNS/kernel/sources/kr_pat_parse.h,v $
   SHORTNAME      : pat_parse
-  SNNS VERSION   : 4.0
+  SNNS VERSION   : 4.2
 
   PURPOSE        : parser for new pattern format; bison format 
   NOTES          : impossible to use with yacc
@@ -10,11 +10,11 @@
   DATE           : 10.9.93
 
   CHANGED BY     : 
-  IDENTIFICATION : $State: Exp $ $Locker:  $
-  RCS VERSION    : $Revision: 2.3 $
-  LAST CHANGE    : $Date: 1995/03/14 14:03:51 $
+  RCS VERSION    : $Revision: 2.7 $
+  LAST CHANGE    : $Date: 1998/02/25 15:26:59 $
 
-             Copyright (c) 1990-1995  SNNS Group, IPVR, Univ. Stuttgart, FRG
+    Copyright (c) 1990-1995  SNNS Group, IPVR, Univ. Stuttgart, FRG
+    Copyright (c) 1996-1998  SNNS Group, WSI, Univ. Tuebingen, FRG
 
 ******************************************************************************/
 
@@ -23,10 +23,10 @@
 
 /* begin global definition section */
 
-#define CURRENT_VERSION_V       3  /* current version of pattern file        */
+#define CURRENT_VERSION_V       4  /* current version of pattern file        */
 #define CURRENT_VERSION_R       2  /* format                                 */
 
-extern int parse_pattern_file(int *set);
+extern int parse_pattern_file(int *set, np_pattern_set_info *this_set);
 
 
 /* end global definition section */
