@@ -1,7 +1,7 @@
 /*****************************************************************************
-  FILE           : $Source: /usr/local/bv/SNNS/SNNSv4.1/kernel/sources/RCS/kr_td.c,v $
+  FILE           : $Source: /projects/higgs1/SNNS/CVS/SNNS/kernel/sources/kr_td.c,v $
   SHORTNAME      : 
-  SNNS VERSION   : 4.1
+  SNNS VERSION   : 4.2
 
   PURPOSE        : SNNS-Kernel Learning Functions for Time Delay networks
   NOTES          : with following learning functions:
@@ -11,17 +11,20 @@
   DATE           : 
 
   CHANGED BY     : Michael Vogt, Guenter Mamier
-  IDENTIFICATION : $State: Exp $ $Locker:  $
-  RCS VERSION    : $Revision: 2.7 $
-  LAST CHANGE    : $Date: 1995/11/16 12:04:40 $
+  RCS VERSION    : $Revision: 2.12 $
+  LAST CHANGE    : $Date: 1998/03/13 16:23:57 $
 
-             Copyright (c) 1990-1995  SNNS Group, IPVR, Univ. Stuttgart, FRG
+    Copyright (c) 1990-1995  SNNS Group, IPVR, Univ. Stuttgart, FRG
+    Copyright (c) 1996-1998  SNNS Group, WSI, Univ. Tuebingen, FRG
 
 ******************************************************************************/
+#include <config.h>
 
 #include <stdio.h>
 #include <math.h>
+#ifdef HAVE_VALUES_H
 #include <values.h>
+#endif
 
 
 #include "kr_typ.h"	 /*  Kernel Types and Constants  */
@@ -90,6 +93,8 @@ static krui_err initializeTDBackprop(void)
   RETURNS  :
   UPDATE   : 19.02.1993
 ******************************************************************************/
+extern FlintType OUT_Custom_Python(FlintType act);
+
 void  propagateTDNetForward(int pattern_no, int sub_pat_no)
 { 
   register struct Unit    *unit_ptr;
@@ -116,6 +121,10 @@ void  propagateTDNetForward(int pattern_no, int sub_pat_no)
 	  if (unit_ptr->out_func == OUT_IDENTITY){
 	      /*  identity output function: don't call the output function  */
 	      unit_ptr->Out.output = unit_ptr->act = *in_pat++;
+	  }else if(unit_ptr->out_func == OUT_Custom_Python){
+	  	unit_ptr->Out.output =
+			kr_PythonOutFunction(unit_ptr->python_out_func,
+				unit_ptr->act = *in_pat++);
 	  }else{
 	      /*  no identity output function: calculate unit's output also  */
 	      unit_ptr->Out.output = 
@@ -157,6 +166,10 @@ void  propagateTDNetForward(int pattern_no, int sub_pat_no)
 	  if (unit_ptr->out_func == OUT_IDENTITY){
 	      /*  identity output function: don't call the output function  */
 	      unit_ptr->Out.output = unit_ptr->act;
+	  }else if(unit_ptr->out_func == OUT_Custom_Python){
+	  	unit_ptr->Out.output =
+			kr_PythonOutFunction(unit_ptr->python_out_func,
+				unit_ptr->act);
 	  }else{
 	      /*  no identity output function: calculate unit's output also  */
 	      unit_ptr->Out.output = (*unit_ptr->out_func) (unit_ptr->act);
@@ -761,7 +774,6 @@ krui_err  TEST_TDbackprop( int start_pattern, int end_pattern,
 {
     static  float  OutParameter[1]; /* OutParameter[0] stores learning error */
     int     ret_code, pattern_no, sub_pat_no;
-    struct Unit *unit_ptr;
 
     if (NoOfInParams < 1)	/*  #  has to be changed (must be 2) # */
 	return( KRERR_PARAMETERS ); /*  Not enough input parameters  */
@@ -815,14 +827,11 @@ static	float testTDNetBackward(int pattern_no, int sub_pat_no,
 				     float learn_parameter, 
 				     float delta_max)
 { 
-    register struct Link   *link_ptr;
-    register struct Site   *site_ptr;
-    register struct Unit   *unit_ptr, *unit_ptr1 ;
-    register struct Unit   *ref_unit;
+    register struct Unit   *unit_ptr;
     register Patterns      out_pat;
-    register float         error,  sum_error,  eta,  devit, learn_error;
+    register float         sum_error,  eta,  devit;
     register TopoPtrArray  topo_ptr;
-    int                    last_log_layer, i;
+    int                    last_log_layer;
     int                    size;
 
     sum_error = 0.0;		/*  reset network error  */
