@@ -1,7 +1,7 @@
 /*****************************************************************************
-  FILE           : $Source: /usr/local/bv/SNNS/SNNSv4.0/kernel/sources/RCS/krui_typ.h,v $
+  FILE           : $Source: /projects/higgs1/SNNS/CVS/SNNS/kernel/sources/krui_typ.h,v $
   SHORTNAME      : 
-  SNNS VERSION   : 4.0
+  SNNS VERSION   : 4.2
  
   PURPOSE        : SNNS-Kernel User Interface Function Prototypes
   NOTES          : ANSI-C only
@@ -10,11 +10,11 @@
   DATE           : 27.02.90
  
   CHANGED BY     : Sven Doering
-  IDENTIFICATION : $State: Exp $ $Locker:  $
-  RCS VERSION    : $Revision: 2.6 $
-  LAST CHANGE    : $Date: 1995/04/26 11:53:37 $
+  RCS VERSION    : $Revision: 2.9 $
+  LAST CHANGE    : $Date: 1998/02/25 15:27:20 $
  
-             Copyright (c) 1990-1995  SNNS Group, IPVR, Univ. Stuttgart, FRG
+    Copyright (c) 1990-1995  SNNS Group, IPVR, Univ. Stuttgart, FRG
+    Copyright (c) 1996-1998  SNNS Group, WSI, Univ. Tuebingen, FRG
  
 ******************************************************************************/
 
