@@ -1,7 +1,7 @@
 /*****************************************************************************
-  FILE           : $Source: /usr/local/bv/SNNS/SNNSv4.0/kernel/sources/RCS/prun_f.c,v $
+  FILE           : $Source: /projects/higgs1/SNNS/CVS/SNNS/kernel/sources/prun_f.c,v $
   SHORTNAME      : prun_f.c
-  SNNS VERSION   : 4.0
+  SNNS VERSION   : 4.2
 
   PURPOSE        : learning functions with pruning algorithms
   NOTES          :
@@ -10,17 +10,22 @@
   DATE           : 13.3.94
 
   CHANGED BY     : Jochen Biedermann, 07.07.94
-  IDENTIFICATION : $State: Exp $ $Locker:  $ 
-  RCS VERSION    : $Revision: 2.5 $
-  LAST CHANGE    : $Date: 1995/03/14 14:00:40 $
+                   Thomas Gern, 07.09.95
+  RCS VERSION    : $Revision: 2.15 $
+  LAST CHANGE    : $Date: 1998/03/13 16:24:01 $
 
-             Copyright (c) 1990-1995  SNNS Group, IPVR, Univ. Stuttgart, FRG
+    Copyright (c) 1990-1995  SNNS Group, IPVR, Univ. Stuttgart, FRG
+    Copyright (c) 1996-1998  SNNS Group, WSI, Univ. Tuebingen, FRG
 
 ******************************************************************************/
+#include <config.h>
 
 #include <stdio.h>
+#include <string.h>
 #include <math.h>
+#ifdef HAVE_VALUES_H
 #include <values.h>
+#endif
 
 #include "kr_typ.h"		/* Kernel Types and Constants  */
 #include "kr_const.h"		/* Constant Declarators for SNNS-Kernel  */
@@ -31,6 +36,7 @@
 #include "kr_funcs.h"
 #include "kr_newpattern.h"
 #include "matrix.h"
+#include "learn_f.h"
 
 #include "prun_f.ph"
 
@@ -434,7 +440,6 @@ krui_err PRUNE_OBD (int pattern)
     register TopoPtrArray topo_ptr;
     register Patterns out_pat;
     register float deriv, delta, delta2, devit;
-    register int output_units = TRUE;
     int size, pattern_no, sub_pat_no;
 
     /* reset auxiliary variables in unit array */
@@ -709,7 +714,7 @@ static krui_err pr_obs_updateInverseHessian (int no_of_patterns)
 {
 
     float hx, xh, denominator, factor;
-    int err, i, j;
+    int i, j;
 
     /* calculate pr_helpHX, pr_helpXH and denominator */
     denominator = (float) no_of_patterns;
@@ -764,13 +769,13 @@ static krui_err pr_obs_calculateInverseHessian (int pattern)
 
     register struct Unit *unit_ptr;
     register TopoPtrArray topo_ptr;
-    int no_of_patterns, pattern_no, sub_pat_no, size, err, i;
+    int no_of_patterns, pattern_no, sub_pat_no, i;
 
     /* initialize matrix */
     RbfClearMatrix (&pr_inverseHessian, 0.0);
     for (i = 0; i < pr_noOfLinks; i++)
 	/* diagonal elements are set */
-	RbfMatrixSetValue (&pr_inverseHessian, i, i, pr_obs_initParameter);
+	RbfMatrixSetValue (&pr_inverseHessian, i, i, 1/pr_obs_initParameter);
 
     /* compute the necessary sub patterns */
     if (pattern == PR_ALL_PATTERNS)
@@ -1027,7 +1032,6 @@ krui_err PRUNE_OBS (int pattern)
 ******************************************************************************/
 
 
-
 /*****************************************************************************
   FUNCTION : pr_skel_processLink
 
@@ -1035,7 +1039,7 @@ krui_err PRUNE_OBS (int pattern)
   RETURNS  : void
   NOTES    : 
 
-  UPDATE   :
+  UPDATE   : 
 ******************************************************************************/
 
 static void pr_skel_processLink (struct Unit *unit_ptr, struct Link *link_ptr)
@@ -1054,7 +1058,9 @@ static void pr_skel_processLink (struct Unit *unit_ptr, struct Link *link_ptr)
   RETURNS  : void
   NOTES    : 
 
-  UPDATE   :
+  UPDATE   : Thomas Gern, 07.09.1995
+             - saliency = actbuf[0]
+	     - search for absolute minimum
 ******************************************************************************/
 
 static void pr_skel_check_saliency (struct Unit *unit_ptr)
@@ -1064,15 +1070,16 @@ static void pr_skel_check_saliency (struct Unit *unit_ptr)
     float saliency;
 
     /* calculate saliency of unit */
-    saliency = unit_ptr->value_a * unit_ptr->Out.output;
-
-    if ((pr_candidateUnit == NULL) ||
-	(saliency < pr_candidateSaliency))
+    unit_ptr->actbuf[0] = 0.8 * unit_ptr->actbuf[0] + 0.2 * unit_ptr->value_b;
+    saliency = unit_ptr->actbuf[0];
+    if (saliency != 0.0)   /* is it the initial-value? (for already pruned input units)*/ 
+      if ((pr_candidateUnit == NULL) ||
+	  (fabs(saliency) < pr_candidateSaliency))
 	/* found first or least important unit so far */
-    {
-	pr_candidateUnit = unit_ptr;
-	pr_candidateSaliency = saliency;
-    }
+	{
+	  pr_candidateUnit = unit_ptr;
+	  pr_candidateSaliency = fabs(saliency);
+	}
 
 }
 
@@ -1095,70 +1102,139 @@ krui_err PRUNE_Skeletonization (int pattern)
     register struct Site *site_ptr;
     register struct Link *link_ptr;
     register TopoPtrArray topo_ptr;
-    float dummy;
+    static bool first = TRUE;
 
-    /* calculate mean deviation of each output unit */
-    KernelErrorCode = pr_calcMeanDeviation (pattern, &dummy);
+    register Patterns out_pat;
+    int size, pattern_no, sub_pat_no, no_of_patterns;
+
+    if (first){
+      FOR_ALL_UNITS (unit_ptr)
+	unit_ptr->actbuf[0] = 0.0;
+      first = FALSE;
+    }
+
+    FOR_ALL_UNITS (unit_ptr)
+	unit_ptr->value_b = 0.0;
+    
+    /* compute the necessary sub patterns */
+    if (pattern == PR_ALL_PATTERNS)
+	/* all patterns */
+	KernelErrorCode = kr_initSubPatternOrder
+	    (0, kr_np_pattern (PATTERN_GET_NUMBER, 0, 0) - 1);
+    else
+	/* single pattern */
+	KernelErrorCode = kr_initSubPatternOrder (pattern, pattern);
     if (KernelErrorCode != KRERR_NO_ERROR)
 	return (KernelErrorCode);
 
-    /* calculate output units */
-    for (topo_ptr = topo_ptr_array + no_of_topo_units + 2,
-	 unit_ptr = *(topo_ptr--);
-	 unit_ptr != NULL;
-	 unit_ptr = *(topo_ptr--))
+    /* calculate total number of subpatterns */
+    no_of_patterns = kr_TotalNoOfSubPatPairs ();
+
+    while (kr_getSubPatternByOrder (&pattern_no, &sub_pat_no))
     {
-	/* calculate delta */
-	if (unit_ptr->value_a > 0)
+      /* initialize value_a of each unit */
+      FOR_ALL_UNITS (unit_ptr)
+	unit_ptr->value_a = 0.0;
+
+
+      /* calculate address of the output pattern */
+      out_pat = kr_getSubPatData (pattern_no, sub_pat_no, OUTPUT, &size);
+      out_pat += size;
+	
+      /* propagate pattern through net */
+      propagateNetForward (pattern_no, sub_pat_no);
+
+      /* calculate deviation for output units */
+      for (topo_ptr = topo_ptr_array + no_of_topo_units + 2,
+	   unit_ptr = *(topo_ptr--); unit_ptr != NULL;
+	   unit_ptr = *(topo_ptr--))
+	unit_ptr->value_a = (float) *(--out_pat) - unit_ptr->Out.output;
+
+      /* calculate output units */
+      for (topo_ptr = topo_ptr_array + no_of_topo_units + 2,
+	   unit_ptr = *(topo_ptr--);
+	   unit_ptr != NULL;
+	   unit_ptr = *(topo_ptr--))
+	{
+	  /* calculate delta */
+	  if (unit_ptr->value_a > 0)
 	    unit_ptr->value_a = (unit_ptr->act_deriv_func) (unit_ptr);
-	else
+	  else
 	    if (unit_ptr->value_a < 0)
-		unit_ptr->value_a = - (unit_ptr->act_deriv_func) (unit_ptr);
+	      unit_ptr->value_a = - (unit_ptr->act_deriv_func) (unit_ptr);
 	    else
-		unit_ptr->value_a = 0;
+	      unit_ptr->value_a = 0;
 
-	/* process all links to that unit */
-	if UNIT_HAS_DIRECT_INPUTS (unit_ptr)
+	  /* process all links to that unit */
+	  if UNIT_HAS_DIRECT_INPUTS (unit_ptr)
 	    /* unit has direct inputs */
 	    FOR_ALL_LINKS (unit_ptr, link_ptr)
-		pr_skel_processLink (unit_ptr, link_ptr);
-	else
+	      pr_skel_processLink (unit_ptr, link_ptr);
+	  else
 	    /* unit has sites */
 	    FOR_ALL_SITES_AND_LINKS (unit_ptr, site_ptr, link_ptr)
-		pr_skel_processLink (unit_ptr, link_ptr);
-    }
-
-    /* calculate hidden units */
-    for (unit_ptr = *(topo_ptr--);
-	 unit_ptr != NULL;
-	 unit_ptr = *(topo_ptr--))
-    {
-	if (pr_hiddenPruning)
-	    /* check saliency of unit if not input pruning */
-	    pr_skel_check_saliency (unit_ptr);
-
-	/* calculate delta */
-	unit_ptr->value_a *= (unit_ptr->act_deriv_func) (unit_ptr);
-
-	/* process all links to that unit */
-	if UNIT_HAS_DIRECT_INPUTS (unit_ptr)
+	      pr_skel_processLink (unit_ptr, link_ptr);
+	}
+      
+      /* calculate hidden units */
+      for (unit_ptr = *(topo_ptr--);
+	   unit_ptr != NULL;
+	   unit_ptr = *(topo_ptr--))
+	{
+	  /* check saliency of unit if not input pruning */
+	  unit_ptr->value_b += unit_ptr->value_a * unit_ptr->Out.output;
+	  
+	  /* calculate delta */
+	  unit_ptr->value_a *= (unit_ptr->act_deriv_func) (unit_ptr);
+	  
+	  /* process all links to that unit */
+	  if UNIT_HAS_DIRECT_INPUTS (unit_ptr)
 	    /* unit has direct inputs */
 	    FOR_ALL_LINKS (unit_ptr, link_ptr)
-		pr_skel_processLink (unit_ptr, link_ptr);
-	else
+	      pr_skel_processLink (unit_ptr, link_ptr);
+	  else
 	    /* unit has sites */
 	    FOR_ALL_SITES_AND_LINKS (unit_ptr, site_ptr, link_ptr)
-		pr_skel_processLink (unit_ptr, link_ptr);
-    }
+	      pr_skel_processLink (unit_ptr, link_ptr);
+	}
 
-    if (pr_inputPruning) 
+      if (pr_inputPruning) 
 	/* calculate input units */
 	for (unit_ptr = *(topo_ptr--);
 	     unit_ptr != NULL;
 	     unit_ptr = *(topo_ptr--))
-	    /* check saliency of unit */
-	    pr_skel_check_saliency (unit_ptr);
-    
+	  /* check saliency of unit */
+	  unit_ptr->value_b += unit_ptr->value_a * unit_ptr->Out.output;
+      
+      
+    }
+
+    for (topo_ptr = topo_ptr_array + no_of_topo_units + 2,
+	   unit_ptr = *(topo_ptr--);
+	   unit_ptr != NULL;
+	   unit_ptr = *(topo_ptr--));
+
+    /* check hidden units */
+    for (unit_ptr = *(topo_ptr--);
+	 unit_ptr != NULL;
+	 unit_ptr = *(topo_ptr--)){
+      if (pr_hiddenPruning)
+	pr_skel_check_saliency (unit_ptr); 
+    }
+
+    /* check input units */
+    if (pr_inputPruning) 
+      /* calculate input units */
+      for (unit_ptr = *(topo_ptr--);
+	   unit_ptr != NULL;
+	   unit_ptr = *(topo_ptr--))
+	pr_skel_check_saliency (unit_ptr); 
+
+
+    if (pr_candidateUnit != NULL){
+      pr_candidateUnit->actbuf[0] = 0.0;
+    }
+      
     return (KRERR_NO_ERROR);
 
 }
@@ -1274,7 +1350,7 @@ static void pr_nc_check_stddev (struct Unit *unit_ptr, struct Unit *unit_ptr2)
 
     stddev = unit_ptr->value_c;
 
-    if (stddev >= 0 && (pr_candidateUnit == NULL) || (stddev < pr_candidateStddev)) {
+    if ((stddev >= 0 && (pr_candidateUnit == NULL)) || (stddev < pr_candidateStddev)) {
         /* found first or smallest unit so far */
         pr_candidateUnit       = unit_ptr;
         pr_candidateTargetUnit = unit_ptr2;
@@ -1574,7 +1650,6 @@ krui_err PRUNE_Noncontributing (int pattern)
 
 krui_err pr_callPrunFunc (int pattern)
 {
-    struct Unit *unit_ptr;
     FunctionPtr func_ptr;
     NetFunctionPtr net_func_ptr;
     char *curr_func;
