@@ -1,7 +1,7 @@
 /*****************************************************************************
-  FILE           : $Source: /usr/local/bv/SNNS/SNNSv4.1/kernel/sources/RCS/tbl_func.h,v $
+  FILE           : $Source: /projects/higgs1/SNNS/CVS/SNNS/kernel/sources/tbl_func.h,v $
   SHORTNAME      : 
-  SNNS VERSION   : 4.1
+  SNNS VERSION   : 4.2
 
   PURPOSE        : SNNS-Kernel: Transfer functions using table lookup and
 	           linear approximation method
@@ -11,11 +11,11 @@
   DATE           : 25.02.93
 
   CHANGED BY     : Sven Doering
-  IDENTIFICATION : $State: Exp $ $Locker:  $
-  RCS VERSION    : $Revision: 2.4 $
-  LAST CHANGE    : $Date: 1995/11/16 12:08:10 $
+  RCS VERSION    : $Revision: 2.6 $
+  LAST CHANGE    : $Date: 1998/02/25 15:27:50 $
 
-             Copyright (c) 1990-1995  SNNS Group, IPVR, Univ. Stuttgart, FRG
+    Copyright (c) 1990-1995  SNNS Group, IPVR, Univ. Stuttgart, FRG
+    Copyright (c) 1996-1998  SNNS Group, WSI, Univ. Tuebingen, FRG
 
 ******************************************************************************/
 #ifndef _TBL_FUNC_DEFINED_
