@@ -1,7 +1,7 @@
 /*****************************************************************************
-  FILE           : $Source: /usr/local/bv/SNNS/SNNSv4.0/kernel/sources/RCS/version.h,v $
+  FILE           : $Source: /projects/higgs1/SNNS/CVS/SNNS/kernel/sources/version.h,v $
   SHORTNAME      : 
-  SNNS VERSION   : 4.0
+  SNNS VERSION   : 4.2
 
   PURPOSE        : SNNS-Kernel: Current Version and Patchlevel
   NOTES          :
@@ -10,11 +10,11 @@
   DATE           : 15.08.9
 
   CHANGED BY     : Sven Doering
-  IDENTIFICATION : $State: Exp $ $Locker:  $
-  RCS VERSION    : $Revision: 2.5 $
-  LAST CHANGE    : $Date: 1995/03/14 14:04:43 $
+  RCS VERSION    : $Revision: 2.10 $
+  LAST CHANGE    : $Date: 1998/02/25 15:27:59 $
 
-             Copyright (c) 1990-1995  SNNS Group, IPVR, Univ. Stuttgart, FRG
+    Copyright (c) 1990-1995  SNNS Group, IPVR, Univ. Stuttgart, FRG
+    Copyright (c) 1996-1998  SNNS Group, WSI, Univ. Tuebingen, FRG
 
 ******************************************************************************/
 #ifndef VERSION_INCLUDE
@@ -22,14 +22,14 @@
 
 /*  define the current patchlevel
 */
-#define KERNEL_DATE    "09-08-1993"
+#define KERNEL_DATE    "01-01-1996"
 #define KERNEL_PATCH   "0"
 
 
 #ifdef MASPAR_KERNEL
 #define  SNNS_VERSION   "SNNS MasPar 3D-Kernel V3.3 (Spontanous Warp Speed)"
 #else
-#define  SNNS_VERSION   "SNNS 3D-Kernel V3.3"
+#define  SNNS_VERSION   "SNNS 3D-Kernel V4.2"
 #endif
 
 #ifdef PARAGON_KERNEL
