@@ -1,7 +1,7 @@
 /******************************************************************************
-  FILE           : $Source: /usr/local/bv/SNNS/SNNSv4.0/tools/sources/RCS/snns2c.c,v $
+  FILE           : $Source: /projects/higgs1/SNNS/CVS/SNNS/tools/sources/snns2c.c,v $
   SHORTNAME      : snns2c.c
-  SNNS VERSION   : 4.0
+  SNNS VERSION   : 4.2
 
   PURPOSE        : Converter for SNNS-net -Files to  executable C-Source
                    only for Feed-Forward- and Elman-nets.
@@ -25,22 +25,25 @@
   LAST UPDATE    : 23.02.95 (Bernward Kett)
 
   CHANGED BY     : 
-  IDENTIFICATION : $State: Exp $ $Locker:  $
-  RCS VERSION    : $Revision: 1.7 $
-  LAST CHANGE    : $Date: 1995/05/11 10:30:10 $
+  RCS VERSION    : $Revision: 1.19 $
+  LAST CHANGE    : $Date: 1998/04/22 16:48:12 $
 
-             Copyright (c) 1990-1995  SNNS Group, IPVR, Univ. Stuttgart, FRG
+    Copyright (c) 1990-1995  SNNS Group, IPVR, Univ. Stuttgart, FRG
+    Copyright (c) 1996-1998  SNNS Group, WSI, Univ. Tuebingen, FRG
   
   used files     : glob_typ.h, kr_ui.h      from kernel/sources
                    libkernel.a              from kernel/bin/<architecture>
                    functions.h, templates.h from actual directory
 ******************************************************************************/
+#include <config.h>
  
 #include <stdio.h>
 #include <stdlib.h>
 #include <string.h>
 #include <ctype.h>
+#ifdef HAVE_LIMITS_H
 #include <limits.h>
+#endif
 #include <time.h>
 #include <memory.h>
 #include "glob_typ.h"
@@ -52,7 +55,6 @@
 #include "kr_typ.h"
 #include "kernel.h"  /* should be removed, when the kr_ui.h is updated */
 
-
 #undef debug
 /* 
 #define debug
@@ -301,7 +303,7 @@ int checkLearnFunc(void)
 {
   static char *NotSupportedLearnFuncs[] = {
     "ART1", "ART2", "ARTMAP", "BackPercolation", "Hebbian", "RM_delta",
-    "RCC", "Kohonen", NULL
+    "Kohonen", NULL
   };
 
   char *LearnFunc = krui_getLearnFunc();     /* learning function of the network */
@@ -338,7 +340,7 @@ bool is_Prototype_Unit(int UnitNr)
   }
   else {
     return ( unit_ptr->TD.target_offset == 0);
-  }
+  }  
 }
 
 
@@ -476,8 +478,12 @@ int matchLayer(pLayer layer, pUnit unit)
   /* unit must not be a member of the source units */ 
   if (isMember(layer->sources, unit->number) ) return (FALSE);
 
+  /* Neue Version von Matthias Oderdorfer */
+  return ( CompareSources(unit->sources, layer->sources) );
+ 
+  /* alte Version */
   /* a member of the layer must not be a source element of the unit */
-  return( !haveIntersection(unit->sources, layer->members) );
+  /* return( !haveIntersection(unit->sources, layer->members) ); */
 }
 
 
@@ -585,7 +591,7 @@ int divideNet(pUnit globalUnits, pLayer globalLayers, int *TDNN_prot)
       sprintf(unit->name, "Old: %d", unit->number);
     }
     else {
-      unit->name = malloc(MAX(1,strlen(string)));
+      unit->name = malloc(MAX(1,strlen(string)+1));
       if(! unit->name) {
 	return (MEM_ERR);
       }
@@ -1024,6 +1030,47 @@ void writeLayer(pLayer layer, FILE *fOutFile)
   fprintf(fOutFile, "}; /* members */\n");
 }
 
+/*****************************************************************************
+  void writeUnitNew(pUnit unit, FILE *fOutFile)
+  ----------------------------------------------------------------------------
+  writes a Unit ( activation, bias, sources, Linkweights) as a struct to the
+  Outfile
+  -> unit   : unit wich is to be written
+  fOutFile  : appreciated output stream 
+  Autor     : Matthias Oberdorfer
+  *****************************************************************************/
+void writeUnitNew(pUnit unit, FILE *fOutFile, int count_links)
+ {
+
+  static int first_time = 1, is_Bptt = 0; /* to avoid unneeded procedure calls */
+ 
+ 	/* initialisation of is_Bptt */
+ 	if (first_time) {
+ 		is_Bptt = is_BPTT_net();
+ 		first_time = 0;
+ 	}
+ 
+  /* write Number and Name of the unit for identification,
+   * if a user is reading the code 
+   */
+  fprintf(fOutFile, "    { /* unit %d (%s) */\n", unit->number, unit->name);
+ 
+  /* write Activation, Bias and number of sources */
+  if (is_Bptt) {
+    fprintf(fOutFile, "      {%f, 0.0}, %f, %d,\n",
+ 	    unit->act, unit->Bias, NoOf(unit->sources));
+   }
+   else {
+     fprintf(fOutFile, "      0.0, %f, %d,\n",unit->Bias, NoOf(unit->sources));
+   }
+ 
+   /* write the Sources of the unit */
+   fprintf(fOutFile, "       &Sources[%d] , \n", count_links);
+   /* write the weights of the units */
+   fprintf(fOutFile, "       &Weights[%d] , \n", count_links);
+   
+   fprintf(fOutFile, "      }");
+ }
 
 /*****************************************************************************
   void writeUnit(pUnit unit, FILE *fOutFile)
@@ -1034,9 +1081,9 @@ void writeLayer(pLayer layer, FILE *fOutFile)
   fOutFile  : appreciated output stream 
   *****************************************************************************/
 void writeUnit(pUnit unit, FILE *fOutFile)
-{
+ {
   int i;
-	static int first_time = 1, is_Bptt = 0; /* to avoid unneeded procedure calls */
+  static int first_time = 1, is_Bptt = 0; /* to avoid unneeded procedure calls */
 
 	/* initialisation of is_Bptt */
 	if (first_time) {
@@ -1207,14 +1254,14 @@ void writeTdnnUnit(pUnit unit, pUnit Units, FILE *fOutFile)
 
 
 /*****************************************************************************
-  void writeAllUnits(pUnit Units, int NoOfUnits, FILE *fOutFile)
+  void writeAllUnitsOld(pUnit Units, int NoOfUnits, FILE *fOutFile)
   ----------------------------------------------------------------------------
   writes all Units of the Net as an array of structs to the OutputFile
   -> pUnits    : array of all units of the net
   NoOfUnits : #units in the net
   fOutFile  : appreciated output stream
   *****************************************************************************/
-void writeAllUnits(pUnit Units, int NoOfUnits, FILE *fOutFile)
+void writeAllUnitsOld(pUnit Units, int NoOfUnits, FILE *fOutFile)
 {
   int nr;
 
@@ -1283,7 +1330,226 @@ void writeAllUnits(pUnit Units, int NoOfUnits, FILE *fOutFile)
   fprintf(fOutFile, "\n  };\n\n");
 }
 
+/*****************************************************************************
+  void writeAllUnits(pUnit Units, int NoOfUnits, FILE *fOutFile)
+  ----------------------------------------------------------------------------
+  writes all Units of the Net as an array of structs to the OutputFile
+  -> pUnits    : array of all units of the net
+  NoOfUnits : #units in the net
+  fOutFile  : appreciated output stream
+  Autor     : Matthias Oberdorfer (changed original)
+  *****************************************************************************/
+void writeAllUnits(pUnit Units, int NoOfUnits, FILE *fOutFile)
+{
+  int nr;
+  int count_links;  /* to give number to links */
 
+  fprintf(fOutFile, "  /* unit definition section (see also UnitType) */\n");
+
+  /* Writing declaration of the Unit-Array */
+  /* the 0-Element is left free because the comiler was easier 
+   * to implement this way. The only exeptions are the TDNNs 
+   * because here the Units are rewritten completely */
+  if (is_TDNN_net()) {
+    fprintf(fOutFile, 
+	    "  static UnitType Units[%d] = \n  {\n", NoOfUnits
+	    );
+  }
+  else if (is_CPN_net() ){
+    fflush(fOutFile);
+    fprintf(fOutFile, 
+	    "  static UnitType Units[%d] = \n  {\n %s,\n",
+	    NoOfUnits + 1, CpnDummyUnit
+	    );
+    fflush(fOutFile);
+  }
+  else if (is_BPTT_net() ) {
+    fprintf(fOutFile, 
+	    "  static UnitType Units[%d] = \n  {\n    %s,\n",
+	    NoOfUnits + 1,
+	    "{ {0.0, 0.0}, 0.0, 0, {NULL /* NO SOURCES */}, {0.0 /* NO MEMBERS*/} }"
+	    );
+  }
+  else {
+
+    fprintf(fOutFile, 
+	    "  static UnitType Units[%d] = \n  {\n    %s,\n",
+	    NoOfUnits + 1,
+	    "{ 0.0, 0.0, 0, NULL , NULL }"
+ /* old  "{ 0.0, 0.0, 0, {NULL * NO SOURCES *}, {0.0 * NO MEMBERS*} }" */
+	    );
+  }
+
+  /* Because of the special requirements of each network-type
+   * the Unit types are slightly modified for each update-function.
+   * so they need a special output-template */
+  if (is_TDNN_net() ) {
+    for(nr = 0; nr < NoOfUnits; nr++) {
+     writeTdnnUnit(Units + nr, Units, fOutFile);
+      if (nr < NoOfUnits -1) fprintf(fOutFile, ",\n");
+      else                   fprintf(fOutFile, "\n");
+    }
+  }
+  else if(is_CPN_net() ) {
+    for(nr = 0; nr < NoOfUnits; nr++) {
+      if (nr != 0) {
+	fprintf(fOutFile, ",\n");
+      }
+      writeCpnUnit(Units + nr, fOutFile);
+    }	
+    fprintf(fOutFile, "\n");
+  }
+  /* Here also BPTT-units are included, because they are very similar to
+     the other types */
+   else {        
+    count_links = 0; /* no links yet */
+
+    for(nr = 0; nr < NoOfUnits; nr++) {
+      writeUnitNew(Units + nr, fOutFile, count_links);
+      count_links += NoOf((Units+nr)->sources);
+   /* old  writeUnit(Units + nr, fOutFile); */
+      if (nr < NoOfUnits -1) fprintf(fOutFile, ",\n");
+      else                   fprintf(fOutFile, "\n");
+    }
+  }
+  fprintf(fOutFile, "\n  };\n\n");
+}
+
+  /*****************************************************************************
+  void writeForwardDeclarationAllUnits(pUnit Units, int NoOfUnits, FILE *fOutFile)
+  ----------------------------------------------------------------------------
+  writes for all Units of the Net an forward decl. array of structs to the OutputFile
+  -> pUnits    : array of all units of the net
+  NoOfUnits : #units in the net
+  fOutFile  : appreciated output stream
+  Autor     : Matthias Oberdorfer
+  *****************************************************************************/
+ void writeForwardDeclarationAllUnits(pUnit Units, int NoOfUnits, FILE *fOutFile)
+ {
+ 
+   fprintf(fOutFile, "  /* Forward Declaration for all unit types */\n");
+ 
+   /* Writing declaration of the Unit-Array */
+   /* the 0-Element is left free because the comiler was easier 
+    * to implement this way. The only exeptions are the TDNNs 
+    * because here the Units are rewritten completely */
+   if (is_TDNN_net()) {
+     fprintf(fOutFile, 
+ 	    "  static UnitType Units[%d];\n", NoOfUnits
+ 	    );
+   }
+   else if (is_CPN_net() ){
+     fflush(fOutFile);
+     fprintf(fOutFile, 
+ 	    "  static UnitType Units[%d];\n",
+ 	    NoOfUnits + 1
+ 	    );
+     fflush(fOutFile);
+   }
+   else if (is_BPTT_net() ) {
+     fprintf(fOutFile, 
+ 	    "  static UnitType Units[%d];\n",
+ 	    NoOfUnits + 1
+ 	    );
+   }
+   else {
+     fprintf(fOutFile, 
+ 	    "  static UnitType Units[%d];\n",
+ 	    NoOfUnits + 1
+ 	    );
+   }
+ }
+
+ /***************************************************************************
+ int writeSource(pUnit unit, FILE *fOutFile)
+ ----------------------------------------------------------------------------
+ help-function for writeAllSources
+ Autor : Matthias Oberdorfer
+ ****************************************************************************/ 
+ int writeSource(pUnit unit, FILE *fOutFile)
+   {
+     int i;
+     /* There should be at least one element in the list */
+     for(i = 0; i < NoOf(unit->sources); i++)
+      {
+       /* write the sources as pointer to the source units */
+       fprintf(fOutFile, "Units + %d, ", element(unit->sources,i) );
+       if(!((i+1) % 10) )
+        fprintf(fOutFile, "\n");  
+      }
+     return i;
+   }
+   
+ /*****************************************************************************
+   void writeAllSources(pUnit Units, int NoOfUnits, FILE *fOutFile)
+   ----------------------------------------------------------------------------
+   writes all Units of the Net as an array of structs to the OutputFile
+   -> pUnits    : array of all units of the net
+   NoOfUnits : #units in the net
+   fOutFile  : appreciated output stream
+   Autor     : Matthias Oberdorfer
+   *****************************************************************************/
+
+ void writeAllSources(pUnit Units, int NoOfUnits, FILE *fOutFile)
+ {
+   int nr;
+ 
+   fprintf(fOutFile, "  /* Sources definition section */\n");
+   fprintf(fOutFile, "  static pUnit Sources[] =  {\n");
+ 
+   for(nr = 0; nr < NoOfUnits; nr++)
+   {
+       if(writeSource(Units + nr, fOutFile))
+         fprintf(fOutFile, "\n");
+   }
+   fprintf(fOutFile, "\n  };\n\n");
+ }
+
+ /***************************************************************************
+ int writeWeigths(pUnit unit, FILE *fOutFile)
+ ---------------------------------------------------------------------------
+ help-function for writeAllWeigths
+ Autor: Matthias Oberdorfer
+ ****************************************************************************/
+
+ int writeWeigths(pUnit unit, FILE *fOutFile)
+   {
+     int i;
+   /* ANSI-C needs at least one entry in an array */
+   for(i = 0; i < NoOf(unit->sources); i++)
+     {
+      fprintf(fOutFile, "%f, ", unit->weights[i]);
+      if(!((i+1) % 10) )
+        fprintf(fOutFile, "\n");  
+     }
+    return i;
+  }
+ 
+ /*****************************************************************************
+   void writeAllWeigths(pUnit Units, int NoOfUnits, FILE *fOutFile)
+   ----------------------------------------------------------------------------
+   writes all Units of the Net as an array of structs to the OutputFile
+   -> pUnits    : array of all units of the net
+   NoOfUnits : #units in the net
+   fOutFile  : appreciated output stream
+   Autor     : Matthias Oberdorfer
+   *****************************************************************************/
+
+ void writeAllWeights(pUnit Units, int NoOfUnits, FILE *fOutFile)
+ {
+   int nr;
+
+   fprintf(fOutFile, "  /* Weigths definition section */\n");
+   fprintf(fOutFile, "  static float Weights[] =  {\n");
+ 
+   for(nr = 0; nr < NoOfUnits; nr++)
+   {
+      if( writeWeigths(Units + nr, fOutFile))
+         fprintf(fOutFile, "\n");
+   }
+   fprintf(fOutFile, "\n  };\n\n");
+ }
+ 
 /***************************************************************************
   int NameLayers(pLayer globalLayers, int NoOfLayers)
   --------------------------------------------------------------------------
@@ -1393,16 +1659,19 @@ int writeTdnnNet(pLayer globalLayers, pUnit globalUnits,
   FunctionList = newList();
   if (!FunctionList) return (MEM_ERR);
 
-  for(nr = 0; nr < NoOfLayers; nr ++) {
+  for(nr = 0; nr < NoOfLayers; nr ++) 
+   {
     layer = globalLayers + nr;
-    if( layer->type == OUTPUT) {
+    if( layer->type == OUTPUT) 
+     {
       if (mergeList(OutList, layer->members) ) return (MEM_ERR);
-    }
+     }
+    else
     if (addList(FunctionList, layer->ActFunc) ) return(MEM_ERR);
-  }
+   }
 
   /** find Names for the Layers **/
-  if (NameLayers(globalLayers, NoOfLayers)) return(MEM_ERR);
+  if (NameLayers(globalLayers, NoOfLayers+1)) return(MEM_ERR);
 
 
   /* ------------------------------------------------------------
@@ -1423,7 +1692,9 @@ int writeTdnnNet(pLayer globalLayers, pUnit globalUnits,
     fprintf(fOutFile, "%s\n", ACT_FUNCTIONS[element(FunctionList, nr)]);
   }
   /* to avoid unneeded include-files */
+  fprintf(fOutFile, "#ifndef NULL\n");
   fprintf(fOutFile, "#define NULL (void *)0\n");
+  fprintf(fOutFile, "#endif\n");
 
   /* write Procedure-Header */
   fprintf(fOutFile, ProcHeader, ProcName);
@@ -1432,7 +1703,7 @@ int writeTdnnNet(pLayer globalLayers, pUnit globalUnits,
      the types must be defined local to the procedure. So 
      it's done generally */
   fprintf(fOutFile, TdnnTypeTemplate, maxTotalDelay, 
-					maxFeature, maxFeature, maxDelay);
+				      maxFeature, maxFeature, maxDelay);
 
 
   /* The Delays of the TDNN are organized as a ring-buffer 
@@ -1611,25 +1882,51 @@ int writeNet(pLayer globalLayers, pUnit globalUnits,
     fprintf(fOutFile, "%s\n", ACT_FUNCTIONS[element(FunctionList, nr)]);
   }
   /* to avoid unneeded include-files */
+  fprintf(fOutFile, "#ifndef NULL\n");
   fprintf(fOutFile, "#define NULL (void *)0\n");
+  fprintf(fOutFile, "#endif\n");
 
-  /* write Procedure-Header */
-  fprintf(fOutFile, ProcHeader, ProcName);
-
+  
   /* if more than one net is included in the application, 
      the types must be defined local to the procedure 
      so it's done generally */
   if (is_CPN_net() ) {
     fprintf(fOutFile, CpnTypeTemplate, maxSource, maxSource, 
-						NoOf(globalLayers[2].members));
+			       NoOf(globalLayers[2].members));
   }
   else if (is_BPTT_net() ) {
     fprintf(fOutFile, BpttTypeTemplate, maxSource, maxSource);
   }  
   else {
-    fprintf(fOutFile, TypeTemplate, maxSource, maxSource);
+    fprintf(fOutFile, TypeTemplate);
   }
 
+  /* write the Units, their weights and biases */
+   writeForwardDeclarationAllUnits(globalUnits, NoOfUnits, fOutFile);
+
+   if( ! is_CPN_net() && !is_BPTT_net())
+    {
+
+     /* write the Units, their weights and biases */
+     writeAllSources(globalUnits, NoOfUnits, fOutFile);
+ 
+     /* write the Units, their weights and biases */
+     writeAllWeights(globalUnits, NoOfUnits, fOutFile);
+    } 
+   if( !is_BPTT_net() )
+   {
+    /* write the Units, their weights and biases */
+    writeAllUnits(globalUnits, NoOfUnits, fOutFile);
+   }
+  else
+  {
+    /* write the Units, their weights and biases */
+    writeAllUnitsOld(globalUnits, NoOfUnits, fOutFile);
+   }
+ 
+   /* write Procedure-Header */
+   fprintf(fOutFile, ProcHeader, ProcName);
+
   /* DLVQ needs the biggest Scalar Product */
   if(is_DLVQ_net() ) {
     fprintf(fOutFile, "  float maxSum = -1.0;\n");
@@ -1644,9 +1941,7 @@ int writeNet(pLayer globalLayers, pUnit globalUnits,
     fprintf(fOutFile, "  pUnit unit;\n\n");  /* variable needed for update */
   }
   
-  /* write the Units, their weights and biases */
-  writeAllUnits(globalUnits, NoOfUnits, fOutFile);
-
+ 
   /** write  Layers e.g. Member of the layers **/
   fprintf(fOutFile, 
           "\n  /* layer definition section (names & member units) */\n");
