@@ -1,7 +1,7 @@
 /*****************************************************************************
-  FILE           : $Source: /usr/local/bv/SNNS/SNNSv4.0/tools/sources/RCS/snnsbat.c,v $
+  FILE           : $Source: /projects/higgs1/SNNS/CVS/SNNS/tools/sources/snnsbat.c,v $
   SHORTNAME      : snnsbat
-  SNNS VERSION   : 4.0
+  SNNS VERSION   : 4.2
 
   PURPOSE        : SNNS Batchlearning Program
   NOTES          :
@@ -10,31 +10,44 @@
   DATE           : 24.07.92
 
   CHANGED BY     : Guenter Mamier
-  IDENTIFICATION : $State: Exp $ $Locker:  $
-  RCS VERSION    : $Revision: 2.14 $
-  LAST CHANGE    : $Date: 1995/04/27 13:36:08 $
+  RCS VERSION    : $Revision: 2.25 $
+  LAST CHANGE    : $Date: 1998/04/22 16:48:12 $
 
-             Copyright (c) 1990-1995  SNNS Group, IPVR, Univ. Stuttgart, FRG
+    Copyright (c) 1990-1995  SNNS Group, IPVR, Univ. Stuttgart, FRG
+    Copyright (c) 1996-1998  SNNS Group, WSI, Univ. Tuebingen, FRG
 
 ******************************************************************************/
+#include <config.h>
 
 #include <stdio.h>
 #include <stdlib.h>
 #include <signal.h>
 #include <ctype.h>
+#ifdef HAVE_LIMITS_H
 #include <limits.h>
+#endif
 #include <time.h>
 #include <string.h>
+#ifdef HAVE_FCNTL_H
 #include <fcntl.h>
+#endif
+#ifdef HAVE_UNISTD_H
+#include <unistd.h>
+#endif
 #include <sys/param.h>
 #include <sys/types.h>
 #include <sys/times.h>
 #include <sys/utsname.h>
 
+#ifndef SIGIOT
+#define SIGIOT SIGABRT
+#endif
+
 #include "glob_typ.h"   /* SNNS-Kernel constants and data type definitions  */
 #include "kr_ui.h"      /* SNNS-Kernel User-Interface Function Prototypes   */
 #include "kr_typ.h"
 #include "kr_newpattern.h"
+#include "prun_f.h"
 
 #include "snnsbat.h"
 
@@ -174,7 +187,6 @@ static void  errChk(int errNo)
 ******************************************************************************/
 static void  writeLearnFuncValues()
 {
-    int  j;
 
     if(return_values != NULL){
 	fprintf(file_out,"  %5d:    %10.5f", cycle + 1,return_values[0]);
@@ -204,28 +216,17 @@ static void  writeLearnFuncValues()
 static void  writeInfo(FILE *stream)
 {
     time_t	   clock;
-#ifdef NeXT
-    char hostname[256];
-#else
-    struct utsname name;
-#endif
 
-    if(stream != NULL){
-	clock = 1;
-	(void) time(&clock);
+    if(stream == NULL)
+	return;
 
-	fprintf(stream, "\n%s Batchlearning terminated at %s",
-		krui_getVersion(),ctime(&clock));
-#ifdef NeXT
-	gethostname(hostname,256);
-	fprintf(stream,"System: NeXTSTEP  Node: %s  Machine:\n",hostname);
-#else
-	if(uname(&name) == 0)
-	    fprintf(stream, "System: %s  Node: %s  Machine: %s\n",
-		    name.sysname, name.nodename, name.machine );
-#endif
-	fflush(stream);
-    }
+    clock = 1;
+    (void) time(&clock);
+    
+    fprintf(stream, "\n%s Batchlearning terminated at %s",
+	    krui_getVersion(), ctime(&clock));
+    fprintf(stream,"Node: %s\n",getenv("HOST") ? getenv("HOST") : "unknown");
+    fflush(stream);
 }
 
 
@@ -266,7 +267,7 @@ static void  writeStatistics(bool status)
 	fprintf(file_out,"No. of links updated : %d\n", 
 		no_of_links * cycle * no_of_patterns);
 	fprintf(file_out,"CPU Time used: %.2f seconds\n",cpu_time);
-	fprintf(file_out,"User time: %d seconds\n",clock-starttime);
+	fprintf(file_out,"User time: %ld seconds\n",clock-starttime);
 	fprintf(file_out,"No. of connection updates per second (CUPS): %e\n\n",
 		((double)no_of_links * (double)cycle * 
 		 (double)no_of_patterns) / ((double)cpu_time));
@@ -311,7 +312,7 @@ static void  writeCaughtMsg(int msg)
   RETURNS  : 
   UPDATE   : 
 ******************************************************************************/
-static void  emergency_exit(int msg)
+RETSIGTYPE emergency_exit(int msg)
 {
     writeCaughtMsg(msg);
 
@@ -340,7 +341,7 @@ static void  emergency_exit(int msg)
 
   UPDATE   : 
 ******************************************************************************/
-static void  exit_batchlearn(int msg)
+RETSIGTYPE exit_batchlearn(int msg)
 {
     char *tmp_file;
 
@@ -898,6 +899,7 @@ static int parseFile(int op_code)
 		ret = fscanf(file_in,"%[^\n]",arg_string);
 		if(IsOld(arg_string)){
 		    if(exec_loop == 0)configError(8,"UpdateParam:");
+		}else{
 		    if (!scanParameter(update_param, arg_string, 
 				       no_of_update_param,FALSE))
 			configError(4,"update");
@@ -1425,7 +1427,7 @@ static void timeCheck ()
 static void trainNet()
 {
 
-    int ret,step,dummy;
+    int ret,step;
 
 
     fprintf(file_out,
@@ -1484,12 +1486,12 @@ static float trainFFNet (int no_of_cycles_ff)
 
 {
 
-    int ret, step, dummy;
+    int ret, step;
 
 
     errChk (krui_DefTrainSubPat 
 	    (SubPatternISize_param, SubPatternOSize_param,
-	     SubPatternIStep_param, SubPatternOStep_param, &dummy));
+	     SubPatternIStep_param, SubPatternOStep_param, NULL));
 
     cycle = 0;
     step = ((no_of_cycles_ff-1) / NO_OF_CYCLES_DISPLAYED)+1;
@@ -1643,7 +1645,7 @@ static void pruneNet ()
 static void computeResultfile()
 {
 
-    int ret,dummy;
+    int ret;
 
 
     if(test_pat_file[0] == '\0' && learn_pat_file[0] == '\0'){
@@ -1673,7 +1675,7 @@ static void computeResultfile()
     }
     errChk(krui_DefTrainSubPat(SubPatternISize_param,SubPatternOSize_param,
 			       SubPatternIStep_param,SubPatternOStep_param,
-			       &dummy));
+			       NULL));
     ret = krui_saveResultParam(res_file,TRUE,start_pattern,end_pattern,
 			       input_included,output_included,update_param, 
 			       NO_OF_UPDATE_PARAMS);
@@ -1696,7 +1698,7 @@ static void computeResultfile()
 ******************************************************************************/
 int main(int argc, char  *argv[] )
 {
-    int	        ret, i, dummy,
+    int	        ret, i,
                 pError,
                 notLast=1;
     time_t	clock;
@@ -1726,7 +1728,7 @@ int main(int argc, char  *argv[] )
 
     /* get HZ value */
 
-    if((getenv("HZ") == NULL) || (sscanf(getenv("HZ"),"%d",&HZ_value)!=1)){
+    if((getenv("HZ") == NULL) || (sscanf(getenv("HZ"),"%ld",&HZ_value)!=1)){
 #ifndef HZ
 	fprintf( stderr, "****  WARNING: no HZ defined!\n" );
 	HZ_value = 100;
@@ -1921,7 +1923,7 @@ int main(int argc, char  *argv[] )
 				       ,SubPatternOSize_param
 				       ,SubPatternIStep_param
 				       ,SubPatternOStep_param
-				       ,&dummy));
+				       ,NULL));
 
 	}
 
