@@ -1,7 +1,7 @@
 /*****************************************************************************
-  FILE           : $Source: /usr/local/bv/SNNS/SNNSv4.0/xgui/sources/RCS/bn_artmap.h,v $
+  FILE           : $Source: /projects/higgs1/SNNS/CVS/SNNS/xgui/sources/bn_artmap.h,v $
   SHORTNAME      : bn_artmap
-  SNNS VERSION   : 4.0
+  SNNS VERSION   : 4.2
 
   PURPOSE        : 
   NOTES          :
@@ -10,11 +10,11 @@
   DATE           : 15.1.1993
 
   CHANGED BY     : 
-  IDENTIFICATION : $State: Exp $ $Locker:  $
-  RCS VERSION    : $Revision: 2.3 $
-  LAST CHANGE    : $Date: 1995/03/14 14:18:47 $
+  RCS VERSION    : $Revision: 2.6 $
+  LAST CHANGE    : $Date: 1998/02/25 15:19:35 $
 
-             Copyright (c) 1990-1995  SNNS Group, IPVR, Univ. Stuttgart, FRG
+    Copyright (c) 1990-1995  SNNS Group, IPVR, Univ. Stuttgart, FRG
+    Copyright (c) 1996-1998  SNNS Group, WSI, Univ. Tuebingen, FRG
 
 ******************************************************************************/
 #ifndef _BN_ARTMAP_DEFINED_
