@@ -1,7 +1,7 @@
 /*****************************************************************************
-  FILE           : $Source: /usr/local/bv/SNNS/SNNSv4.0/xgui/sources/RCS/d3_dither.h,v $
+  FILE           : $Source: /projects/higgs1/SNNS/CVS/SNNS/xgui/sources/d3_dither.h,v $
   SHORTNAME      : dither.h
-  SNNS VERSION   : 4.0
+  SNNS VERSION   : 4.2
 
   PURPOSE        : header
   NOTES          :
@@ -10,11 +10,11 @@
   DATE           : 1.12.1991
 
   CHANGED BY     : Sven Doering
-  IDENTIFICATION : $State: Exp $ $Locker:  $
-  RCS VERSION    : $Revision: 2.3 $
-  LAST CHANGE    : $Date: 1995/03/14 14:18:57 $
+  RCS VERSION    : $Revision: 2.6 $
+  LAST CHANGE    : $Date: 1998/02/25 15:20:00 $
 
-             Copyright (c) 1990-1995  SNNS Group, IPVR, Univ. Stuttgart, FRG
+    Copyright (c) 1990-1995  SNNS Group, IPVR, Univ. Stuttgart, FRG
+    Copyright (c) 1996-1998  SNNS Group, WSI, Univ. Tuebingen, FRG
 
 ******************************************************************************/
 #ifndef _D3_DITHER_DEFINED_
