@@ -1,7 +1,7 @@
 /*****************************************************************************
-  FILE           : $Source: /usr/local/bv/SNNS/SNNSv4.1/xgui/sources/RCS/d3_units.c,v $
+  FILE           : $Source: /projects/higgs1/SNNS/CVS/SNNS/xgui/sources/d3_units.c,v $
   SHORTNAME      : units.c
-  SNNS VERSION   : 4.1
+  SNNS VERSION   : 4.2
 
   PURPOSE        : controls the unit pannel
   NOTES          :
@@ -10,13 +10,14 @@
   DATE           : 1.12.1991
 
   CHANGED BY     :
-  IDENTIFICATION : $State: Exp $ $Locker:  $
-  RCS VERSION    : $Revision: 2.4 $
-  LAST CHANGE    : $Date: 1995/11/16 07:19:05 $
+  RCS VERSION    : $Revision: 2.7 $
+  LAST CHANGE    : $Date: 1998/03/03 14:10:04 $
 
-             Copyright (c) 1990-1995  SNNS Group, IPVR, Univ. Stuttgart, FRG
+    Copyright (c) 1990-1995  SNNS Group, IPVR, Univ. Stuttgart, FRG
+    Copyright (c) 1996-1998  SNNS Group, WSI, Univ. Tuebingen, FRG
              
 ******************************************************************************/
+#include <config.h>
 
 
 #include <stdio.h>
