@@ -1,7 +1,7 @@
 /*****************************************************************************
-  FILE           : $Source: /usr/local/bv/SNNS/SNNSv4.0/xgui/sources/RCS/ui.h,v $
+  FILE           : $Source: /projects/higgs1/SNNS/CVS/SNNS/xgui/sources/ui.h,v $
   SHORTNAME      : ui.h
-  SNNS VERSION   : 4.0
+  SNNS VERSION   : 4.2
 
   PURPOSE        : general header file 
   NOTES          : This file is to include in all ui_*.c files.
@@ -13,16 +13,16 @@
   DATE           : 18.5.1990
 
   CHANGED BY     : Sven Doering
-  IDENTIFICATION : $State: Exp $ $Locker:  $
-  RCS VERSION    : $Revision: 2.7 $
-  LAST CHANGE    : $Date: 1995/05/11 15:04:18 $
+  RCS VERSION    : $Revision: 2.15 $
+  LAST CHANGE    : $Date: 1998/04/20 11:54:57 $
 
-             Copyright (c) 1990-1995  SNNS Group, IPVR, Univ. Stuttgart, FRG
+    Copyright (c) 1990-1995  SNNS Group, IPVR, Univ. Stuttgart, FRG
+    Copyright (c) 1996-1998  SNNS Group, WSI, Univ. Tuebingen, FRG
 
 ******************************************************************************/
 
-#ifndef __ui
-#define __ui
+#ifndef snns_ui
+#define snns_ui
 
 /* X11 */
 
@@ -66,7 +66,7 @@
 
 /***************************** misc    ********************************/
 
-#define MAX_NAME_LENGTH 100
+#define MAX_NAME_LENGTH 4096
 
 #define UI_ASCII_BLANK   32
 
@@ -154,7 +154,11 @@ struct LinkAttributeType {
 };
 
 
-
+struct ErrorValuesType {
+    FlintType       SSE;
+    FlintType       MSE;
+    FlintType       SSE_div_Out;
+};
 
 
 /*****************************************************************************/
@@ -176,8 +180,6 @@ struct LinkAttributeType {
 #define UI_POPUP_WEIGHTS_CANCEL 11
 #define UI_POPUP_RESULT  12
 #define UI_POPUP_SUBPATTERN  13
-#define UI_POPUP_RPC 14          
-#define UI_POPUP_RPC_SERVER 15   
 #define UI_POPUP_INFO  16
 
 #define SEARCH_WORD_MAXLEN 40
@@ -222,6 +224,7 @@ kernel. */
 #define UI_LIST_INIT_FUNC   6 
 #define UI_LIST_PRUN_FUNC   10
 #define UI_LIST_FF_LEARN_FUNC  0x0404
+#define UI_LIST_REMAP_FUNC  12
 
 #define UI_LIST_IOTYPE         20 
 #define UI_LIST_SITE           21
@@ -340,7 +343,15 @@ struct Ui_DisplayType {
 #define UI_NO_LEARN_PARAMS  5
 #define UI_NO_UPDATE_PARAMS 5
 #define UI_NO_INIT_PARAMS   5
-#define UI_NO_OF_CASCADE_PARAMS 15
+#define UI_NO_REMAP_PARAMS   5
+/* !!!!!! ATTENTION !!!!!
+   When changing the following value, always make sure that 
+   NO_OF_LEARN_PARAMS = UI_NO_LEARN_PARAMS + UI_NO_OF_CASCADE_PARAMS
+   remains true!! NO_OF_LEARN_PARAMS is declared in kernel/sources/glob_typ.h
+   Also note, that the file kernel/sources/cc_mac.h assumes that 
+   NO_OF_LEARN_PARAMS >= 27 !!!!! 
+*/ 
+#define UI_NO_OF_CASCADE_PARAMS 23
 
 #define UI_STEPS         1
 #define UI_LEARN         2
@@ -385,11 +396,8 @@ struct Ui_DisplayType {
 #define  UI_SCALE_LINKS      6
 
 
-
-
 /* info */
 
-
 struct UnitWidgetType {
     Widget    no;                       /* label */
     Widget    subnetNo;                 /* label */
