@@ -1,7 +1,7 @@
 /*****************************************************************************
-  FILE           : $Source: /usr/local/bv/SNNS/SNNSv4.0/xgui/sources/RCS/ui_config.c,v $  
+  FILE           : $Source: /projects/higgs1/SNNS/CVS/SNNS/xgui/sources/ui_config.c,v $  
   SHORTNAME      : config.c
-  SNNS VERSION   : 4.0
+  SNNS VERSION   : 4.2
 
   PURPOSE        : handling of configuration files
   NOTES          :
@@ -10,13 +10,14 @@
   DATE           : 28.9.1990
 
   CHANGED BY     : Michael Vogt, Guenter Mamier
-  IDENTIFICATION : $State: Exp $ $Locker:  $
-  RCS VERSION    : $Revision: 2.4 $ 
-  LAST CHANGE    : $Date: 1995/04/24 13:35:19 $  
+  RCS VERSION    : $Revision: 2.11 $ 
+  LAST CHANGE    : $Date: 1998/05/20 15:00:37 $  
 
-             Copyright (c) 1990-1995  SNNS Group, IPVR, Univ. Stuttgart, FRG
+    Copyright (c) 1990-1995  SNNS Group, IPVR, Univ. Stuttgart, FRG
+    Copyright (c) 1996-1998  SNNS Group, WSI, Univ. Tuebingen, FRG
 
 ******************************************************************************/
+#include <config.h>
 
 
 #include <stdio.h>
@@ -27,20 +28,28 @@
 #include "ui_display.h"
 #include "ui_fileP.h"
 #include "ui_mainP.h"
+#include "ui_infoP.h"
 #include "ui_confirmer.h"
 #include "ui_xWidgets.h"
 #include "ui_utilP.h"
 #include "ui_color.h"
+#include "ui_class.h"
 #include "ui_control.h"
 #include "ui_print.h"
 #include "ui_main.h"
+#include "cc_main.h"
+#include "pr_main.h"
 #include "ui_layerP.h"
+#include "cc_type.h"
+#include "cc_glob.h"
 
 #include "d3_global.h"
 #include "d3_main.h"
 #include "d3_fonts.h"
 #include "d3_pannels.h"
 #include "d3_disp.h"
+#include "d3_zgraph.h"
+#include "kr_ui.h"
 
 #include "ui_config.ph"
 
@@ -53,16 +62,17 @@
   NOTES    : In the first line, format determines the format of the file. This
              number will be checked be future routines, to be able to read 
 	     all previous formats for compatibility reasons.
-
-  UPDATE   : 19.3.1991
+  UPDATE   : 
 ******************************************************************************/
-
 int ui_cfg_save (FILE *filePtr)
 
 {
     int    err;
     int    i, count = 0;
+    int    in, out;
     struct Ui_DisplayType *listPtr;
+    pattern_set_info   patt_info;
+    pattern_descriptor descrip;
 
     err = fprintf(filePtr,"SNNS xgui configuration file.  format: %d\n\n",
 		  CURRENT_FORMAT);
@@ -96,33 +106,73 @@ int ui_cfg_save (FILE *filePtr)
     err = fprintf(filePtr,"\n");
     retchk(err);
 
-    err = fprintf(filePtr,"Learn parameters: %d\n", UI_NO_LEARN_PARAMS);
+    krui_getFuncParamInfo(krui_getLearnFunc(), LEARN_FUNC, &in, &out);
+    if(strcmp(krui_getLearnFunc(),"CC") == 0)
+	err = fprintf(filePtr,"Learn parameters: %d\n", 
+		      UI_NO_LEARN_PARAMS+UI_NO_OF_CASCADE_PARAMS);
+    else
+	err = fprintf(filePtr,"Learn parameters: %d\n", in);
     retchk(err);
-    for (i=0; i<UI_NO_LEARN_PARAMS; i++) {
-	err = fprintf(filePtr,"param %d: %9.5f\n",i+1,
-		      ui_learnParameters[i]);
+    for (i=0; i<in; i++) {
+	if (ui_controlIsCreated) {
+	    err = fprintf(filePtr,"param %d: %9.5f\n",i+1,
+			 ui_xFloatFromAsciiWidget(ui_learnParameterWidgets[i]));
+	}else{
+	    err = fprintf(filePtr,"param %d: %9.5f\n",i+1,
+			  ui_learnParameters[i]);
+	}
+	retchk(err);
+    }
+    cc_readElements();
+    for (i=in; i<UI_NO_LEARN_PARAMS+UI_NO_OF_CASCADE_PARAMS; i++) {
+	err = fprintf(filePtr,"param %d: %9.5f\n",i+1, ui_learnParameters[i]);
 	retchk(err);
     }
     err = fprintf(filePtr,"\n");
     retchk(err);
 
-    err = fprintf(filePtr,"Update parameters: %d\n", UI_NO_UPDATE_PARAMS);
+    krui_getFuncParamInfo(krui_getUpdateFunc(), UPDATE_FUNC, &in, &out);
+    err = fprintf(filePtr,"Update parameters: %d\n", in);
     retchk(err);
-    for (i=0; i<UI_NO_UPDATE_PARAMS; i++) {
-	err = fprintf(filePtr,"param %d: %9.5f\n",i+1,
-		      ui_updateParameters[i]);
+    for (i=0; i<in; i++) {
+	if (ui_controlIsCreated) 
+	    err = fprintf(filePtr,"param %d: %9.5f\n",i+1,
+			ui_xFloatFromAsciiWidget(ui_updateParameterWidgets[i]));
+	else
+	    err = fprintf(filePtr,"param %d: %9.5f\n",i+1,
+			  ui_updateParameters[i]);
 	retchk(err);
     }
     err = fprintf(filePtr,"\n");
     retchk(err);
 
-    err = fprintf(filePtr,"Initialisation parameters: %d\n", UI_NO_INIT_PARAMS);
+    krui_getFuncParamInfo(krui_getInitialisationFunc(), INIT_FUNC, &in, &out);
+    err = fprintf(filePtr,"Initialisation parameters: %d\n", in);
     retchk(err);
-    for (i=0; i<UI_NO_INIT_PARAMS; i++) {
-	err = fprintf(filePtr,"param %d: %9.5f\n",i+1,
-		      ui_initParameters[i]);
+    for (i=0; i<in; i++) {
+	if (ui_controlIsCreated) 
+	    err = fprintf(filePtr,"param %d: %9.5f\n",i+1,
+			 ui_xFloatFromAsciiWidget(ui_initParameterWidgets[i]));
+	else
+	    err = fprintf(filePtr,"param %d: %9.5f\n",i+1,
+			  ui_initParameters[i]);
 	retchk(err);
     }
+
+    krui_GetPatInfo(&patt_info, &descrip);
+    err = fprintf(filePtr,"Remap parameters: %d\n",
+		  patt_info.no_of_remap_params);
+    retchk(err);
+    for (i=0; i<patt_info.no_of_remap_params; i++) {
+	if (ui_controlIsCreated) 
+	    err = fprintf(filePtr,"param %d: %9.5f\n",i+1,
+			 ui_xFloatFromAsciiWidget(ui_remapParameterWidgets[i]));
+	else
+	    err = fprintf(filePtr,"param %d: %9.5f\n",i+1,
+			  ui_remapParameters[i]);
+	retchk(err);
+    }
+
     err = fprintf(filePtr,"\n");
     retchk(err);
 
@@ -293,9 +343,7 @@ int ui_cfg_save (FILE *filePtr)
         retchk(err);
    }  
 
-   err = fprintf (filePtr, "%s\n", ui_printerConfigStr);
-   retchk(err);
-   err = fprintf(filePtr,"\n");
+   err = fprintf (filePtr, "%s\n\n", ui_printerConfigStr);
    retchk(err);
     
    err = fprintf (filePtr, "destination               : %d\n", ui_prVal.dest); 
@@ -341,6 +389,24 @@ int ui_cfg_save (FILE *filePtr)
    err = fprintf (filePtr, "command line              : %s\n", ui_prVal.cmdLineStr); 
    retchk(err);
 
+
+   err = fprintf (filePtr, "\n%s\n\n", ui_classConfigStr);
+   retchk(err);
+   if(ui_class_open)class_readWidgets();
+   err = fprintf (filePtr, "%d %d ",ui_classes,patt_info.class_distrib_active);
+   retchk(err);
+   for(i=0; i<ui_classes; i++){
+       err = fprintf(filePtr,"%d ", *patt_info.class_redistribution++);
+   }
+   err = fprintf(filePtr,"\n");
+   retchk(err);
+  
+   err = fprintf (filePtr, "\n%s\n\n", ui_windowConfigStr);
+   retchk(err);
+   err = fprintf (filePtr, "%d %d %d %d %d \n", ui_controlIsCreated, 
+		  ui_infoIsCreated, ui_class_open, pr_open, cc_open); 
+   retchk(err);
+
    err = fprintf(filePtr,"\n");
    retchk(err);
 
@@ -355,18 +421,19 @@ int ui_cfg_save (FILE *filePtr)
   RETURNS  : int
   NOTES    : future load routines have to check the value "format" to be able
              to read all previous formats as well.
-
-  UPDATE   : 19.3.1991
+  UPDATE   : 
 ******************************************************************************/
-
 int ui_cfg_load (FILE *filePtr)
 
 {
     char   header[200];
     char   colorString[7];
     int    i, err, noParams, dummy, count, format, lines = 1;
+    int    number, onOff, *dist, one, two, three, four, five;
     float  dummyf, f1, f2, f3;
-    char   ch[1];
+    char   ch[1], rest_string[256], classline[256];
+    pattern_set_info   patt_info;
+    pattern_descriptor descrip;
 
     struct Ui_DisplayType *listPtr;
 
@@ -425,17 +492,37 @@ int ui_cfg_load (FILE *filePtr)
 	err = fscanf(filePtr,"%*[^:]: %d\n", &noParams);
 	chkretline(1);
 	lines++;
-	for (i=0; (i<UI_NO_LEARN_PARAMS) AND (i<noParams); i++) {
+	for (i=0; (i<UI_NO_LEARN_PARAMS+UI_NO_OF_CASCADE_PARAMS) && (i<noParams); i++){
 	    err = fscanf(filePtr,"%*[^:]: %f\n", &ui_learnParameters[i]);
 	    chkretline(1);
 	    lines++;
-	    if (ui_controlIsCreated) {
+	    if (ui_controlIsCreated && (i < 5)) {
 		char buf[20];
 		sprintf(buf,"%6.4f",ui_learnParameters[i]);
 		ui_cutTrailingZeros(buf);
 		ui_xSetString(ui_learnParameterWidgets[i], buf);
 	    }
 	}
+	cc_data.GLOBAL.pixelError = ui_learnParameters[6];
+	cc_data.GLOBAL.learningFunc = (int)ui_learnParameters[7];
+	cc_data.GLOBAL.onOff = (int)ui_learnParameters[8];
+	cc_data.CAND.covarianceChange = ui_learnParameters[9] ;
+	cc_data.CAND.candidatePatience = (int)ui_learnParameters[10];
+	cc_data.CAND.maxNoOfUpdateCycles = (int)ui_learnParameters[11];
+	cc_data.CAND.maxNoOfCandUnits = (int)ui_learnParameters[12];
+	cc_data.CAND.actFunc = (int)ui_learnParameters[13];
+	cc_data.OUT.errorChange = ui_learnParameters[14];
+	cc_data.OUT.outputPatience = (int)ui_learnParameters[15];
+	cc_data.OUT.maxNoOfUpdateCycles = (int)ui_learnParameters[16];
+	cc_data.GLOBAL.pruneOnOff = (int)ui_learnParameters[17];
+	cc_data.GLOBAL.backfittOnOff = (int)ui_learnParameters[18];
+	cc_data.GLOBAL.backfittPatience = (int)ui_learnParameters[19];
+	cc_data.GLOBAL.pruneFunc = (int)ui_learnParameters[20];
+	cc_data.GLOBAL.modification = (int)ui_learnParameters[21];
+	for (i=0;i<5;i++)
+	    cc_data.GLOBAL.addParameters[i] = ui_learnParameters[22+i];
+	cc_data.GLOBAL.fastmode = (int)ui_learnParameters[27];
+
 	err = fscanf(filePtr,"\n");
 	chkretline(0);
 	lines++;
@@ -465,6 +552,32 @@ int ui_cfg_load (FILE *filePtr)
 	    err = fscanf(filePtr,"%*[^:]: %f\n", &ui_initParameters[i]);
 	    chkretline(1);
 	    lines++;
+	    if (ui_controlIsCreated) {
+		char buf[20];
+		sprintf(buf,"%6.4f",ui_initParameters[i]);
+		ui_cutTrailingZeros(buf);
+		ui_xSetString(ui_initParameterWidgets[i], buf);
+	    }
+	}
+	err = fscanf(filePtr,"\n");
+	chkretline(0);
+	lines++;
+    }
+
+    if (format >= 7) {
+	err = fscanf(filePtr,"%*[^:]: %d\n", &noParams);
+	chkretline(1);
+	lines++;
+	for (i=0; (i<UI_NO_REMAP_PARAMS) AND (i<noParams); i++) {
+	    err = fscanf(filePtr,"%*[^:]: %f\n", &ui_remapParameters[i]);
+	    chkretline(1);
+	    lines++;
+	    if (ui_controlIsCreated) {
+		char buf[20];
+		sprintf(buf,"%6.4f",ui_remapParameters[i]);
+		ui_cutTrailingZeros(buf);
+		ui_xSetString(ui_remapParameterWidgets[i], buf);
+	    }
 	}
 	err = fscanf(filePtr,"\n");
 	chkretline(0);
@@ -575,7 +688,7 @@ int ui_cfg_load (FILE *filePtr)
 	    err = fscanf(filePtr,"%*[^:]: %s\n", colorString);
 	    chkfreeretline(1);
 	    lines++;
-            ui_convertColorString(colorString, &(listPtr->setup.textColorIndex), 
+            ui_convertColorString(colorString, &(listPtr->setup.textColorIndex),
                                   &(listPtr->setup.backgroundColorIndex),
                                   &(listPtr->setup.selectionColorIndex));
 	}
@@ -588,195 +701,240 @@ int ui_cfg_load (FILE *filePtr)
 	ui_displayGraphic(NULL, listPtr, NULL);
     }
 
-    if (format >= 5) {
-	err = fscanf(filePtr,"%s\n", header);
-	if (strcmp (header, d3_configStr) == 0) {
-            ui_configHas3dSection = TRUE; 
-	    chkretline(1);
-	    lines++;
-            err = fscanf(filePtr,"\n");
-	    chkretline(0);
-	    lines++;
+    if (format < 5) 
+	return(TRUE);
 
-            err = fscanf(filePtr, "%*[^:]: %f %f %f\n", &f1, &f2, &f3); 
-	    chkretline(3);
-	    lines++;
-            d3_state.rot_vec[0] = rad(f1);
-            d3_state.rot_vec[1] = rad(f2);
-            d3_state.rot_vec[2] = rad(f3);
-            err = fscanf(filePtr, "%*[^:]: %f %f %f\n", 
-               &d3_state.trans_vec[0], &d3_state.trans_vec[1], 
-               &d3_state.trans_vec[2]);
-	    chkretline(3);
-	    lines++;
-            err = fscanf(filePtr, "%*[^:]: %f %f %f\n", 
-               &d3_state.scale_vec[0], &d3_state.scale_vec[1], 
-               &d3_state.scale_vec[2]);
-            chkretline(3);
-            lines++;
+    err = fscanf(filePtr,"%s\n", header);
+    if (strcmp (header, d3_configStr) == 0) {
+	ui_configHas3dSection = TRUE; 
+	chkretline(1);
+	lines++;
+	err = fscanf(filePtr,"\n");
+	chkretline(0);
+	lines++;
 
-            err = fscanf(filePtr, "%*[^:]: %f %f %f\n", &f1, &f2, &f3); 
-	    chkretline(3);
-	    lines++;
-            d3_state.rot_step[0] = rad(f1);
-            d3_state.rot_step[1] = rad(f2);
-            d3_state.rot_step[2] = rad(f3);
-            err = fscanf(filePtr, "%*[^:]: %f %f %f\n", &d3_state.trans_step[0], 
-               &d3_state.trans_step[1], &d3_state.trans_step[2]);
-	    chkretline(3);
-	    lines++;
-            err = fscanf(filePtr, "%*[^:]: %f %f %f\n", &d3_state.scale_step[0], 
-               &d3_state.scale_step[1], &d3_state.scale_step[2]);
-            chkretline(3);
-            lines++;
+	err = fscanf(filePtr, "%*[^:]: %f %f %f\n", &f1, &f2, &f3); 
+	chkretline(3);
+	lines++;
+	d3_state.rot_vec[0] = rad(f1);
+	d3_state.rot_vec[1] = rad(f2);
+	d3_state.rot_vec[2] = rad(f3);
+	err = fscanf(filePtr, "%*[^:]: %f %f %f\n", 
+		     &d3_state.trans_vec[0], &d3_state.trans_vec[1], 
+		     &d3_state.trans_vec[2]);
+	chkretline(3);
+	lines++;
+	err = fscanf(filePtr, "%*[^:]: %f %f %f\n", 
+		     &d3_state.scale_vec[0], &d3_state.scale_vec[1], 
+		     &d3_state.scale_vec[2]);
+	chkretline(3);
+	lines++;
 
-            err = fscanf(filePtr, "%*[^:]: %d\n", &d3_state.projection_mode); 
-            chkretline(1);
-            lines++;
-            err = fscanf(filePtr, "%*[^:]: %f %f %f\n", &d3_state.viewpoint[0], 
-               &d3_state.viewpoint[1], &d3_state.viewpoint[2]);
-	    chkretline(3);
-	    lines++;
+	err = fscanf(filePtr, "%*[^:]: %f %f %f\n", &f1, &f2, &f3); 
+	chkretline(3);
+	lines++;
+	d3_state.rot_step[0] = rad(f1);
+	d3_state.rot_step[1] = rad(f2);
+	d3_state.rot_step[2] = rad(f3);
+	err = fscanf(filePtr, "%*[^:]: %f %f %f\n", &d3_state.trans_step[0], 
+		     &d3_state.trans_step[1], &d3_state.trans_step[2]);
+	chkretline(3);
+	lines++;
+	err = fscanf(filePtr, "%*[^:]: %f %f %f\n", &d3_state.scale_step[0], 
+		     &d3_state.scale_step[1], &d3_state.scale_step[2]);
+	chkretline(3);
+	lines++;
 
-            err = fscanf(filePtr, "%*[^:]: %d\n", &d3_state.font); 
-            chkretline(1);
-            lines++;
+	err = fscanf(filePtr, "%*[^:]: %d\n", &d3_state.projection_mode); 
+	chkretline(1);
+	lines++;
+	err = fscanf(filePtr, "%*[^:]: %f %f %f\n", &d3_state.viewpoint[0], 
+		     &d3_state.viewpoint[1], &d3_state.viewpoint[2]);
+	chkretline(3);
+	lines++;
 
-            err = fscanf(filePtr, "%*[^:]: %d\n", &d3_state.model_mode); 
-            chkretline(1);
-            lines++;
-            err = fscanf(filePtr, "%*[^:]: %d\n", &d3_state.link_mode); 
-            chkretline(1);
-            lines++;
-            err = fscanf(filePtr, "%*[^:]: %f\n", &d3_state.link_scale); 
-            chkretline(1);
-            lines++;
-            err = fscanf(filePtr, "%*[^:]: %f\n", &d3_state.unit_aspect); 
-            chkretline(1);
-            lines++;
-            err = fscanf(filePtr, "%*[^:]: %d\n", &d3_state.unit_mode.size); 
-            chkretline(1);
-            lines++;
-            err = fscanf(filePtr, "%*[^:]: %d\n", &d3_state.unit_mode.color); 
-            chkretline(1);
-            lines++;
-            err = fscanf(filePtr, "%*[^:]: %d\n", &d3_state.unit_mode.top_label); 
-            chkretline(1);
-            lines++;
-            err = fscanf(filePtr, "%*[^:]: %d\n", &d3_state.unit_mode.bottom_label);            chkretline(1);
-            lines++;
+	err = fscanf(filePtr, "%*[^:]: %d\n", &d3_state.font); 
+	chkretline(1);
+	lines++;
 
-            err = fscanf(filePtr, "%*[^:]: %f %f %f\n", &d3_state.light.position[0],                &d3_state.light.position[1], &d3_state.light.position[2]);
-	    chkretline(3);
-	    lines++;
-            err = fscanf(filePtr, "%*[^:]: %f\n", &d3_state.light.Ia); 
-            chkretline(1);
-	    lines++;
-            err = fscanf(filePtr, "%*[^:]: %f\n", &d3_state.light.Ka); 
-            chkretline(1);
-	    lines++;
-            err = fscanf(filePtr, "%*[^:]: %f\n", &d3_state.light.Ip); 
-            chkretline(1);
-	    lines++;
-            err = fscanf(filePtr, "%*[^:]: %f\n", &d3_state.light.Kd); 
-            chkretline(1);
-	    lines++;
+	err = fscanf(filePtr, "%*[^:]: %d\n", &d3_state.model_mode); 
+	chkretline(1);
+	lines++;
+	err = fscanf(filePtr, "%*[^:]: %d\n", &d3_state.link_mode); 
+	chkretline(1);
+	lines++;
+	err = fscanf(filePtr, "%*[^:]: %f\n", &d3_state.link_scale); 
+	chkretline(1);
+	lines++;
+	err = fscanf(filePtr, "%*[^:]: %f\n", &d3_state.unit_aspect); 
+	chkretline(1);
+	lines++;
+	err = fscanf(filePtr, "%*[^:]: %d\n", &d3_state.unit_mode.size); 
+	chkretline(1);
+	lines++;
+	err = fscanf(filePtr, "%*[^:]: %d\n", &d3_state.unit_mode.color); 
+	chkretline(1);
+	lines++;
+	err = fscanf(filePtr, "%*[^:]: %d\n", &d3_state.unit_mode.top_label); 
+	chkretline(1);
+	lines++;
+	err = fscanf(filePtr, "%*[^:]: %d\n", &d3_state.unit_mode.bottom_label);
+	chkretline(1);
+	lines++;
 
-	    err = fscanf(filePtr,"\n");
-	    chkretline(0);
-	    lines++;
+	err = fscanf(filePtr, "%*[^:]: %f %f %f\n", &d3_state.light.position[0],
+		     &d3_state.light.position[1], &d3_state.light.position[2]);
+	chkretline(3);
+	lines++;
+	err = fscanf(filePtr, "%*[^:]: %f\n", &d3_state.light.Ia); 
+	chkretline(1);
+	lines++;
+	err = fscanf(filePtr, "%*[^:]: %f\n", &d3_state.light.Ka); 
+	chkretline(1);
+	lines++;
+	err = fscanf(filePtr, "%*[^:]: %f\n", &d3_state.light.Ip); 
+	chkretline(1);
+	lines++;
+	err = fscanf(filePtr, "%*[^:]: %f\n", &d3_state.light.Kd); 
+	chkretline(1);
+	lines++;
+
+	err = fscanf(filePtr,"\n");
+	chkretline(0);
+	lines++;
     
-            d3_select_font (d3_state.font);
-            if (d3_state.model_mode == solid) 
-                d3_initZbuffer ();
-            d3_displayGraphic ();
-            d3_createDisplayWindow ();
-        }
+	d3_select_font (d3_state.font);
+	if (d3_state.model_mode == solid) 
+	    d3_initZbuffer ();
+	d3_displayGraphic ();
+	d3_createDisplayWindow ();
     }
 
-    if (format >= 6) {
-        if (ui_configHas3dSection)
-            err = fscanf(filePtr,"%s\n", header);
-	if (strcmp (header, ui_printerConfigStr) == 0) { 
-	    chkretline(1);
-	    lines++;
-            err = fscanf(filePtr,"\n");
-	    chkretline(0);
-	    lines++;
+    if (format < 6) 
+	return(TRUE);
+        
+    if (ui_configHas3dSection)
+	err = fscanf(filePtr,"%s\n", header);
+    if (strcmp (header, ui_printerConfigStr) == 0) { 
+	chkretline(1);
+	lines++;
+	err = fscanf(filePtr,"\n");
+	chkretline(0);
+	lines++;
 
-            err = fscanf(filePtr, "%*[^:]: %d\n", &ui_prVal.dest); 
-	    chkretline(1);
-	    lines++;
-            err = fscanf(filePtr, "%*[^:]: %d\n", &ui_prVal.format); 
-	    chkretline(1);
-	    lines++;
-            err = fscanf(filePtr, "%*[^:]: %d\n", &ui_prVal.paper); 
-	    chkretline(1);
-	    lines++;
-            err = fscanf(filePtr, "%*[^:]: %d\n", &ui_prVal.autoScale); 
-	    chkretline(1);
-	    lines++;
-            err = fscanf(filePtr, "%*[^:]: %d\n", &ui_prVal.clip); 
-	    chkretline(1);
-	    lines++;
-            err = fscanf(filePtr, "%*[^:]: %d\n", &ui_prVal.color); 
-	    chkretline(1);
-	    lines++;
-            err = fscanf(filePtr, "%*[^:]: %d\n", &ui_prVal.orient); 
-	    chkretline(1);
-	    lines++;
-            err = fscanf(filePtr, "%*[^:]: %d\n", &ui_prVal.autoUni); 
-	    chkretline(1);
-	    lines++;
-            err = fscanf(filePtr, "%*[^:]: %d\n", &ui_prVal.size); 
-	    chkretline(1);
-	    lines++;
-            err = fscanf(filePtr, "%*[^:]: %d\n", &ui_prVal.shape); 
-	    chkretline(1);
-	    lines++;
-            err = fscanf(filePtr, "%*[^:]: %d\n", &ui_prVal.text); 
-	    chkretline(1);
-	    lines++;
-            err = fscanf(filePtr, "%*[^:]: %d\n", &ui_prVal.border); 
-	    chkretline(1);
-	    lines++;
-            err = fscanf(filePtr, "%*[^:]: %d\n", &ui_prVal.resolution); 
-	    chkretline(1);
-	    lines++;
-            err = fscanf(filePtr, "%*[^:]: %d\n", &ui_prVal.displayToPrint); 
-	    chkretline(1);
-	    lines++;
-            err = fscanf(filePtr, "%*[^:]: %f\n", &ui_prVal.borderHoriz); 
-	    chkretline(1);
-	    lines++;
-            err = fscanf(filePtr, "%*[^:]: %f\n", &ui_prVal. borderVert); 
-	    chkretline(1);
-	    lines++;
-            err = fscanf(filePtr, "%*[^:]: %f\n", &ui_prVal.scaleValX); 
-	    chkretline(1);
-	    lines++;
-            err = fscanf(filePtr, "%*[^:]: %f\n", &ui_prVal.scaleValY); 
-	    chkretline(1);
-	    lines++;
-            err = fscanf(filePtr, "%*[^:]: %f\n", &ui_prVal.unitGray); 
-	    chkretline(1);
-	    lines++;
-            err = fscanf(filePtr, "%*[^:]: %s\n", ui_prVal.fileNameStr); 
-	    chkretline(1);
-	    lines++;
+	err = fscanf(filePtr, "%*[^:]: %d\n", &ui_prVal.dest); 
+	chkretline(1);
+	lines++;
+	err = fscanf(filePtr, "%*[^:]: %d\n", &ui_prVal.format); 
+	chkretline(1);
+	lines++;
+	err = fscanf(filePtr, "%*[^:]: %d\n", &ui_prVal.paper); 
+	chkretline(1);
+	lines++;
+	err = fscanf(filePtr, "%*[^:]: %d\n", &ui_prVal.autoScale); 
+	chkretline(1);
+	lines++;
+	err = fscanf(filePtr, "%*[^:]: %d\n", &ui_prVal.clip); 
+	chkretline(1);
+	lines++;
+	err = fscanf(filePtr, "%*[^:]: %d\n", &ui_prVal.color); 
+	chkretline(1);
+	lines++;
+	err = fscanf(filePtr, "%*[^:]: %d\n", &ui_prVal.orient); 
+	chkretline(1);
+	lines++;
+	err = fscanf(filePtr, "%*[^:]: %d\n", &ui_prVal.autoUni); 
+	chkretline(1);
+	lines++;
+	err = fscanf(filePtr, "%*[^:]: %d\n", &ui_prVal.size); 
+	chkretline(1);
+	lines++;
+	err = fscanf(filePtr, "%*[^:]: %d\n", &ui_prVal.shape); 
+	chkretline(1);
+	lines++;
+	err = fscanf(filePtr, "%*[^:]: %d\n", &ui_prVal.text); 
+	chkretline(1);
+	lines++;
+	err = fscanf(filePtr, "%*[^:]: %d\n", &ui_prVal.border); 
+	chkretline(1);
+	lines++;
+	err = fscanf(filePtr, "%*[^:]: %d\n", &ui_prVal.resolution); 
+	chkretline(1);
+	lines++;
+	err = fscanf(filePtr, "%*[^:]: %d\n", &ui_prVal.displayToPrint); 
+	chkretline(1);
+	lines++;
+	err = fscanf(filePtr, "%*[^:]: %f\n", &ui_prVal.borderHoriz); 
+	chkretline(1);
+	lines++;
+	err = fscanf(filePtr, "%*[^:]: %f\n", &ui_prVal. borderVert); 
+	chkretline(1);
+	lines++;
+	err = fscanf(filePtr, "%*[^:]: %f\n", &ui_prVal.scaleValX); 
+	chkretline(1);
+	lines++;
+	err = fscanf(filePtr, "%*[^:]: %f\n", &ui_prVal.scaleValY); 
+	chkretline(1);
+	lines++;
+	err = fscanf(filePtr, "%*[^:]: %f\n", &ui_prVal.unitGray); 
+	chkretline(1);
+	lines++;
+	err = fscanf(filePtr, "%*[^:]: %s\n", ui_prVal.fileNameStr); 
+	chkretline(1);
+	lines++;
 
-            err = fscanf(filePtr, "%*[^:]: ");
-            ui_prVal.cmdLineStr[0] = '\0';
-            while ((*ch = getc(filePtr)) != '\n')
-               strncat (ui_prVal.cmdLineStr, ch, 1);
-	    lines++;
+	err = fscanf(filePtr, "%*[^:]: ");
+	ui_prVal.cmdLineStr[0] = '\0';
+	while ((*ch = getc(filePtr)) != '\n')
+	    strncat (ui_prVal.cmdLineStr, ch, 1);
+	lines++;
+	err = fscanf(filePtr,"%s\n", header);
+    }
+
+    if (strcmp (header, ui_classConfigStr) == 0) { 
+	chkretline(1);
+	lines++;
+	err = fscanf(filePtr,"\n");
+	chkretline(0);
+	lines++;
+
+	err = (fgets(classline, 256, filePtr) == NULL)?0:1;
+	chkretline(1);
+	sscanf(classline,"%d %d %[^\n]",&number, &onOff, rest_string);
+	if( (krui_GetPatInfo(&patt_info, &descrip) != 0) || 
+	    (number != patt_info.classes)){
+	    ui_confirmOk("Class information does not match pattern file;\nclass information ignored");
+	}else{
+            dist = (int *)malloc(patt_info.classes * sizeof(int));
+	    for(i=0; i<patt_info.classes; i++){
+		sscanf(rest_string,"%d %[^\n]",&dist[i],classline);
+		strcpy(rest_string,classline);
+	    }
+	    krui_useClassDistribution(onOff);
+	    krui_setClassDistribution(dist);
 	}
-    }   
+	lines++;
+	err = fscanf(filePtr,"\n%s\n", header);
+    }
+
+    if (strcmp (header, ui_windowConfigStr) == 0) { 
+	chkretline(1);
+	lines++;
+	err = fscanf(filePtr,"\n");
+	chkretline(0);
+	lines++;
+
+	err = fscanf(filePtr, "%d %d %d %d %d", &one, &two, &three, 
+		     &four, &five); 
+	if(one) ui_displayControl(NULL, NULL, NULL);
+	if(two) ui_displayInfo(NULL, NULL, NULL);
+	if(three) ui_classWindow();
+	if(four) pr_createWindow();
+	if(five) cc_createWindow();
+	chkretline(5);
+	lines++;
+    }
     return(TRUE);
 
 }
-
-
-
 /* end of file */
-/* lines: 682 */
