@@ -1,7 +1,7 @@
 /*****************************************************************************
-  FILE           : $Source: /usr/local/bv/SNNS/SNNSv4.0/xgui/sources/RCS/ui_control.c,v $
+  FILE           : $Source: /projects/higgs1/SNNS/CVS/SNNS/xgui/sources/ui_control.c,v $
   SHORTNAME      : control.c
-  SNNS VERSION   : 4.0
+  SNNS VERSION   : 4.2
 
   PURPOSE        : creates the widget containing all controls of the kernal.
   NOTES          : is called only during initialisation
@@ -10,13 +10,14 @@
   DATE           : 20.7.1990
 
   CHANGED BY     : Michael Vogt, Guenter Mamier
-  IDENTIFICATION : $State: Exp $ $Locker:  $
-  RCS VERSION    : $Revision: 1.2 $ 
-  LAST CHANGE    : $Date: 1995/05/11 15:05:30 $  
+  RCS VERSION    : $Revision: 1.15 $ 
+  LAST CHANGE    : $Date: 1998/04/20 11:55:08 $  
 
-             Copyright (c) 1990-1995  SNNS Group, IPVR, Univ. Stuttgart, FRG
+    Copyright (c) 1990-1995  SNNS Group, IPVR, Univ. Stuttgart, FRG
+    Copyright (c) 1996-1998  SNNS Group, WSI, Univ. Tuebingen, FRG
              
 ******************************************************************************/
+#include <config.h>
 
 
 #include <stdio.h>
@@ -32,12 +33,11 @@
 #include <X11/Xaw/List.h>
 #include <X11/Xaw/MenuButton.h>
 
+#include "kr_ui.h"
 #include "ui_controlP.h"
 #include "ui_xWidgets.h"
-#include "ui_lists.h"
 #include "ui_main.h"  /* ui_labelFontWidth */
 #include "ui_mainP.h" /* ui_editPopup() */
-#include "ui_infoP.h" /* ui_info_displayList() */
 #include "ui_utilP.h" /* ui_cutTrailingZeros() */
 #include "ui_fileP.h"
 
@@ -71,14 +71,15 @@ void ui_xCreateControlPanel (Widget parent)
     static struct SimpleListType  listLearnFunc;  /* func list */
     static struct SimpleListType  listUpdateFunc; /* func list */
     static struct SimpleListType  listInitFunc;   /* func list */
+    static struct SimpleListType  listRemapFunc;   /* func list */
 
     Widget      stepLabel, learnLabel, updateLabel, learn2Label, pattLabel;
-    Widget      mButton, sButton, button, menu, entry, mItem, subpattLabel;
-    Widget      mdelButton,museButton, testLabel, initLabel;  
+    Widget      sButton, button, menu, entry, mItem;
+    Widget      mdelButton,museButton, testLabel, initLabel, remapLabel;  
     Arg		args[10];
     Cardinal	n;
     int         i;
-    char        buf[20], *func_name;
+    char        buf[20];
 
 
 /*
@@ -86,7 +87,6 @@ void ui_xCreateControlPanel (Widget parent)
 */
     int  titelWidth  =  7 * ui_labelFontWidth;
     int  numberWidth =  7 * ui_labelFontWidth;
-    int  nameWidth   =  6 * ui_labelFontWidth;
     int  fileWidth   =  26* ui_labelFontWidth;
 
 /***************************************************************************/
@@ -116,13 +116,13 @@ void ui_xCreateControlPanel (Widget parent)
     XtSetArg(args[n], XtNborderWidth, 1); n++;
     XtSetArg(args[n], XtNinternalHeight, 3); n++;
     XtSetArg(args[n], XtNinternalWidth , 5); n++;
-    XtSetArg(args[n], XtNhorizDistance, 11); n++; 
+    XtSetArg(args[n], XtNhorizDistance, 5); n++; 
     XtSetValues(ui_numberOfStepsDoneWidget, args, n);
-
-    button = ui_xCreateButtonItem("init", ui_controlPanel, 
-				  ui_numberOfStepsDoneWidget, NULL);
-    XtSetArg(args[0], XtNhorizDistance, 11); 
-    XtSetValues(button, args, 1);
+    jogbutton = ui_xCreateButtonItem("jog", ui_controlPanel,
+				     ui_numberOfStepsDoneWidget, NULL);
+    XtAddCallback(jogbutton, XtNcallback, (XtCallbackProc)ui_popupWeights,NULL);
+   
+    button = ui_xCreateButtonItem("init", ui_controlPanel, jogbutton, NULL);
     XtAddCallback(button, XtNcallback, (XtCallbackProc)ui_rem_doInitialization,
 		  NULL);
 
@@ -167,17 +167,11 @@ void ui_xCreateControlPanel (Widget parent)
     XtAddCallback(button, XtNcallback, (XtCallbackProc) ui_rem_shuffleProc, 
 		  NULL);
     
-    button = ui_xCreateMenuButtonItem("options", ui_controlPanel,
+    button = ui_xCreateMenuButtonItem("editors", ui_controlPanel,
 				      button, stepLabel);
 
     menu = XtCreatePopupShell("menu", simpleMenuWidgetClass, button,
 			      NULL, ZERO);
-
-    mItem = XtCreateManagedWidget("jog weights", smeBSBObjectClass, 
-				  menu, NULL, ZERO);
-    XtAddCallback(mItem, XtNcallback, (XtCallbackProc) ui_popupWeights, 
-		  (caddr_t) UI_JOG);
-
     mItem = XtCreateManagedWidget("edit f-types", smeBSBObjectClass, 
 				  menu, NULL, ZERO);
     sprintf(listSiteFType.msg,"Edit f-type table");
@@ -241,7 +235,7 @@ void ui_xCreateControlPanel (Widget parent)
 				    titelWidth, NULL, learnLabel);
 
     sprintf(buf,"%d",ui_noOfCurrentPattern);
-    ui_numberOfPatternWidget = ui_xCreateDialogItem("patternNo", ui_controlPanel,
+    ui_numberOfPatternWidget = ui_xCreateDialogItem("patternNo",ui_controlPanel,
 						    buf, numberWidth, 
 						    pattLabel, learnLabel);
 
@@ -250,7 +244,7 @@ void ui_xCreateControlPanel (Widget parent)
     XtAddCallback(button, XtNcallback, 
 		  (XtCallbackProc) ui_rem_deletePatternProc, NULL);
 
-    button = ui_xCreateButtonItem("modify", ui_controlPanel, button, learnLabel);
+    button = ui_xCreateButtonItem("modify", ui_controlPanel, button,learnLabel);
     XtAddCallback(button, XtNcallback, 
 		  (XtCallbackProc) ui_rem_modifyPatternProc, NULL);
 
@@ -279,7 +273,7 @@ void ui_xCreateControlPanel (Widget parent)
     XtAddCallback(button, XtNcallback, 
 		  (XtCallbackProc)ui_rem_moveInPatternsProc, (caddr_t)UI_LAST);
 
-    button = ui_xCreateButtonItem("subpat", ui_controlPanel, button, learnLabel);
+    button = ui_xCreateButtonItem("subpat", ui_controlPanel, button,learnLabel);
     XtAddCallback(button,XtNcallback,
 		  (XtCallbackProc)ui_rem_defSubPat, (caddr_t)0);
 
@@ -298,7 +292,9 @@ void ui_xCreateControlPanel (Widget parent)
 						      smeBSBObjectClass,
 						      REM_DFileMenu,NULL,ZERO);
 	    XtAddCallback(DELPattFileWidget[i], XtNcallback, 
-			  (XtCallbackProc)ui_rem_delPattSet, (caddr_t)i);
+			  (XtCallbackProc)ui_rem_delPattSet,
+			  (XtPointer) ((long)i));
+
 	}
     }else{
 	DELPattFileWidget[0] = XtCreateManagedWidget("No Files",
@@ -319,7 +315,8 @@ void ui_xCreateControlPanel (Widget parent)
 						      smeBSBObjectClass,
 						      REM_UFileMenu,NULL,ZERO);
 	    XtAddCallback(USEPattFileWidget[i], XtNcallback, 
-			  (XtCallbackProc)ui_rem_usePattSet, (caddr_t)i);
+			  (XtCallbackProc)ui_rem_usePattSet, 
+			  (XtPointer) ((long)i));
 	}
 	sprintf(buf,"%s",PATTERN_SET_FILE[CURR_PATTERN_SET]);
     }else{
@@ -361,7 +358,8 @@ void ui_xCreateControlPanel (Widget parent)
 	       XtCreateManagedWidget(PATTERN_SET_FILE[i],smeBSBObjectClass,
 				     REM_UTestFileMenu,NULL,ZERO);
 	    XtAddCallback(USETestPattFileWidget[i], XtNcallback, 
-			  (XtCallbackProc)ui_rem_useTestPattSet, (caddr_t)i);
+			  (XtCallbackProc)ui_rem_useTestPattSet,
+			  (XtPointer) ((long)i));
        }
        sprintf(buf,"%s",PATTERN_SET_FILE[CURR_TEST_PATTERN_SET]);
     }else{
@@ -396,19 +394,13 @@ void ui_xCreateControlPanel (Widget parent)
     button = ui_xCreateMenuButtonItem("func",ui_controlPanel, 
 				      ui_learnParameterWidgets[i-1], testLabel);
 
-    /* Note:
-    /* the construction of a dummy menu is necessary. Otherwise the creation */
-    /* of the control panel would take more than 60 sec. with the RPC kernel  */
-
-    menu = XtCreatePopupShell("menu", simpleMenuWidgetClass, button, NULL,ZERO);
-    mItem = XtCreateManagedWidget("dummy",smeBSBObjectClass,menu, NULL,ZERO);
-
     sprintf(listLearnFunc.msg,"Select learning function");
     listLearnFunc.unitPtr  = NULL;
     listLearnFunc.widgetPtr= button;
     listLearnFunc.listType = UI_LIST_LEARN_FUNC;
-    XtAddCallback(menu, XtNpopupCallback, (XtCallbackProc) ui_rem_displayList, 
-		  (caddr_t) &listLearnFunc); 
+    ui_rem_displayList(button, &listLearnFunc);
+
+
 
 
 /*****************************  UPDATE PARAMETER  **************************/
@@ -429,20 +421,11 @@ void ui_xCreateControlPanel (Widget parent)
 
     button = ui_xCreateMenuButtonItem("func",ui_controlPanel, 
 				  ui_updateParameterWidgets[i-1], learn2Label);
-
-    /* Note:
-    /* the construction of a dummy menu is necessary. Otherwise the creation */
-    /* of the control panel would take more than 60 sec. with the RPC kernel  */
-
-    menu = XtCreatePopupShell("menu", simpleMenuWidgetClass, button,NULL,ZERO);
-    mItem = XtCreateManagedWidget("dummy",smeBSBObjectClass,menu, NULL,ZERO);
-
     sprintf(listUpdateFunc.msg,"Select update function");
     listUpdateFunc.unitPtr  = NULL;
     listUpdateFunc.widgetPtr= button;
     listUpdateFunc.listType = UI_LIST_UPDATE_FUNC;
-    XtAddCallback(menu, XtNpopupCallback, (XtCallbackProc) ui_rem_displayList, 
-		  (caddr_t) &listUpdateFunc); 
+    ui_rem_displayList(button, &listUpdateFunc);
 
 
 /****************************** INIT PARAMETER *****************************/
@@ -462,28 +445,195 @@ void ui_xCreateControlPanel (Widget parent)
     button = ui_xCreateMenuButtonItem("func",ui_controlPanel, 
 				  ui_initParameterWidgets[i-1], updateLabel);
 
-
-    /* Note:
-    /* the construction of a dummy menu is necessary. Otherwise the creation */
-    /* of the control panel would take more than 60 sec. with the RPC kernel  */
-
-    menu = XtCreatePopupShell("menu", simpleMenuWidgetClass, button,NULL,ZERO);
-    mItem = XtCreateManagedWidget("dummy",smeBSBObjectClass,menu,NULL,ZERO);
-   
     sprintf(listInitFunc.msg,"Select init function");
     listInitFunc.unitPtr  = NULL;
     listInitFunc.widgetPtr= button;
     listInitFunc.listType = UI_LIST_INIT_FUNC;
-    XtAddCallback(menu, XtNpopupCallback, (XtCallbackProc) ui_rem_displayList, 
-		  (caddr_t) &listInitFunc); 
+    ui_rem_displayList(button, &listInitFunc);
+
+
+/****************************** REMAP PARAMETER *****************************/
+
+    remapLabel = ui_xCreateLabelItem("REMAP", ui_controlPanel,
+				      titelWidth, NULL, initLabel);
+
+    for (i=0; i<UI_NO_REMAP_PARAMS; i++) {
+	sprintf(buf,"%6.4f",ui_remapParameters[i]);
+	ui_cutTrailingZeros(buf);
+	ui_remapParameterWidgets[i] =
+	    ui_xCreateDialogItem("remapParameter", ui_controlPanel,
+				 buf, numberWidth, 
+				 i==0?remapLabel:ui_remapParameterWidgets[i-1],
+				 initLabel);
+    }
+    button = ui_xCreateMenuButtonItem("func",ui_controlPanel, 
+				  ui_remapParameterWidgets[i-1], initLabel);
+    sprintf(listRemapFunc.msg,"Select remap function");
+    listRemapFunc.unitPtr  = NULL;
+    listRemapFunc.widgetPtr= button;
+    listRemapFunc.listType = UI_LIST_REMAP_FUNC;
+    ui_rem_displayList(button, &listRemapFunc);
 
 
 /***************************************************************************/
 
     XawFormDoLayout(ui_controlPanel, True);
     ui_controlIsCreated = TRUE;
+    ui_NumberOfLearnParamsChanged();
+    ui_NumberOfUpdateParamsChanged();
+    ui_NumberOfInitParamsChanged();
+    ui_NumberOfRemapParamsChanged();
+}
+
+
+
+
+/*****************************************************************************
+  FUNCTION : ui_NumberOfLearnParamsChanged
+
+  PURPOSE  : hiding all unused learn parameter widgets
+  RETURNS  : 
+  NOTES    :
+
+  UPDATE   : 
+******************************************************************************/
+void ui_NumberOfLearnParamsChanged(void)
+{
+    int in=UI_NO_LEARN_PARAMS;
+    int out=0;
+    int i;
+    Arg args[5];
+    Cardinal n;
+    if(!ui_controlIsCreated)
+	return;
+    krui_getFuncParamInfo(krui_getLearnFunc(), LEARN_FUNC, &in, &out);
+    n = 0;
+    XtSetArg(args[n], XtNsensitive, TRUE); n++;
+    XtSetArg(args[n], XtNmappedWhenManaged, TRUE); n++;
+    for(i=0; i < in; i++){
+	XtSetValues(ui_learnParameterWidgets[i], args, n);
+    }
+    n = 0;
+    XtSetArg(args[n], XtNsensitive, FALSE); n++;
+    XtSetArg(args[n], XtNmappedWhenManaged, FALSE); n++;
+    while(i < UI_NO_LEARN_PARAMS) {
+	XtSetValues(ui_learnParameterWidgets[i], args, n);
+	ui_xSetString(ui_learnParameterWidgets[i],"");
+	i++;
+    }
+}
+
+/*****************************************************************************
+  FUNCTION : ui_NumberOfUpdateParamsChanged
+
+  PURPOSE  : hiding all unused update parameter widgets
+
+  RETURNS  : 
+  NOTES    :
+
+  UPDATE   : 
+******************************************************************************/
+void ui_NumberOfUpdateParamsChanged(void)
+{
+    int in=UI_NO_UPDATE_PARAMS;
+    int out=0;
+    int i;
+    Arg args[5];
+    Cardinal n;
+    if(!ui_controlIsCreated)
+	return;
+    krui_getFuncParamInfo(krui_getUpdateFunc(), UPDATE_FUNC, &in, &out);
+    n = 0;
+    XtSetArg(args[n], XtNsensitive, TRUE); n++;
+    XtSetArg(args[n], XtNmappedWhenManaged, TRUE); n++;
+    for(i=0; i < in; i++){
+	XtSetValues(ui_updateParameterWidgets[i], args, n);
+    }
+    n = 0;
+    XtSetArg(args[n], XtNsensitive, FALSE); n++;
+    XtSetArg(args[n], XtNmappedWhenManaged, FALSE); n++;
+    while(i < UI_NO_UPDATE_PARAMS) {
+	XtSetValues(ui_updateParameterWidgets[i], args, n);
+	ui_xSetString(ui_updateParameterWidgets[i],"");
+	i++;
+    }
+}
+
+/*****************************************************************************
+  FUNCTION : ui_NumberOfInitParamsChanged
+
+  PURPOSE  : hiding all unused init parameter widgets
+  RETURNS  : 
+  NOTES    :
+
+  UPDATE   : 
+******************************************************************************/
+void ui_NumberOfInitParamsChanged(void)
+{
+    int in=UI_NO_INIT_PARAMS;
+    int out=0;
+    int i;
+    Arg args[5];
+    Cardinal n;
+    if(!ui_controlIsCreated)
+	return;
+    krui_getFuncParamInfo(krui_getInitialisationFunc(), INIT_FUNC, &in, &out);
+    n = 0;
+    XtSetArg(args[n], XtNsensitive, TRUE); n++;
+    XtSetArg(args[n], XtNmappedWhenManaged, TRUE); n++;
+    for(i=0; i < in; i++){
+	XtSetValues(ui_initParameterWidgets[i], args, n);
+    }
+    n = 0;
+    XtSetArg(args[n], XtNsensitive, FALSE); n++;
+    XtSetArg(args[n], XtNmappedWhenManaged, FALSE); n++;
+    while(i < UI_NO_INIT_PARAMS) {
+	XtSetValues(ui_initParameterWidgets[i], args, n);
+	ui_xSetString(ui_initParameterWidgets[i],"");
+	i++;
+    }
+}
+
+
+/*****************************************************************************
+  FUNCTION : ui_NumberOfRemapParamsChanged
+
+  PURPOSE  : hiding all unused remap parameter widgets
+  RETURNS  : 
+  NOTES    :
+
+  UPDATE   : 
+******************************************************************************/
+void ui_NumberOfRemapParamsChanged(void)
+{
+    int i, error, border;
+    Arg args[5];
+    Cardinal n;
+    pattern_set_info   patt_info;
+    pattern_descriptor descrip;
+
+    if(!ui_controlIsCreated)
+	return;
+
+    if((error = krui_GetPatInfo(&patt_info, &descrip))< 0){
+	border = 0;
+    }else{
+	border = patt_info.no_of_remap_params;
+    }
+
+    XtSetArg(args[0], XtNsensitive, TRUE);
+    XtSetArg(args[1], XtNmappedWhenManaged, TRUE);
+    for(i=0; i<border; i++){
+	XtSetArg(args[2], XtNlabel, patt_info.remap_params[i]);
+	XtSetValues(ui_remapParameterWidgets[i], args, 3);
+    }
+    n = 0;
+    XtSetArg(args[n], XtNsensitive, FALSE); n++;
+    XtSetArg(args[n], XtNmappedWhenManaged, FALSE); n++;
+    for(i=border; i<UI_NO_REMAP_PARAMS;i++) {
+	XtSetValues(ui_remapParameterWidgets[i], args, n);
+	ui_xSetString(ui_remapParameterWidgets[i],"");
+    }
 }
 
 /* end of file */
-/* lines: 485 */
-
