@@ -1,7 +1,7 @@
 /*****************************************************************************
-  FILE           : $Source: /usr/local/bv/SNNS/SNNSv4.0/xgui/sources/RCS/ui_fileP.c,v $
+  FILE           : $Source: /projects/higgs1/SNNS/CVS/SNNS/xgui/sources/ui_fileP.c,v $
   SHORTNAME      : fileP.c
-  SNNS VERSION   : 4.0
+  SNNS VERSION   : 4.2
 
   PURPOSE        :
   NOTES          :
@@ -10,13 +10,14 @@
   DATE           : 22.5.1990
 
   CHANGED BY     : Michael Vogt, Guenter Mamier
-  IDENTIFICATION : $State: Exp $ $Locker:  $
-  RCS VERSION    : $Revision: 2.5 $ 
-  LAST CHANGE    : $Date: 1995/04/24 13:09:12 $  
+  RCS VERSION    : $Revision: 2.14 $ 
+  LAST CHANGE    : $Date: 1998/03/03 14:10:24 $  
 
-             Copyright (c) 1990-1995  SNNS Group, IPVR, Univ. Stuttgart, FRG
+    Copyright (c) 1990-1995  SNNS Group, IPVR, Univ. Stuttgart, FRG
+    Copyright (c) 1996-1998  SNNS Group, WSI, Univ. Tuebingen, FRG
              
 ******************************************************************************/
+#include <config.h>
 
 
 #include <stdio.h>
@@ -50,6 +51,8 @@
 #include "ui_main.h"
 #include "ui_event.h"
 #include "ui_action.h"
+#include "ui_xWidgets.h"
+#include "ui_class.h"
 
 #include "ui_fileP.ph"
 
@@ -502,6 +505,7 @@ void ui_file_loadPatterns (Widget w, XtPointer button, caddr_t call_data)
 	ui_printMessage("Patterns loaded.");
 	strcpy(ui_filenameSLPAT, ui_filenamePAT);
 	ui_file_updateShellLabels();
+	ui_classUpdatePanel(TRUE);
     }
 }
 
@@ -559,13 +563,15 @@ void ui_file_saveNet (Widget w, XtPointer button, caddr_t call_data)
   FUNCTION : ui_file_loadNet
 
   PURPOSE  : loads the dynamic net structure
-  RETURNS  : void
+  RETURNS  : -1 on error condition
+              0 for success
+              1 when also a configuration file has been loaded
   NOTES    : calls krui_loadNet() 
 
   UPDATE   :
 *****************************************************************************/
 
-void ui_file_loadNet (Widget w, XtPointer button, caddr_t call_data)
+int ui_file_loadNet (Widget w, XtPointer button, caddr_t call_data)
 
 {
     char     filename[4+MAX_NAME_LENGTH+MAX_NAME_LENGTH];
@@ -573,11 +579,12 @@ void ui_file_loadNet (Widget w, XtPointer button, caddr_t call_data)
              /* filename plus some text */
     Bool     performLoad = TRUE;
     char     *temp;
+    int      ret_val = 0;
 
     /* check now for errors and react ! */
     if (strlen(ui_filenameNET) == 0) { 
 	ui_confirmOk("No file specified");
-	return;
+	return (-1);
     }
 
     /* a filename is given */
@@ -591,7 +598,7 @@ void ui_file_loadNet (Widget w, XtPointer button, caddr_t call_data)
 
     if (NOT ui_fileExist(filename, 0)) {
 	ui_confirmOk("No such network file exists!");
-	return;
+	return(-1);
     }
 
     /* a file exists */
@@ -612,9 +619,9 @@ void ui_file_loadNet (Widget w, XtPointer button, caddr_t call_data)
 	if(ui_controlIsCreated)ui_xSetLabel(ui_controlMessageWidget, "");
         d3_clear_xyTranslationTable ();
 	ui_checkError(krui_loadNet(filename, &temp));
-	if (ui_kernelError < 0)
+	if (ui_kernelError < 0){
 	    ui_confirmOk("Error during loading the network!");
-	else {
+	} else {
 	    ui_printMessage("Network loaded.");  
 	    /* message to text window */
 	    sprintf(string,"\n\n\nNetwork loaded from file:\n   %s\n",
@@ -629,6 +636,7 @@ void ui_file_loadNet (Widget w, XtPointer button, caddr_t call_data)
 	        if (ui_fileExist(filename, 0) AND  
 		    ui_confirmYes("Load corresponding configuration file")) {
 		    ui_file_doLoadConfiguration(filename);
+		    ret_val = 1;
 	        }
 	    }
 	}
@@ -649,7 +657,12 @@ void ui_file_loadNet (Widget w, XtPointer button, caddr_t call_data)
 	strcpy(ui_filenameSLNET, ui_filenameNET);
 	ui_file_updateShellLabels();
 	ui_info_makeUnitInfoPanelConsistent();
+	ui_NumberOfLearnParamsChanged();
+	ui_NumberOfUpdateParamsChanged();
+	ui_NumberOfInitParamsChanged();
     }    
+    
+    return (ret_val);
 }
 
 
