@@ -1,7 +1,7 @@
 /*****************************************************************************
-  FILE           : $Source: /usr/local/bv/SNNS/SNNSv4.0/xgui/sources/RCS/ui_inversion.c,v $
+  FILE           : $Source: /projects/higgs1/SNNS/CVS/SNNS/xgui/sources/ui_inversion.c,v $
   SHORTNAME      : inversion.c
-  SNNS VERSION   : 4.0
+  SNNS VERSION   : 4.2
 
   PURPOSE  : contains all routines for handling inversion of NN, invented
             by Alexander Linden
@@ -83,13 +83,14 @@
  VERSION  : 0.20
 
  CHANGED BY     : Sven Doering
- IDENTIFICATION : $State: Exp $ $Locker:  $
- RCS VERSION    : $Revision: 2.5 $
- LAST CHANGE    : $Date: 1995/04/24 13:17:11 $
+ RCS VERSION    : $Revision: 2.11 $
+ LAST CHANGE    : $Date: 1998/03/03 14:10:30 $
 
-             Copyright (c) 1990-1995  SNNS Group, IPVR, Univ. Stuttgart, FRG
+    Copyright (c) 1990-1995  SNNS Group, IPVR, Univ. Stuttgart, FRG
+    Copyright (c) 1996-1998  SNNS Group, WSI, Univ. Tuebingen, FRG
 
 ******************************************************************************/
+#include <config.h>
 
 #ifndef MASPAR_KERNEL
 
@@ -100,19 +101,8 @@
 #include "ui.h"
 
 #include <X11/Shell.h>
-#include <X11/cursorfont.h>
-#include <X11/Xaw/MenuButton.h>
-#include <X11/Xaw/Text.h>
-#include <X11/Xaw/TextSrc.h>
 #include <X11/Xaw/Form.h>
 #include <X11/Xaw/Box.h>
-#include <X11/Xaw/Cardinals.h>
-#include <X11/Xaw/Command.h>
-#include <X11/Xaw/Dialog.h>
-#include <X11/Xaw/List.h>
-#include <X11/Xaw/AsciiText.h>
-#include <X11/Xaw/Scrollbar.h>
-#include <X11/Xaw/Viewport.h>
 
 #include "ui_xWidgets.h"
 #include "ui_main.h"
@@ -158,9 +148,10 @@ void ui_inversion(Widget button, caddr_t call_data)
     }
 
 
-    if(INVERS_CREATED)
+    if(INVERS_CREATED){
+       XRaiseWindow(XtDisplay(ui_InvRootWidget), XtWindow(ui_InvRootWidget));
        return;
-
+    }
 
     if((test = ui_set_IO_units()) == 1){
       ui_confirmOk("No input and/or output units defined !");
@@ -184,13 +175,13 @@ void ui_inversion(Widget button, caddr_t call_data)
        dPtr = dPtr->nextPtr;
     }
  
-    sprintf(buf,"inversion display");
+    sprintf(buf,"SNNS Inversion Display");
     ui_InvRootWidget =
 	XtCreatePopupShell(buf, topLevelShellWidgetClass, ui_toplevel,args, n);
     displayPtr->frameWidget = 
-	XtCreateManagedWidget("form", formWidgetClass, ui_InvRootWidget, NULL, ZERO);
+	XtCreateManagedWidget("form", formWidgetClass, ui_InvRootWidget,NULL,0);
 
-    fbutton    = ui_xCreateButtonItem("done", displayPtr->frameWidget, NULL, NULL);
+    fbutton = ui_xCreateButtonItem("done", displayPtr->frameWidget, NULL, NULL);
     sbutton    = ui_xCreateButtonItem("multiStep", displayPtr->frameWidget,
 				   fbutton, NULL);
     stopbutton = ui_xCreateButtonItem("stop", displayPtr->frameWidget,
@@ -236,8 +227,8 @@ void ui_inversion(Widget button, caddr_t call_data)
 
     /* define necessary callbacks */
 
-    XtAddCallback(fbutton, XtNcallback, (XtCallbackProc) ui_closeDisplay,NULL);
-    XtAddCallback(sbutton, XtNcallback, (XtCallbackProc) ui_start_inversion, NULL);
+    XtAddCallback(fbutton, XtNcallback,(XtCallbackProc)ui_closeDisplay,NULL);
+    XtAddCallback(sbutton, XtNcallback,(XtCallbackProc)ui_start_inversion,NULL);
     XtAddCallback(stbutton, XtNcallback, (XtCallbackProc) ui_invNew, NULL);
     XtAddCallback(stopbutton, XtNcallback, 
 		  (XtCallbackProc) ui_stop_inversion, NULL);
@@ -288,7 +279,7 @@ static void ui_invSetup(Widget button, caddr_t call_data)
     XtSetArg(args[0], XtNwidth, &width);n++;
     XtSetArg(args[1], XtNheight, &height);n++;
     XtGetValues(button, args, n);
-    XtTranslateCoords(button, (Position)(width/2), (Position)(height/2), &x, &y);
+    XtTranslateCoords(button, (Position)(width/2), (Position)(height/2), &x,&y);
     n = 0;
     XtSetArg(args[n], XtNx, x);n++;
     XtSetArg(args[n], XtNy, y);n++;
@@ -299,25 +290,28 @@ static void ui_invSetup(Widget button, caddr_t call_data)
     ui_invpop = XtCreatePopupShell("setup", transientShellWidgetClass, 
 				   ui_toplevel, args, n);
     ui_invBox = XtCreateManagedWidget("form", formWidgetClass, ui_invpop, 
-				      NULL, ZERO);
+				      NULL, 0);
     doneButton = ui_xCreateButtonItem("done", ui_invBox, NULL, NULL);
-    XtAddCallback(doneButton, XtNcallback, (XtCallbackProc) ui_inv_popupDone, NULL);
+    XtAddCallback(doneButton, XtNcallback, (XtCallbackProc) ui_inv_popupDone, 
+		  NULL);
     helpButton = ui_xCreateButtonItem("help", ui_invBox, doneButton, NULL);
     XtAddCallback(helpButton, XtNcallback, (XtCallbackProc) ui_invHelp, FALSE);
     eta_lab = ui_xCreateLabelItem("eta           =", ui_invBox,120,
 				  NULL,doneButton);
     sprintf(buf,"%g",INV_eta);
-    etaW    = ui_xCreateDialogItem("eta_val",ui_invBox,buf,56,eta_lab,doneButton);
+    etaW = ui_xCreateDialogItem("eta_val",ui_invBox,buf,56,eta_lab,doneButton);
     delta_lab = ui_xCreateLabelItem("delta_max     =",ui_invBox,120,
 				    NULL,eta_lab);
     sprintf(buf,"%g",INV_delta_max);
     delta_maxW = ui_xCreateDialogItem("delta_max_val",ui_invBox, 
 				      buf, 56, delta_lab, etaW);
-    pat_lab = ui_xCreateLabelItem("Input pattern =",ui_invBox,120,NULL,delta_lab);
+    pat_lab = ui_xCreateLabelItem("Input pattern =",ui_invBox,120,NULL,
+				  delta_lab);
     sprintf(buf,"%g",INPUT_PAT);
     inPatW = ui_xCreateDialogItem("input_pat_val",ui_invBox,buf,56,
 				  pat_lab,delta_maxW);
-    rat_lab = ui_xCreateLabelItem("2nd approx ratio",ui_invBox,120,NULL,pat_lab);
+    rat_lab = ui_xCreateLabelItem("2nd approx ratio",ui_invBox,120,NULL,
+				  pat_lab);
     sprintf(buf,"%g",RATIO);
     ratioW = ui_xCreateDialogItem("ratio_val",ui_invBox,buf,56,
 				  rat_lab,inPatW);
@@ -423,7 +417,7 @@ static void ui_invHelp(Widget button, Boolean fromMain, caddr_t call_data)
     ui_invHelp = XtCreatePopupShell("help", transientShellWidgetClass, 
 				   ui_toplevel, args, n);
     ui_invHBox = XtCreateManagedWidget("form", formWidgetClass, ui_invHelp, 
-				      NULL, ZERO);
+				      NULL, 0);
     doneButton = ui_xCreateButtonItem("done", ui_invHBox, NULL, NULL);
     XtAddCallback(doneButton, XtNcallback, (XtCallbackProc) ui_inv_helpDone, NULL);
 
