@@ -1,7 +1,7 @@
 /*****************************************************************************
-  FILE           : $Source: /usr/local/bv/SNNS/SNNSv4.0/xgui/sources/RCS/ui_netGraph.c,v $
+  FILE           : $Source: /projects/higgs1/SNNS/CVS/SNNS/xgui/sources/ui_netGraph.c,v $
   SHORTNAME      : netGraph.c
-  SNNS VERSION   : 4.0
+  SNNS VERSION   : 4.2
 
   PURPOSE        : routines to draw all graphic elements of the net
   NOTES          :
@@ -10,13 +10,14 @@
   DATE           : 18.5.1990
 
   CHANGED BY     :
-  IDENTIFICATION : $State: Exp $ $Locker:  $
-  RCS VERSION    : $Revision: 2.4 $
-  LAST CHANGE    : $Date: 1995/03/14 14:16:44 $
+  RCS VERSION    : $Revision: 2.8 $
+  LAST CHANGE    : $Date: 1998/03/03 14:10:39 $
 
-             Copyright (c) 1990-1995  SNNS Group, IPVR, Univ. Stuttgart, FRG
+    Copyright (c) 1990-1995  SNNS Group, IPVR, Univ. Stuttgart, FRG
+    Copyright (c) 1996-1998  SNNS Group, WSI, Univ. Tuebingen, FRG
              
 ******************************************************************************/
+#include <config.h>
 
 
 #include <stdio.h>
