@@ -1,7 +1,7 @@
 /*****************************************************************************
-  FILE           : $Source: /usr/local/bv/SNNS/SNNSv4.0/xgui/sources/RCS/ui_print.c,v $
+  FILE           : $Source: /projects/higgs1/SNNS/CVS/SNNS/xgui/sources/ui_print.c,v $
   SHORTNAME      : print.c
-  SNNS VERSION   : 4.0
+  SNNS VERSION   : 4.2
 
   PURPOSE        : contains routines to print a network on a postscript printer
   NOTES          : not fully implemented
@@ -10,18 +10,16 @@
   DATE           : 25.5.1992
 
   CHANGED BY     :
-  IDENTIFICATION : $State: Exp $ $Locker:  $
-  RCS VERSION    : $Revision: 2.6 $
-  LAST CHANGE    : $Date: 1995/05/11 15:32:36 $
+  RCS VERSION    : $Revision: 2.16 $
+  LAST CHANGE    : $Date: 1998/03/13 16:31:56 $
 
-             Copyright (c) 1990-1995  SNNS Group, IPVR, Univ. Stuttgart, FRG
+    Copyright (c) 1990-1995  SNNS Group, IPVR, Univ. Stuttgart, FRG
+    Copyright (c) 1996-1998  SNNS Group, WSI, Univ. Tuebingen, FRG
              
 ******************************************************************************/
-
-
+#include <config.h>
 #include <stdio.h>
 #include <stdlib.h>
-#include <malloc.h>		    
 #include <math.h>		    
 #include <time.h>		    
 
@@ -85,7 +83,7 @@ void ui_defaultPrinterValues (void)
     strcpy (ui_prVal.cmdLineStr, "rlp $1 -raw -pr=lw4");
 }
 
-
+#ifdef _UNUSED_FUNCTIONS_
 /*****************************************************************************
   FUNCTION : ui_readPrintHeader
 
@@ -95,11 +93,8 @@ void ui_defaultPrinterValues (void)
 
   UPDATE   :
 *****************************************************************************/
-
 static void ui_readPrintHeader (void)
-
 {
-    FILE *filePtr;
 
 #ifndef HEADER_COMPILE
     if ((filePtr = fopen ("psheader05.ps", "r")) == NULL) {
@@ -118,7 +113,7 @@ static void ui_readPrintHeader (void)
     *(psHeader+headerSize) = '\0';
 #endif
 }
-
+#endif
 
 /*****************************************************************************
   FUNCTION : ui_valueToRGB
@@ -620,9 +615,9 @@ static void ui_printProlog (void)
 
 {
     fprintf (psOutfile, "%%!PS-Adobe-2.0\n");
-    fprintf (psOutfile, "%%%%Copyright (c) 1992 Tilman Sommer\n");
+    fprintf (psOutfile, "%%%%Copyright (c) 1992-1998 SNNS Group\n");
     fprintf (psOutfile, "%%%%Title: SNNS network: %s\n", ui_filenameNET);
-    fprintf (psOutfile, "%%%%Creator: SNNS Version 3.1\n");
+    fprintf (psOutfile, "%%%%Creator: SNNS Version 4.2\n");
     fprintf (psOutfile, "%%%%CreationDate: %s", timeStr);
     fprintf (psOutfile, "%%%%Pages: 0\n");
 /*
@@ -833,27 +828,6 @@ static void ui_closePrintPannel (Widget w, Widget pannel, caddr_t call_data)
 }
 
 
-/*****************************************************************************
-  FUNCTION : ui_setToggles
-
-  PURPOSE  : toggles one of the radio button groups
-  RETURNS  : void
-  NOTES    : sets the toggle variable to the new value
-
-  UPDATE   :
-*****************************************************************************/
-
-static void ui_setToggles (int index, int *new, int max, Widget widgets[])
-
-{
-   int i;
-
-   for(i=0; i<max; i++)
-       ui_xSetToggleState(widgets[i], FALSE);
-   ui_xSetToggleState(widgets[index], TRUE);
-   *new = index;
-}
-
 
 /*****************************************************************************
   FUNCTION : ui_setCmdLine
@@ -1202,25 +1176,16 @@ static void ui_printSetupProc (Widget w, Widget button, caddr_t call_data)
                                     borderToggle[0], textToggle[0]);
     XtAddCallback (borderToggle[1], XtNcallback, (XtCallbackProc) ui_setBorderProc, (caddr_t) UI_BORDER_OFF);
 
-/*
-    label = ui_xCreateLabelItem ("Clipping", pannel, ui_fontWidth * 10,
-                                   NULL, borderToggle[0]); 
-    clipToggle[0] = ui_xCreateToggleItem ("on", pannel, NULL,
-                                    label, borderToggle[0]);
-    XtAddCallback (clipToggle[0], XtNcallback, (XtCallbackProc) ui_setClipProc, (caddr_t) UI_CLIP_ON);
-    clipToggle[1] = ui_xCreateToggleItem ("off", pannel, NULL,
-                                    clipToggle[0], borderToggle[0]);
-    XtAddCallback (clipToggle[1], XtNcallback, (XtCallbackProc) ui_setClipProc, (caddr_t) UI_CLIP_OFF);
-*/
-
     label = ui_xCreateLabelItem ("Color", pannel, ui_fontWidth * 10,
                                    NULL, borderToggle[0]); 
     colorToggle[0] = ui_xCreateToggleItem ("on", pannel, NULL,
                                     label, borderToggle[0]);
-    XtAddCallback (colorToggle[0], XtNcallback, (XtCallbackProc) ui_setColorProc, (caddr_t) UI_COLOR_ON);
+    XtAddCallback (colorToggle[0], XtNcallback, (XtCallbackProc)ui_setColorProc,
+		   (caddr_t) UI_COLOR_ON);
     colorToggle[1] = ui_xCreateToggleItem ("off", pannel, NULL,
                                     colorToggle[0], borderToggle[0]);
-    XtAddCallback (colorToggle[1], XtNcallback, (XtCallbackProc) ui_setColorProc, (caddr_t) UI_COLOR_OFF);
+    XtAddCallback (colorToggle[1], XtNcallback, (XtCallbackProc)ui_setColorProc,
+		   (caddr_t) UI_COLOR_OFF);
 
     label = ui_xCreateLabelItem ("Fill Intens.", pannel, ui_fontWidth * 10,
                                   NULL, colorToggle[0]); 
@@ -1238,13 +1203,11 @@ static void ui_printSetupProc (Widget w, Widget button, caddr_t call_data)
     XtPopup (networkPannel, XtGrabExclusive);
     ui_xDontResizeWidget(networkPannel); 
 
-    ui_setToggles(ui_prVal.border, &ui_prVal.border, noOfBorderToggles, borderToggle);
-/*
-    ui_setToggles(ui_prVal.clip, &ui_prVal.clip, noOfClipToggles, clipToggle);
-*/
-    ui_setToggles(ui_prVal.color, &ui_prVal.color, noOfColorToggles, colorToggle);
+    ui_setToggles(ui_prVal.border, &ui_prVal.border, noOfBorderToggles, 
+		  borderToggle);
+    ui_setToggles(ui_prVal.color, &ui_prVal.color,noOfColorToggles,colorToggle);
     ui_setToggles(ui_prVal.size, &ui_prVal.size, noOfSizeToggles, sizeToggle);
-    ui_setToggles(ui_prVal.shape, &ui_prVal.shape, noOfShapeToggles, shapeToggle);
+    ui_setToggles(ui_prVal.shape, &ui_prVal.shape,noOfShapeToggles,shapeToggle);
     ui_setToggles(ui_prVal.text, &ui_prVal.text, noOfTextToggles, textToggle);
 
 }
@@ -1263,15 +1226,18 @@ static void ui_printSetupProc (Widget w, Widget button, caddr_t call_data)
 void ui_printNet (void)
 
 {
-    Widget       printPannel, border, pannel, done, network, print, label;
+    Widget       border, pannel, done, network, print, label;
     Widget       label1, label2, label3;
     Arg          arg[25];
     Cardinal     n;
     char         buf[UI_STR_LEN];
     int          labelWidth = 11;
 
-    if (ui_printPannelIsOpen)
+    if (ui_printPannelIsOpen){
+       XRaiseWindow (XtDisplay (ui_printPannel), XtWindow (ui_printPannel));
        return;
+    }
+
     ui_printPannelIsOpen = TRUE;
 
     if (!ui_printDefaultsAreThere) {
@@ -1282,13 +1248,12 @@ void ui_printNet (void)
     ui_getNetworkSize (&networkXmin, &networkYmin, &networkXmax, &networkYmax);
     ui_transferSettings();
 
-    sprintf(buf, "printer setup");
+    sprintf(buf, "SNNS printer setup");
     n = 0;
-    printPannel = 
-	XtCreatePopupShell(buf, topLevelShellWidgetClass, ui_toplevel,
-			   arg, n);
+    ui_printPannel = XtCreatePopupShell(buf, topLevelShellWidgetClass, 
+					ui_toplevel, arg, n);
     border = XtCreateManagedWidget("border", boxWidgetClass,
-                                   printPannel, NULL, ZERO);
+                                   ui_printPannel, NULL, ZERO);
     pannel = XtCreateManagedWidget("pannel", formWidgetClass, 
                                    border, NULL, ZERO);
 
@@ -1297,57 +1262,56 @@ void ui_printNet (void)
     done = ui_xCreateButtonItem ("done", border, network, NULL);
 
     XtAddCallback (done, XtNcallback, (XtCallbackProc) ui_closePrintPannel,
-                   (caddr_t) printPannel);
+                   (caddr_t) ui_printPannel);
 
     XtAddCallback (print, XtNcallback, (XtCallbackProc) ui_printProc, NULL);
-    XtAddCallback (network, XtNcallback, (XtCallbackProc) ui_printSetupProc, (caddr_t) network);
+    XtAddCallback (network, XtNcallback, (XtCallbackProc) ui_printSetupProc, 
+		   (caddr_t) network);
 
-    cmdLabel = ui_xCreateLabelItem ("Command", pannel, ui_fontWidth * labelWidth,
+    cmdLabel = ui_xCreateLabelItem ("Command", pannel, ui_fontWidth *labelWidth,
                                    NULL, NULL); 
 
-    cmdLine = ui_xCreateDialogItem ("cmd_line", pannel, ui_prVal.cmdLineStr, ui_fontWidth * 40, 
-                                   cmdLabel, NULL);
+    cmdLine = ui_xCreateDialogItem ("cmd_line", pannel, ui_prVal.cmdLineStr, 
+				    ui_fontWidth * 40,    cmdLabel, NULL);
 
-    label = ui_xCreateLabelItem ("Destination", pannel, ui_fontWidth * labelWidth,
+    label = ui_xCreateLabelItem ("Destination", pannel, ui_fontWidth*labelWidth,
                                    NULL, cmdLine); 
     destToggle[0] = ui_xCreateToggleItem ("printer", pannel, NULL,
                                     label, cmdLine);
-    XtAddCallback (destToggle[0], XtNcallback, (XtCallbackProc) ui_setDestProc, (caddr_t) UI_DEST_PRINTER);
+    XtAddCallback (destToggle[0], XtNcallback, (XtCallbackProc) ui_setDestProc,
+		   (caddr_t) UI_DEST_PRINTER);
     destToggle[1] = ui_xCreateToggleItem ("file", pannel, NULL,
                                     destToggle[0], cmdLine);
-    XtAddCallback (destToggle[1], XtNcallback, (XtCallbackProc) ui_setDestProc, (caddr_t) UI_DEST_FILE);
+    XtAddCallback (destToggle[1], XtNcallback, (XtCallbackProc) ui_setDestProc,
+		   (caddr_t) UI_DEST_FILE);
 
-/*
-    label1 = ui_xCreateLabelItem ("    Format", pannel, ui_fontWidth * 10,
-                                   destToggle[1], cmdLine); 
-    formatToggle[0] = ui_xCreateToggleItem ("postscript", pannel, NULL, label1, cmdLine);
-    XtAddCallback (formatToggle[0], XtNcallback, (XtCallbackProc) ui_setFormatProc, (caddr_t) UI_FORMAT_POSTSCRIPT);
-    formatToggle[1] = ui_xCreateToggleItem ("eps", pannel, NULL, formatToggle[0], cmdLine);
-    XtAddCallback (formatToggle[1], XtNcallback, (XtCallbackProc) ui_setFormatProc, (caddr_t) UI_FORMAT_EPSF);
-*/
     label = ui_xCreateLabelItem ("Paper", pannel, ui_fontWidth * labelWidth,
                                    NULL, destToggle[0]); 
     paperToggle[0] = ui_xCreateToggleItem ("dina4", pannel, NULL,
                                     label, destToggle[0]);
-    XtAddCallback (paperToggle[0], XtNcallback, (XtCallbackProc) ui_setPaperProc, (caddr_t) UI_PAPER_DINA4);
+    XtAddCallback (paperToggle[0], XtNcallback, (XtCallbackProc)ui_setPaperProc,
+		   (caddr_t) UI_PAPER_DINA4);
     paperToggle[1] = ui_xCreateToggleItem ("dina3", pannel, NULL,
                                     paperToggle[0], destToggle[0]);
-    XtAddCallback (paperToggle[1], XtNcallback, (XtCallbackProc) ui_setPaperProc, (caddr_t) UI_PAPER_DINA3);
+    XtAddCallback (paperToggle[1], XtNcallback, (XtCallbackProc)ui_setPaperProc,
+		   (caddr_t) UI_PAPER_DINA3);
     paperToggle[2] = ui_xCreateToggleItem ("usletter", pannel, NULL,
                                     paperToggle[1], destToggle[0]);
-    XtAddCallback (paperToggle[2], XtNcallback, (XtCallbackProc) ui_setPaperProc, (caddr_t) UI_PAPER_USLETTER);
+    XtAddCallback (paperToggle[2], XtNcallback, (XtCallbackProc)ui_setPaperProc,
+		   (caddr_t) UI_PAPER_USLETTER);
 
-
-    label = ui_xCreateLabelItem ("Orientation", pannel, ui_fontWidth * labelWidth,
+    label = ui_xCreateLabelItem("Orientation", pannel, ui_fontWidth*labelWidth,
                                    NULL, paperToggle[0]); 
     orientToggle[0] = ui_xCreateToggleItem ("portrait", pannel, NULL,
                                     label, paperToggle[0]);
-    XtAddCallback (orientToggle[0], XtNcallback, (XtCallbackProc) ui_setOrientProc, (caddr_t) UI_ORIENTATION_PORTAIT);
+    XtAddCallback (orientToggle[0],XtNcallback,(XtCallbackProc)ui_setOrientProc,
+		   (caddr_t) UI_ORIENTATION_PORTAIT);
     orientToggle[1] = ui_xCreateToggleItem ("landscape", pannel, NULL,
                                     orientToggle[0], paperToggle[0]);
-    XtAddCallback (orientToggle[1], XtNcallback, (XtCallbackProc) ui_setOrientProc, (caddr_t) UI_ORIENTATION_LANDSCAPE);
+    XtAddCallback(orientToggle[1], XtNcallback,(XtCallbackProc)ui_setOrientProc,
+		  (caddr_t) UI_ORIENTATION_LANDSCAPE);
 
-    label = ui_xCreateLabelItem ("Border (mm)", pannel, ui_fontWidth * labelWidth,
+    label = ui_xCreateLabelItem ("Border (mm)", pannel, ui_fontWidth*labelWidth,
                                    NULL, orientToggle[0]);
     label1 = ui_xCreateLabelItem ("horiz", pannel, ui_fontWidth * 7,
                                    label, orientToggle[0]);
@@ -1376,35 +1340,39 @@ void ui_printNet (void)
                                    NULL, psxScale); 
     autoScaleToggle[0] = ui_xCreateToggleItem ("on", pannel, NULL,
                                     label, psxScale);
-    XtAddCallback (autoScaleToggle[0], XtNcallback, (XtCallbackProc) ui_setAutoScaleProc, (caddr_t) UI_AUTOSCALE_ON);
+    XtAddCallback(autoScaleToggle[0], XtNcallback, 
+		  (XtCallbackProc)ui_setAutoScaleProc,(caddr_t)UI_AUTOSCALE_ON);
     autoScaleToggle[1] = ui_xCreateToggleItem ("off", pannel, NULL,
                                     autoScaleToggle[0], psxScale);
-    XtAddCallback (autoScaleToggle[1], XtNcallback, (XtCallbackProc) ui_setAutoScaleProc, (caddr_t) UI_AUTOSCALE_OFF);
+    XtAddCallback(autoScaleToggle[1], XtNcallback, 
+		 (XtCallbackProc)ui_setAutoScaleProc,(caddr_t)UI_AUTOSCALE_OFF);
 
     label1 = ui_xCreateLabelItem ("   Aspect", pannel, ui_fontWidth * 8,
                                    autoScaleToggle[1], psxScale); 
     autoUniToggle[0] = ui_xCreateToggleItem ("on", pannel, NULL,
                                     label1, psxScale);
-    XtAddCallback (autoUniToggle[0], XtNcallback, (XtCallbackProc) ui_setAutoUniProc, (caddr_t) UI_AUTOUNI_ON);
+    XtAddCallback (autoUniToggle[0], XtNcallback, 
+		   (XtCallbackProc) ui_setAutoUniProc, (caddr_t) UI_AUTOUNI_ON);
     autoUniToggle[1] = ui_xCreateToggleItem ("off", pannel, NULL,
                                     autoUniToggle[0], psxScale);
-    XtAddCallback (autoUniToggle[1], XtNcallback, (XtCallbackProc) ui_setAutoUniProc, (caddr_t) UI_AUTOUNI_OFF);
+    XtAddCallback (autoUniToggle[1], XtNcallback, 
+		   (XtCallbackProc) ui_setAutoUniProc, (caddr_t)UI_AUTOUNI_OFF);
 
 
     XtAddEventHandler(pannel,KeyPressMask,FALSE,
 		      (XtEventHandler)ui_key_control,(Cardinal *) 0);
-    ui_checkWindowPosition(printPannel);
-    XtPopup (printPannel, XtGrabNone);
-    ui_xDontResizeWidget(printPannel); 
+    ui_checkWindowPosition(ui_printPannel);
+    XtPopup (ui_printPannel, XtGrabNone);
+    ui_xDontResizeWidget(ui_printPannel); 
 
     ui_setCmdLine(ui_prVal.dest);
     ui_setToggles(ui_prVal.dest, &ui_prVal.dest, noOfDestToggles, destToggle);
-/*
-    ui_setToggles(ui_prVal.format, &ui_prVal.format, noOfFmtToggles, formatToggle);
-*/
-    ui_setToggles(ui_prVal.paper, &ui_prVal.paper, noOfPaperToggles, paperToggle); 
-    ui_setToggles(ui_prVal.autoScale, &ui_prVal.autoScale, noOfAsToggles, autoScaleToggle);
-    ui_setToggles(ui_prVal.autoUni, &ui_prVal.autoUni, noOfAuToggles, autoUniToggle);
-    ui_setToggles(ui_prVal.orient, &ui_prVal.orient, noOfOrientToggles, orientToggle);
+    ui_setToggles(ui_prVal.paper,&ui_prVal.paper,noOfPaperToggles,paperToggle); 
+    ui_setToggles(ui_prVal.autoScale, &ui_prVal.autoScale, noOfAsToggles, 
+		  autoScaleToggle);
+    ui_setToggles(ui_prVal.autoUni, &ui_prVal.autoUni, noOfAuToggles, 
+		  autoUniToggle);
+    ui_setToggles(ui_prVal.orient, &ui_prVal.orient, noOfOrientToggles, 
+		  orientToggle);
 }
 
