@@ -1,7 +1,7 @@
 /*****************************************************************************
-  FILE           : $Source: /usr/local/bv/SNNS/SNNSv4.0/xgui/sources/RCS/ui_selection.c,v $
+  FILE           : $Source: /projects/higgs1/SNNS/CVS/SNNS/xgui/sources/ui_selection.c,v $
   SHORTNAME      : select.c
-  SNNS VERSION   : 4.0
+  SNNS VERSION   : 4.2
 
   PURPOSE        :
   NOTES          : UI_SELECTION_SIZE is no more in use! (defined in ui.h)
@@ -10,22 +10,19 @@
   DATE           : 1.2.1990
 
   CHANGED BY     :
-  IDENTIFICATION : $State: Exp $ $Locker:  $
-  RCS VERSION    : $Revision: 2.3 $
-  LAST CHANGE    : $Date: 1995/03/14 14:16:53 $
+  RCS VERSION    : $Revision: 2.9 $
+  LAST CHANGE    : $Date: 1998/03/13 16:31:57 $
 
-             Copyright (c) 1990-1995  SNNS Group, IPVR, Univ. Stuttgart, FRG
+    Copyright (c) 1990-1995  SNNS Group, IPVR, Univ. Stuttgart, FRG
+    Copyright (c) 1996-1998  SNNS Group, WSI, Univ. Tuebingen, FRG
              
 ******************************************************************************/
-
-
+#include <config.h>
 #include <stdio.h>
-#include <malloc.h>
+#include <stdlib.h>
 
 #include "ui.h"
-
 #include "kr_ui.h"
-
 #include "ui_utilP.h"
 #include "ui_textP.h"
 #include "ui_status.h"
@@ -37,7 +34,6 @@
 #include "ui_event.h"
 #include "ui_mainP.h"
 
-
 #include "ui_selection.ph"
 
 
